<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:template match="OMA">
		<xsl:choose>
			<xsl:when test="SMStatus='0'">
				<xsl:apply-templates select="LRAProtObj"/>
			</xsl:when>
			<xsl:otherwise>
				<DataArea>
					<PageTitle>
						<xsl:attribute name="display">
							<xsl:call-template name="smstatus">
								<xsl:with-param name="status"><xsl:value-of select="SMStatus"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
					</PageTitle>
				</DataArea>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="LRAProtObj">
		<xsl:choose>
			<xsl:when test="/OMA/@cli = 'true'">
				<DataArea>
					<PageTitle>
						<xsl:attribute name="display"><!--XLATESTART-->Thermal Shutdown<!--XLATESTOP--></xsl:attribute>
					</PageTitle>
					<ListData>
						<Data name="LRAProtect">
							<xsl:attribute name="display"><!--XLATESTART-->Thermal protect shutdown severity<!--XLATESTOP--></xsl:attribute>
							<xsl:attribute name="value"><xsl:call-template name="cond2txt">
								<xsl:with-param name="condition"><xsl:value-of select="Condition"/></xsl:with-param>
							</xsl:call-template></xsl:attribute>
						</Data>
					</ListData>
				</DataArea>
			</xsl:when>
			<xsl:otherwise>
				<DataArea>
					<xsl:if test="(/OMA/OMAUserRights = '7')">
						<xsl:attribute name="submit">/servlet/SubmitForm?plugin=com.dell.hip.webplugins.SetLRAProtectWebPlugin</xsl:attribute>
					</xsl:if>
					<PageTitle>
						<xsl:attribute name="display"><!--XLATESTART-->Thermal Shutdown<!--XLATESTOP--></xsl:attribute>
					</PageTitle>
					<CustomButton>
						<Data name="Refresh" display="Refresh">
							<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.hip.webplugins.LRAProtectWebPlugin</xsl:attribute>
						</Data>
					</CustomButton>			
					<TableData>
						<Row>
							<Data name="oid" display="oid" type="hidden">
								<xsl:attribute name="returnvalue"><xsl:value-of select="@oid"/></xsl:attribute>
							</Data>
							<Data name="LRAProtect" value="Thermal Protect Shutdown Severity"/>
							<xsl:choose>
								<xsl:when test="(/OMA/OMAUserRights = '7')">
									<Data name="condition" type="radio">
										<xsl:attribute name="value">Disabled</xsl:attribute>
										<xsl:attribute name="returnvalue">0</xsl:attribute>
										<xsl:if test="Condition='0'">
											<xsl:attribute name="state">1</xsl:attribute>
										</xsl:if>
									</Data>
									<Data name="condition" type="radio">
										<xsl:attribute name="value">Warning</xsl:attribute>
										<xsl:attribute name="returnvalue">1</xsl:attribute>
										<xsl:if test="Condition='1'">
											<xsl:attribute name="state">1</xsl:attribute>
										</xsl:if>
									</Data>
									<Data name="condition" type="radio">
										<xsl:attribute name="value">Failure</xsl:attribute>
										<xsl:attribute name="returnvalue">2</xsl:attribute>
										<xsl:if test="Condition='2'">
											<xsl:attribute name="state">1</xsl:attribute>
										</xsl:if>
									</Data>
								</xsl:when>
								<xsl:otherwise>
									<Data name="condition" type="radio">
										<xsl:attribute name="value">Disabled</xsl:attribute>
										<xsl:choose>
											<xsl:when test="Condition='0'"><xsl:attribute name="state">3</xsl:attribute></xsl:when>
											<xsl:otherwise><xsl:attribute name="state">2</xsl:attribute></xsl:otherwise>
										</xsl:choose>
									</Data>
									<Data name="condition" type="radio">
										<xsl:attribute name="value">Warning</xsl:attribute>
										<xsl:choose>
											<xsl:when test="Condition='1'"><xsl:attribute name="state">3</xsl:attribute></xsl:when>
											<xsl:otherwise><xsl:attribute name="state">2</xsl:attribute></xsl:otherwise>
										</xsl:choose>
									</Data>
									<Data name="condition" type="radio">
										<xsl:attribute name="value">Failure</xsl:attribute>
										<xsl:choose>
											<xsl:when test="Condition='2'"><xsl:attribute name="state">3</xsl:attribute></xsl:when>
											<xsl:otherwise><xsl:attribute name="state">2</xsl:attribute></xsl:otherwise>
										</xsl:choose>
									</Data>
								</xsl:otherwise>
							</xsl:choose>
						</Row>
					</TableData>
				</DataArea>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="cond2txt">
		<xsl:param name="condition"/>
		<xsl:choose>
			<xsl:when test="$condition='0'">Disabled</xsl:when>
			<xsl:when test="$condition='1'">Warning</xsl:when>			
			<xsl:when test="$condition='2'">Failure</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="smstatus">
		<xsl:param name="status"/>
		<xsl:choose>
			<xsl:when test="$status = '-1'"><!--XLATESTART-->Error! Command Unsuccessful.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '0'"><!--XLATESTART-->Error! Command Successful.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '1'"><!--XLATESTART-->Error! Command Not Implemented.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '2'"><!--XLATESTART-->Error! Bad Command.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '3'"><!--XLATESTART-->Error! Command Timeout.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '4'"><!--XLATESTART-->Error! Command Cancelled.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '5'"><!--XLATESTART-->Error! Command Aborted.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '6'"><!--XLATESTART-->Error! Command Pending.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '7'"><!--XLATESTART-->Error! No such device.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '8'"><!--XLATESTART-->Error! Device busy.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '9'"><!--XLATESTART-->Error! Bad device.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '10'"><!--XLATESTART-->Error! Spurious Interrupt.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '11'"><!--XLATESTART-->Error! Resource locked.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '12'"><!--XLATESTART-->Error! Invalid index.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '13'"><!--XLATESTART-->Error! SMB error.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '14'"><!--XLATESTART-->Error! Data requested is not available.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '15'"><!--XLATESTART-->Error! Data requested is more than data available.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '16'"><!--XLATESTART-->Error! Data requested is less than data available.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '17'"><!--XLATESTART-->Error! Device not yet ready to accept commands. Try later.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '18'"><!--XLATESTART-->Error! Device does not have data.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '19'"><!--XLATESTART-->Error! Device out of memory.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '20'"><!--XLATESTART-->Error! Device already exists.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '256'"><!--XLATESTART-->Error! Thermal protect shutdown feature not found on this system.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '257'"><!--XLATESTART-->Error! Thermal protect shutdown object malformed, corrupt or bad.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '258'"><!--XLATESTART-->Error! Thermal protect shutdown object already exists.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '260'"><!--XLATESTART-->Error! INI file not found.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '261'"><!--XLATESTART-->Error! INI malformed, corrupt or bad.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '262'"><!--XLATESTART-->Error! INI section does not exist.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '263'"><!--XLATESTART-->Error! INI key does not exist.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '264'"><!--XLATESTART-->Error! INI value malformed, corrupt or bad.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '270'"><!--XLATESTART-->Error! Insufficient access rights.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '271'"><!--XLATESTART-->Error! Invalid parameter name or value.</xsl:when>
			<xsl:when test="$status = '272'"><!--XLATESTART-->Error! Out of memory.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '280'"><!--XLATESTART-->Error! XML file not found.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '281'"><!--XLATESTART-->Error! XML malformed, corrupt or bad.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '282'"><!--XLATESTART-->Error! XML node does not exist.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '283'"><!--XLATESTART-->Error! XML value malformed, corrupt or bad.<!--XLATESTOP--></xsl:when>
			<xsl:otherwise>SMStatus: <xsl:value-of select="$status"/></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
