<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" />
	<xsl:strip-space elements="*"/>
	<xsl:template match="OMA">
		<xsl:choose>
			<xsl:when test="SMStatus != '0'">
				<DataArea printable="false">
					<PageTitle>
						<xsl:attribute name="display">
							<xsl:call-template name="smstatus">
								<xsl:with-param name="status"><xsl:value-of select="SMStatus"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
					</PageTitle>
				</DataArea>
			</xsl:when>
			<xsl:otherwise>
				<DataArea validate="true" onLoad="true">
				<xsl:attribute name="backpagedisplay"><!--XLATESTART-->L&#252;ftersonden<!--XLATESTOP--></xsl:attribute>
					<xsl:apply-templates select="ServletArguments"/>
					<xsl:apply-templates select="FanProbe"/>
				</DataArea>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="FanProbe">
		<PageTitle></PageTitle>
		<SubHeader >
			<xsl:attribute name="display"><xsl:value-of select="ProbeLocation"/></xsl:attribute>
			<xsl:attribute name="status"><xsl:value-of select="@status"/></xsl:attribute>
		</SubHeader>
		<xsl:choose>
			<xsl:when test="(ProbeThresholds/LCThreshold &gt; 0) and (ProbeThresholds/UCThreshold &gt; 0) and (ProbeThresholds/LNCThreshold &gt; 0) and (ProbeThresholds/UNCThreshold &gt; 0) and (ProbeReading &gt;= 0)">
				<Guage  digits="0">
				<xsl:attribute name="units"> <!--XLATESTART-->U/min<!--XLATESTOP--></xsl:attribute>
					<Reading><xsl:value-of select="ProbeReading"/></Reading>
					<MFThresh><xsl:value-of select="ProbeThresholds/LCThreshold"/></MFThresh>
					<MXFThresh><xsl:value-of select="ProbeThresholds/UCThreshold"/></MXFThresh>
					<MWThresh><xsl:value-of select="ProbeThresholds/LNCThreshold"/></MWThresh>
					<MXWThresh><xsl:value-of select="ProbeThresholds/UNCThreshold"/></MXWThresh>
					<ListData>
						<Data display="Status">
							<xsl:call-template name="StatusToStr">
								<xsl:with-param name="status"><xsl:value-of select="@status"/></xsl:with-param>
							</xsl:call-template>
						</Data>
						<Data display="Messwert" reading="true">
							<xsl:attribute name="value"><xsl:value-of select="ProbeReading"/> <!--XLATESTART-->U/min<!--XLATESTOP--></xsl:attribute>
						</Data>
						<Data display="Minimaler Fehler-Schwellenwert">
							<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/LCThreshold"/><!--XLATESTART--> U/min<!--XLATESTOP--></xsl:attribute>
						</Data>
						<Data display="Maximaler Fehler-Schwellenwert">
							<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/UCThreshold"/><!--XLATESTART--> U/min<!--XLATESTOP--></xsl:attribute>
						</Data>
						<xsl:choose>
						<xsl:when test="(Capabilities/ProbeUNCDefSetEnabled = 'true') or (Capabilities/ProbeLNCDefSetEnabled = 'true')">
						<Data display="Schwellenwert-Einstellungen" type="radio"  state="1">
							<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
							<xsl:attribute name="value">Standardeinstellung</xsl:attribute>
						</Data>
							<xsl:if test="(Capabilities/ProbeUNCSetEnabled = 'true') or (Capabilities/ProbeLNCSetEnabled = 'true')">
							<Data type="radio">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">Einstellen</xsl:attribute>
							</Data>
							</xsl:if>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="(Capabilities/ProbeUNCSetEnabled = 'true') or (Capabilities/ProbeLNCSetEnabled = 'true')">
							<Data display="Schwellenwert-Einstellungen" type="radio"  state="1">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">Einstellen</xsl:attribute>
							</Data>
							</xsl:if>
						</xsl:otherwise>
						</xsl:choose>
						<xsl:if test="(Capabilities/ProbeLNCSetEnabled = 'true')">
						<Data display="Minimaler Warnungs-Schwellenwert" type="editbox">
							<xsl:attribute name="textboxname">LNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART--> U/min<!--XLATESTOP--></xsl:attribute>
						</Data>
						</xsl:if>
						<xsl:if test="(Capabilities/ProbeUNCSetEnabled = 'true')">
						<Data display="Maximaler Warnungs-Schwellenwert" type="editbox">
							<xsl:attribute name="textboxname">UNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART--> U/min<!--XLATESTOP--></xsl:attribute>
						</Data>
						</xsl:if>
					</ListData>
				</Guage>
			</xsl:when>
			<xsl:otherwise>
				<ListData>
					<Data display="Status">
						<xsl:call-template name="StatusToStr">
							<xsl:with-param name="status"><xsl:value-of select="@status"/></xsl:with-param>
						</xsl:call-template>
					</Data>
					<Data display="Messwert">
						<xsl:attribute name="value"><xsl:value-of select="ProbeReading"/><!--XLATESTART--> U/min<!--XLATESTOP--></xsl:attribute>
					</Data>
					<Data display="Minimaler Fehler-Schwellenwert">
						<xsl:choose>
							<xsl:when test="ProbeThresholds/LCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/LCThreshold"/><!--XLATESTART--> U/min<!--XLATESTOP--></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value"><!--XLATESTART-->Unbekannt<!--XLATESTOP--></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</Data>			
					<Data display="Maximaler Fehler-Schwellenwert">
						<xsl:choose>
							<xsl:when test="ProbeThresholds/UCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/UCThreshold"/><!--XLATESTART--> U/min<!--XLATESTOP--></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value"><!--XLATESTART-->Unbekannt<!--XLATESTOP--></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</Data>
					<Data display="Schwellenwert-Einstellungen" type="radio"  state="1">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
						<xsl:attribute name="value">Standardeinstellung</xsl:attribute>
					</Data>
					<Data type="radio">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
						<xsl:attribute name="value">Einstellen</xsl:attribute>
					</Data>
					<Data display="Minimaler Warnungs-Schwellenwert" type="editbox" size="5">
						<xsl:attribute name="name">LNCVal</xsl:attribute>
						<xsl:choose>
							<xsl:when test="ProbeThresholds/LNCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value">0</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:attribute name="unit"><!--XLATESTART--> U/min<!--XLATESTOP--></xsl:attribute>
					</Data>
					<Data display="Maximaler Warnungs-Schwellenwert" type="editbox" size="5">
						<xsl:attribute name="name">UNCVal</xsl:attribute>
						<xsl:choose>
							<xsl:when test="ProbeThresholds/UNCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value">0</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:attribute name="unit"><!--XLATESTART--> U/min<!--XLATESTOP--></xsl:attribute>
					</Data>
				</ListData>
			</xsl:otherwise>
		</xsl:choose>
		<script language="javascript">
			isProbeUNCSetEnabled 		= <xsl:value-of select="Capabilities/ProbeUNCSetEnabled"/>;
			isProbeLNCSetEnabled 		= <xsl:value-of select="Capabilities/ProbeLNCSetEnabled"/>;
			isProbeUNCDefSetEnabled 	= <xsl:value-of select="Capabilities/ProbeUNCDefSetEnabled"/>;
			isProbeLNCDefSetEnabled 	= <xsl:value-of select="Capabilities/ProbeLNCDefSetEnabled"/>;
		
			setToDefault	= true;
			setToValues	= false;

if( (( ! isProbeUNCDefSetEnabled )  &amp;&amp; (! isProbeLNCDefSetEnabled)) &amp;&amp; ( isProbeUNCSetEnabled || isProbeLNCSetEnabled ) )
{
	setToValues	= true;
}

			function initializationRoutine()
			{
				if( isProbeUNCSetEnabled )
				{
					document.getElementById("UNCVal").value = <xsl:value-of select="ProbeThresholds/UNCThreshold"/>;
					document.getElementById("UNCVal").disabled = false;
					if ( ( isProbeUNCDefSetEnabled || isProbeLNCDefSetEnabled ) &amp;&amp; setToDefault )
					{
						document.getElementById("UNCVal").disabled = true;
					}
				}

				if( isProbeLNCSetEnabled )
				{
					document.getElementById("LNCVal").value = <xsl:value-of select="ProbeThresholds/LNCThreshold"/>;
					document.getElementById("LNCVal").disabled = false;
					if ( ( isProbeUNCDefSetEnabled || isProbeLNCDefSetEnabled ) &amp;&amp; setToDefault )
					{
						document.getElementById("LNCVal").disabled = true;
					}
				}
				
				if( isProbeUNCDefSetEnabled || isProbeLNCDefSetEnabled )
				{
					document.getElementById("threshsetting").checked = true;
				}
			}
			
			function setToVal()
			{
				setToValues = true;
				setToDefault = false;
				if( isProbeUNCSetEnabled )
				{
					document.getElementById("UNCVal").disabled = false;
				}

				if( isProbeLNCSetEnabled )
				{
					document.getElementById("LNCVal").disabled = false;
				}
			}
			
			function setToDef()
			{
				setToDefault = true;
				setToValues = false;
				if( isProbeUNCSetEnabled )
				{
					document.getElementById("UNCVal").disabled = true;
				}

				if( isProbeLNCSetEnabled )
				{
					document.getElementById("LNCVal").disabled = true;
				}
			}

			function validate()
			{
				<xsl:choose>
					<xsl:when test="ProbeThresholds/UCThreshold &gt; 0 ">
						var UC 	= parseFloat("<xsl:value-of select="ProbeThresholds/UCThreshold"/>");
						var preUNC = <xsl:value-of select="ProbeThresholds/UNCThreshold"/>;
					</xsl:when>
					<xsl:otherwise>
						var UC 	= 0;
						var preUNC = <xsl:value-of select="ProbeThresholds/UNCThreshold"/>;
					</xsl:otherwise>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="ProbeThresholds/LCThreshold &gt; 0 ">
						var LC = parseFloat("<xsl:value-of select="ProbeThresholds/LCThreshold"/>");
						var preLNC = <xsl:value-of select="ProbeThresholds/LNCThreshold"/>;
					</xsl:when>
					<xsl:otherwise>
						var LC = 0;
						var preLNC = <xsl:value-of select="ProbeThresholds/LNCThreshold"/>;
					</xsl:otherwise>
				</xsl:choose>
				
				if(setToValues)
				{
					// user has changed the threshold settings.
					
					<xsl:if test="Capabilities/ProbeUNCSetEnabled = 'true' ">
						document.getElementById("UNCVal").disabled = false;
						var tempUNC = document.getElementById("UNCVal").value;
						
						if(isNaN(tempUNC) == true)
						{
							alert("Fehler! Zahl erwartetet f&#252;r den maximalen Warnungs-Schwellenwert, gelesen: " + tempUNC);
							document.getElementById("UNCVal").value = preUNC;
							document.getElementById("LNCVal").value = preLNC;
							return false;
						}
						
						if(isNaN(parseFloat(tempUNC)) == true)
						{
							alert("Fehler! Ganze Zahl erwartet f&#252;r den maximalen Warnungs-Schwellenwert, gelesen: " + tempUNC);
						document.getElementById("UNCVal").value = preUNC;
						document.getElementById("LNCVal").value = preLNC;
						return false;
					}
					else
					{
						if(tempUNC.indexOf(".") != "-1")
						{
							alert("Fehler! Ganze Zahl erwartet f&#252;r den maximalen Warnungs-Schwellenwert, gelesen: " + tempUNC);
								document.getElementById("UNCVal").value = preUNC;
								return false;
							}
						}
						
						var UNC 	= parseFloat(document.getElementById("UNCVal").value);
					</xsl:if>
					
					<xsl:if test="Capabilities/ProbeLNCSetEnabled = 'true' ">
						document.getElementById("LNCVal").disabled = false;
						var tempLNC 	= document.getElementById("LNCVal").value;
						
						if( isNaN(tempLNC) == true)
						{
							alert("Fehler! Zahl erwartet f&#252;r den minimalen Warnungs-Schwellenwert, gelesen: " + tempLNC);
							document.getElementById("UNCVal").value = preUNC;
							document.getElementById("LNCVal").value = preLNC;
							return false;
						}
						
						
						if( isNaN(parseFloat(tempLNC)) == true)
						{
							alert("Fehler! Ganze Zahl erwartet f&#252;r den minimalen Warnungs-Schwellenwert, gelesen: " + tempLNC);
						document.getElementById("UNCVal").value = preUNC;
						document.getElementById("LNCVal").value = preLNC;
						return false;
					}
					else
					{
						if(tempLNC.indexOf(".") != "-1")
						{
							alert("Fehler! Ganze Zahl erwartet f&#252;r den minimalen Warnungs-Schwellenwert, gelesen: " + tempLNC);
								document.getElementById("LNCVal").value = preLNC;
								return false;
							}
						}
						
						var LNC 	= parseFloat(document.getElementById("LNCVal").value);
					</xsl:if>
							
					if( isProbeUNCSetEnabled &amp;&amp; (! isProbeLNCSetEnabled) )
					{
						// only upper warning threshold is settable.

						if((UC &gt; 0) &amp;&amp; (LC &gt; 0))
						{
							if((UC &gt; UNC) &amp;&amp; (UNC &gt; LC))
							{
								return true;
							}
							else
							{
								alert("Fehler! Der Wert [" + UNC + "] liegt nicht zwischen dem Bereich " + LC + " U/min bis " + UC + " U/min f&#252;r den maximalen Warnungs-Schwellenwert" );
							}
						}
						else
						{
							// UC und LC stehen zur Best&#228;tigung des UNC-Wertes nicht zur Verf&#252;gung.
							return true;
						}
						
						document.getElementById("UNCVal").value = preUNC;
					}
					else if( (! isProbeUNCSetEnabled ) &amp;&amp; isProbeLNCSetEnabled )
					{
						// Nur der untere Warnungs-Schwellenwert kann eingestellt werden.
						
						if((UC &gt; 0) &amp;&amp; (LC &gt; 0))
						{
							if((UC &gt; LNC) &amp;&amp; (LNC &gt; LC))
							{
								return true;
							}
							else
							{
								alert("Fehler! Der Wert [" + LNC + "] liegt nicht im Berech " + LC + " U/min bis " + UC + " U/min f&#252;r den minimalen Warnungs-Schwellenwert" );
							}
						}
						else
						{
							// UC und LC stehen zur Best&#228;tigung des LNC-Wertes nicht zur Vef&#252;gung.
							return true;
						}
						
						document.getElementById("LNCVal").value = preLNC;
					}
					else
					{
						// Beide k&#246;nnen eingestellt werden
						
						if((UC &gt; 0) &amp;&amp; (LC &gt; 0))
						{
							if((UC &gt; UNC) &amp;&amp; (UNC &gt; LC))
							{
								if(UNC &gt; LNC)
								{
									if(LNC &gt; LC)
									{
										return true;
									}
									else
									{
										alert("Fehler! Der Wert [" + LNC + "] ist nicht im Bereich " + LC + " U/min bis " + UNC + " U/min f&#252;r den minimalen Warnungs-Schwellenwert" );
								}
							}
							else
							{
								alert("Fehler! Minimaler Warnungs-Schwellenwert darf nicht gr&#246;&#223;er als oder gleich dem maximalen Warnungs-Schwellenwert sein" );
							}
						}
						else
						{
							if((UC &gt; LNC) &amp;&amp; (LNC &gt; LC))
							{
								alert("Fehler! Der Wert [" + UNC + "] ist nicht im Bereich " + LNC + " U/min " + UC + " U/min f&#252;r den maximalen Warnungs-Schwellenwert" );
							}
							else
							{
								alert("Fehler! Der Wert [" + UNC + "] ist nicht im Bereich " + preLNC + " U/min bis " + UC + " U/min f&#252;r den minimalen Warnungs-Schwellenwert" );
							}
						}
					}
					else
					{
							<!-- UC and LC have invalid values. Accept the user values if they are positive-->						
							if( UNC &gt; 0)
						{
							if( LNC &gt; 0)
							{
								if(UNC &gt; LNC)
								{
									return true;
								}
								else
								{
									alert("Fehler! Minimaler Warnungs-Schwellenwert darf nicht gr&#246;&#223;er als oder gleich dem maximalen Warnungs-Schwellenwert sein" );
								}
							}
							else
							{
								alert("Fehler! Zahl ohne Vorzeichen erwartet f&#252;r den minimalen Warnungs-Schwellenwert, gelesen: " + LNC);
							}
						}
						else
						{
							alert("Fehler! Zahl ohne Vorzeichen erwartet f&#252;r den maximalen Warnungs-Schwellenwert, gelesen: " + UNC);
							}
						}

						document.getElementById("UNCVal").value = preUNC;
						document.getElementById("LNCVal").value = preLNC;
					}
				}
				else
				{
					// do not validate the values if user has selected default threshold settings.
					return true;
				}
				
				<!--  returning false doesn't submit the form -->
				return false;
			}
		</script>
	</xsl:template>
	<xsl:template match="ServletArguments">
		<xsl:attribute name="submit">/servlet/SubmitForm?plugin=com.dell.hip.webplugins.SetFanWebPlugin&amp;oid=<xsl:value-of select="@OID"/>&amp;poid=<xsl:value-of select="@POID"/>&amp;objtype=<xsl:value-of select="@PObjType"/>
</xsl:attribute>
		<xsl:attribute name="backpagetarget">/servlet/DataArea?plugin=com.dell.hip.webplugins.FanProbesWebPlugin&amp;poid=<xsl:value-of select="@POID"/>&amp;help=Fans</xsl:attribute>
		<CustomButton>
			<Data  name="" >
			<xsl:attribute name="display"><!--XLATESTART-->Aktualisieren<!--XLATESTOP--></xsl:attribute>
							<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.hip.webplugins.EditFanProbeWebPlugin&amp;oid=<xsl:value-of select="@OID"/>&amp;poid=<xsl:value-of select="@POID"/>&amp;help=EditFanProbe</xsl:attribute>
			</Data>
		</CustomButton>
	</xsl:template>
		<xsl:template name="StatusToStr">
		<xsl:param name="status"/>
		<xsl:choose>
			<xsl:when test="$status = 1">
				<xsl:attribute name="value">Unknown</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 2">
				<xsl:attribute name="value">OK</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 3">
				<xsl:attribute name="value">Non Critical</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 4">
				<xsl:attribute name="value">Critical</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 5">
				<xsl:attribute name="value">Non Recoverable</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:attribute name="value">Other</xsl:attribute>
			</xsl:otherwise>
		</xsl:choose>				
	</xsl:template>
	<xsl:template name="DataType">
		<xsl:param name="name"/>
		<xsl:param name="display"/>
		<xsl:param name="value"/>
		<xsl:param name="type"/>
		<xsl:param name="link"/>
		<xsl:param name="href"/>		
		<Data >
			<xsl:attribute name="name"><xsl:value-of select="$name"/></xsl:attribute>
			<xsl:attribute name="display"><xsl:value-of select="$display"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$value"/></xsl:attribute>
			<xsl:attribute name="link"><xsl:value-of select="$link"/></xsl:attribute>
			<xsl:attribute name="href"><xsl:value-of select="$href"/></xsl:attribute>
			<xsl:attribute name="type"><xsl:value-of select="$type"/></xsl:attribute>
		</Data>
	</xsl:template>
		<xsl:template name="smstatus">
		<xsl:param name="status"/>
		<xsl:param name="mssg"/>
		<xsl:choose>
			<xsl:when test="$status = '-1'"><!--XLATESTART-->Befehl nicht erfolgreich<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '0'"><!--XLATESTART-->Befehl erfolgreich<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '1'"><!--XLATESTART-->Befehl nicht implementiert<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '2'"><!--XLATESTART-->Inkorrekter Befehl<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '3'"><!--XLATESTART-->Befehl-Zeit&#252;berschreitung<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '4'"><!--XLATESTART-->Befehl storniert<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '5'"><!--XLATESTART-->Befehl abgebrochen<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '6'"><!--XLATESTART-->Befehl anstehend<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '7'"><!--XLATESTART-->Kein derartiges Ger&#228;t vorhanden<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '8'"><!--XLATESTART-->Ger&#228;t besetzt<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '9'"><!--XLATESTART-->Fehlerhaftes Ger&#228;t<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '10'"><!--XLATESTART-->Unechter Interrupt<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '11'"><!--XLATESTART-->Ressource gesperrt<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '12'"><!--XLATESTART-->Ung&#252;ltiger Index<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '13'"><!--XLATESTART-->SMB-Fehler<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '14'"><!--XLATESTART-->Angeforderte Daten sind nicht verf&#252;gbar<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '15'"><!--XLATESTART-->Angeforderte Daten &#252;bersteigen die verf&#252;gbaren Daten<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '16'"><!--XLATESTART-->Angeforderte Daten sind weniger als die verf&#252;gbaren Daten<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '17'"><!--XLATESTART-->Ger&#228;t noch nicht zum Befehlsempfang bereit. Sp&#228;ter versuchen<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '18'"><!--XLATESTART-->Ger&#228;t hat keine Daten<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '19'"><!--XLATESTART-->Ger&#228;t hat nicht gen&#252;gend Speicher<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '20'"><!--XLATESTART-->Ger&#228;t existiert bereits<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '256'"><!--XLATESTART-->L&#252;fter-Objekt nicht gefunden<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '257'"><!--XLATESTART-->L&#252;fter-Objekt verformt, besch&#228;digt oder fehlerhaft<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '258'"><!--XLATESTART-->L&#252;fter-Objekt existiert bereits<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '260'"><!--XLATESTART-->INI-Datei nicht gefunden<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '261'"><!--XLATESTART-->INI verformt, besch&#228;digt oder fehlerhaft<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '262'"><!--XLATESTART-->INI-Abschnitt existiert nicht<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '263'"><!--XLATESTART-->INI-Schl&#252;ssel existiert nicht<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '264'"><!--XLATESTART-->INI-Wert verformt, besch&#228;digt oder fehlerhaft<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '270'"><!--XLATESTART-->Ungen&#252;gende Zugriffsrechte<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '271'"><!--XLATESTART-->Ung&#252;ltiger Parametername oder -wert <!--XLATESTOP--><xsl:value-of select="$mssg"/></xsl:when>
			<xsl:when test="$status = '272'"><!--XLATESTART-->Nicht gen&#252;gend Speicher vorhanden<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '280'"><!--XLATESTART-->XML-Datei nicht gefunden<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '281'"><!--XLATESTART-->XML verformt, besch&#228;digt oder fehlerhaft<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '282'"><!--XLATESTART-->XML-Knoten existiert nicht<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '283'"><!--XLATESTART-->XML-Wert verformt, besch&#228;digt oder fehlerhaft<!--XLATESTOP--></xsl:when>
		<xsl:otherwise>SMStatus: <xsl:value-of select="$status"/></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="*"/>
</xsl:stylesheet>
