<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
<xsl:template match="OMA">
	<xsl:if test="(OMAUserRights = '7') or (OMAUserRights = '3')">
		<xsl:choose>
			<xsl:when test="(VoltageProbe/ProbeThresholds/LCThreshold != '-2147483648') and (VoltageProbe/ProbeThresholds/UCThreshold != '-2147483648') and (VoltageProbe/ProbeThresholds/LNCThreshold != '-2147483648') and (VoltageProbe/ProbeThresholds/UNCThreshold != '-2147483648') and (VoltageProbe/ProbeReading != '-2147483648')">
				<xsl:choose>
					<xsl:when test="SMStatus='0'"><xsl:apply-templates select="VoltageProbe"/></xsl:when>
					<xsl:otherwise><xsl:call-template name="failure"/></xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise><xsl:call-template name="invalid"/></xsl:otherwise>
		</xsl:choose>
	</xsl:if>
</xsl:template>

<xsl:template name="failure">
	<DataArea>
		<PageTitle>
			<xsl:attribute name="display"><!--XLATESTART-->Spannungssonden<!--XLATESTOP--></xsl:attribute>
		</PageTitle>
		<TableData>
			<Row>
				<Data name=""  display="">
					<xsl:attribute name="value">
						<xsl:call-template name="smstatus">
							<xsl:with-param name="status"><xsl:value-of select="SMStatus"/></xsl:with-param>
						</xsl:call-template>
					</xsl:attribute>
				</Data>
			</Row>
		</TableData>
	</DataArea>
</xsl:template>

<xsl:template name="invalid">
	<DataArea>
		<PageTitle>
			<xsl:attribute name="display"><!--XLATESTART-->Spannungssonden<!--XLATESTOP--></xsl:attribute>
		</PageTitle>
		<PromptText><!--XLATESTART-->Die Schwellenwerte oder der Messwert der Spannungssonde hat ung&#252;ltige Werte.<!--XLATESTOP--></PromptText>
	</DataArea>
</xsl:template>

<xsl:template match="VoltageProbe">
	<DataArea  backpagedisplay="Spannungssonden" validate="true"  onLoad="true">
		<xsl:attribute name="submit">/servlet/SubmitForm?plugin=com.dell.hip.webplugins.SetVoltageWebPlugin&amp;oid=<xsl:value-of select="@oid"/></xsl:attribute>
		<xsl:attribute name="backpagetarget">/servlet/DataArea?plugin=com.dell.hip.webplugins.ListVoltageWebPlugin&amp;poid=<xsl:value-of select="@poid"/>&amp;help=Voltages</xsl:attribute>
		<PageTitle>PageTitle</PageTitle>
		<Header>Header</Header>
		<SubHeader>
			<xsl:attribute name="display"><xsl:value-of select="ProbeLocation"/></xsl:attribute>
			<xsl:attribute name="status"><xsl:value-of select="@status"/></xsl:attribute>
		</SubHeader>
		<CustomButton>
			<Data name="Refresh">
			<xsl:attribute name="display"><!--XLATESTART-->Aktualisieren<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="href">
					/servlet/DataArea?plugin=com.dell.hip.webplugins.VoltageWebPlugin&amp;oid=<xsl:value-of select="@oid"/>&amp;poid=<xsl:value-of select="@poid"/>&amp;help=EditVoltageProbes
				</xsl:attribute>
			</Data>
		</CustomButton>
		<xsl:choose>
			<xsl:when test="(ProbeThresholds/LCThreshold != '-2147483648') and (ProbeThresholds/UCThreshold != '-2147483648') and (ProbeThresholds/LNCThreshold != '-2147483648') and (ProbeThresholds/UNCThreshold != '-2147483648') and (ProbeReading != '-2147483648')">
				<Guage digits="3">
					<xsl:attribute name="units"><!--XLATESTART-->Volt<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="showdecsep"><!--XLATESTART-->,<!--XLATESTOP--></xsl:attribute>
					<Reading>
						<xsl:call-template name="calVolt">
							<xsl:with-param name="volt"><xsl:value-of select="ProbeReading"/></xsl:with-param>
						</xsl:call-template>
					</Reading>
					<MFThresh>
						<xsl:call-template name="calVolt">
							<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LCThreshold"/></xsl:with-param>
						</xsl:call-template>
					</MFThresh>
					<MXFThresh>
						<xsl:call-template name="calVolt">
							<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param>
						</xsl:call-template>
					</MXFThresh>
					<MWThresh>
						<xsl:call-template name="calVolt">
							<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:with-param>
						</xsl:call-template>
					</MWThresh>
					<MXWThresh>
						<xsl:call-template name="calVolt">
							<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param>
						</xsl:call-template>
					</MXWThresh>
					<ListData>
						<Data display="Status" type="status-text">							<xsl:attribute name="value"><xsl:value-of select="@status"/></xsl:attribute>
						</Data>
						<Data display="Messwert" reading="true">
							<xsl:attribute name="value">
								<xsl:call-template name="showcalVolt">
									<xsl:with-param name="volt"><xsl:value-of select="ProbeReading"/></xsl:with-param>
								</xsl:call-template><!--XLATESTART-->Volt<!--XLATESTOP-->
							</xsl:attribute>
						</Data>
						<Data display="Minimaler Fehler-Schwellenwert">
							<xsl:attribute name="value">
								<xsl:call-template name="showcalVolt">
									<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LCThreshold"/></xsl:with-param>
								</xsl:call-template><!--XLATESTART-->Volt<!--XLATESTOP-->
							</xsl:attribute>
						</Data>
						<Data display="Maximaler Fehler-Schwellenwert">
							<xsl:attribute name="value">
								<xsl:call-template name="showcalVolt">
									<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param>
								</xsl:call-template><!--XLATESTART-->Volt<!--XLATESTOP-->
							</xsl:attribute>
						</Data>
						<xsl:choose>
							<xsl:when test="(Capabilities/ProbeUNCDefSetEnabled = 'true') or (Capabilities/ProbeLNCDefSetEnabled = 'true')">			
							<Data display="Schwellenwert-Einstellungen" type="radio"  state="1">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
						<xsl:attribute name="value">Set to Default</xsl:attribute>
							</Data>						
							<Data type="radio">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">Set to Values</xsl:attribute>
							</Data>
							</xsl:when>
							<xsl:otherwise>
							<Data display="Schwellenwert-Einstellungen" type="radio"  state="1">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">Set to Values</xsl:attribute>
							</Data>												
							</xsl:otherwise>
						</xsl:choose>
						<Data display="Minimaler Warnungs-Schwellenwert" type="editbox">
							<xsl:attribute name="textboxname">LNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue">
								<xsl:call-template name="showcalVolt">
									<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:with-param>
								</xsl:call-template>
							</xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART--> Volt<!--XLATESTOP--></xsl:attribute>
						</Data>
						<Data display="Maximaler Warnungs-Schwellenwert" type="editbox">
							<xsl:attribute name="textboxname">UNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue">
								<xsl:call-template name="showcalVolt">
									<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param>
								</xsl:call-template>
							</xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART--> Volt<!--XLATESTOP--></xsl:attribute>
						</Data>
					</ListData>
				</Guage>
			</xsl:when>
			<xsl:otherwise>
				<ListData>
					<Data name="plugin" type="hidden">
						<xsl:attribute name="returnvalue">com.dell.hip.webplugins.SetVoltageWebPlugin</xsl:attribute>
					</Data>
					<Data name="oid" type="hidden">
						<xsl:attribute name="returnvalue"><xsl:value-of select="@oid"/></xsl:attribute>
					</Data>
					<xsl:element name="Data">
						<xsl:attribute name="name">Status</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="@status"/></xsl:attribute>
						<xsl:attribute name="display"><!--XLATESTART-->Status<!--XLATESTOP--></xsl:attribute>
						<xsl:attribute name="type">status-text</xsl:attribute>
					</xsl:element>
					<xsl:element name="Data">
						<xsl:attribute name="value">
							<xsl:call-template name="showcalVolt">
								<xsl:with-param name="volt"><xsl:value-of select="ProbeReading"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:attribute name="display"><!--XLATESTART-->Messwert<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="type">ustring</xsl:attribute>
						<xsl:attribute name="unit"><!--XLATESTART--> Volt<!--XLATESTOP--></xsl:attribute>
					</xsl:element>
					<xsl:element name="Data">
						<xsl:attribute name="value">
							<xsl:call-template name="showcalVolt">
								<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LCThreshold"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:attribute name="display"><!--XLATESTART-->Minimaler Fehlerschwellenwert<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="type">ustring</xsl:attribute>
						<xsl:attribute name="unit"> <!--XLATESTART-->Volt<!--XLATESTOP--></xsl:attribute>
					</xsl:element>
					<xsl:element name="Data">
						<xsl:attribute name="value">
							<xsl:call-template name="showcalVolt">
								<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:attribute name="display"><!--XLATESTART-->Maximaler Fehlerschwellenwert<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="type">ustring</xsl:attribute>
						<xsl:attribute name="unit"><!--XLATESTART--> Volt<!--XLATESTOP--></xsl:attribute>
					</xsl:element>
					<Data display="Schwellenwert-Einstellungen" type="radio"  state="1">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
						<xsl:attribute name="value">Set to Default</xsl:attribute>
					</Data>
					<Data type="radio">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">Set to Values</xsl:attribute>
					</Data>
					<Data display="Minimaler Warnungs-Schwellenwert" type="editbox" size="6">						<xsl:attribute name="name">LNCVal</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:call-template name="showcalVolt">
								<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:attribute name="unit"><!--XLATESTART--> Volt<!--XLATESTOP--></xsl:attribute>
					</Data>
					<Data display="Maximaler Warnungs-Schwellenwert" type="editbox" size="6">						<xsl:attribute name="name">UNCVal</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:call-template name="showcalVolt">
								<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:attribute name="unit"><!--XLATESTART--> Volt<!--XLATESTOP--></xsl:attribute>
					</Data>
				</ListData>
			</xsl:otherwise>
		</xsl:choose>
		
		<script language="javascript" src="/oma/js/Probe.js" />
		
		<script language="javascript">
		
			var setToDefault	= true;
			var setToValues	= false;
			var UC;
			var LC;
			var preUNC;
			var preLNC;
			var UCTxt;
			var LCTxt;
			var preUNCTxt;
			var preLNCTxt;
			var toggleunivDecsep = <!--XLATESTART-->","<!--XLATESTOP-->; //In German ,French and Spanish, change it to ",". In en, it should be ".".
			var togglelocalDecsep = <!--XLATESTART-->"."<!--XLATESTOP-->;//In German ,French and Spanish, change it to ".".In en, it should be ",".
			var univDecsep = "."; // don't translate.
			var unit =  <!--XLATESTART-->"Volt"<!--XLATESTOP-->;
			var multiplier = 1000;
			var lengthval = 4;
			var msg1 = <!--XLATESTART-->"Fehler! Zahl mit bis zu 3 Stellen nach dem Dezimalkomma erwartet, gelesen: "<!--XLATESTOP-->;
			var msg2 = <!--XLATESTART-->"Fehler! Der Wert ["<!--XLATESTOP-->;
			var msg3 = <!--XLATESTART-->"] liegt nicht im Bereich zwischen "<!--XLATESTOP-->;
			var msg4 = <!--XLATESTART-->"  und "<!--XLATESTOP-->;
			var msg5 = <!--XLATESTART-->"  f&#252;r den minimalen Warnungsschwellenwert."<!--XLATESTOP-->;
			var msg6 = <!--XLATESTART-->"  f&#252;r den maximalen Warnungsschwellenwert."<!--XLATESTOP-->;
			var msg7 = <!--XLATESTART-->"Fehler! Minimaler Warnungsschwellenwert darf nicht gr&#246;&#223;er als oder gleich dem maximalen Warnungsschwellenwert sein."<!--XLATESTOP-->;
			
			function initializationRoutine()
			{
				document.getElementById("UNCVal").value = '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of 	select="ProbeThresholds/UNCThreshold"/></xsl:with-param></xsl:call-template>';
				document.getElementById("LNCVal").value = '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of 	select="ProbeThresholds/LNCThreshold"/></xsl:with-param></xsl:call-template>';
				
				document.getElementById("UNCVal").disabled = true;
				document.getElementById("LNCVal").disabled = true;
				document.getElementById("threshsetting").checked = true;
				assignVal();
				<xsl:if test="(Capabilities/ProbeUNCDefSetEnabled != 'true') and (Capabilities/ProbeLNCDefSetEnabled != 'true')">	
				 	setToVal();
				</xsl:if>
			}
			
			function assignVal(){
					var UCloc 			= parseFloat("<xsl:call-template name="calVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param></xsl:call-template>");
					var LCloc 			= parseFloat("<xsl:call-template name="calVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LCThreshold"/></xsl:with-param></xsl:call-template>");
					var preUNCloc 		= parseFloat("<xsl:call-template name="calVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param></xsl:call-template>");
					var preLNCloc 		= parseFloat("<xsl:call-template name="calVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:with-param></xsl:call-template>");
			
					var UCTxtloc		= '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param></xsl:call-template>';
					var LCTxtloc		= '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LCThreshold"/></xsl:with-param></xsl:call-template>';
		
					var preUNCTxtloc		= '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param></xsl:call-template>';
					var preLNCTxtloc 		= '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:with-param></xsl:call-template>';

					UC = UCloc;
					LC = LCloc;
					preUNC = preUNCloc;
					preLNC = preLNCloc;
					UCTxt = trim(UCTxtloc);
					LCTxt = trim(LCTxtloc);
					preUNCTxt = trim(preUNCTxtloc);
					preLNCTxt = trim(preLNCTxtloc);
			}
		</script>
		
	</DataArea>
</xsl:template>

<xsl:template name="showcalVolt">
	<xsl:param name="volt"/>
		<xsl:variable name="formatval"><xsl:value-of select="format-number($volt div 1000,'##0.000')"/></xsl:variable>
		<xsl:variable name="univdecsep">
			<xsl:choose>
				<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = '.'">.</xsl:when>
				<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = ','">,</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="localdecsep"><!--XLATESTART-->,<!--XLATESTOP--></xsl:variable>
		<xsl:value-of select="translate($formatval,$univdecsep,$localdecsep)"/>	
</xsl:template>

<xsl:template name="calVolt">
	<xsl:param name="volt"/>
		<xsl:variable name="formatval"><xsl:value-of select="format-number($volt div 1000,'##0.000')"/></xsl:variable>
		<xsl:variable name="univdecsep">
			<xsl:choose>
				<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = '.'">.</xsl:when>
				<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = ','">,</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="localdecsep">.</xsl:variable>
		<xsl:value-of select="translate($formatval,$univdecsep,$localdecsep)"/>	
</xsl:template>

<xsl:template name="smstatus">
	<xsl:param name="status"/>
	<xsl:choose>
		<xsl:when test="$status = '-1'"><!--XLATESTART-->Befehl nicht erfolgreich<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '1'"><!--XLATESTART-->Befehl nicht implementiert<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '2'"><!--XLATESTART-->Inkorrekter Befehl<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '3'"><!--XLATESTART-->Befehls-Zeit&#252;berschreitung<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '4'"><!--XLATESTART-->Befehl storniert<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '5'"><!--XLATESTART-->Befehl abgebrochen<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '6'"><!--XLATESTART-->Befehl anstehend<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '7'"><!--XLATESTART-->Kein derartiges Ger&#228;t vorhanden<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '8'"><!--XLATESTART-->Ger&#228;t besetzt<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '9'"><!--XLATESTART-->Fehlerhaftes Ger&#228;t<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '10'"><!--XLATESTART-->Unechter Interrupt<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '11'"><!--XLATESTART-->Ressource gesperrt<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '12'"><!--XLATESTART-->Ung&#252;ltiger Index<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '13'"><!--XLATESTART-->SMB-Fehler<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '14'"><!--XLATESTART-->Angeforderte Daten sind nicht verf&#252;gbar<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '15'"><!--XLATESTART-->Angeforderte Daten &#252;bersteigen die verf&#252;gbaren Daten<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '16'"><!--XLATESTART-->Angeforderte Daten sind weniger als die verf&#252;gbaren Daten<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '17'"><!--XLATESTART-->Ger&#228;t noch nicht zum Befehlsempfang bereit. Sp&#228;ter versuchen<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '18'"><!--XLATESTART-->Ger&#228;t hat keine Daten<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '19'"><!--XLATESTART-->Ger&#228;t hat nicht gen&#252;gend Speicher<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '20'"><!--XLATESTART-->Ger&#228;t existiert bereits<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '256'"><!--XLATESTART-->Spannungssonde nicht gefunden<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '257'"><!--XLATESTART-->Objekt verformt, besch&#228;digt oder fehlerhaft<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '258'"><!--XLATESTART-->Objekt existiert bereits<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '260'"><!--XLATESTART-->INI-Datei nicht gefunden<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '261'"><!--XLATESTART-->INI verformt, besch&#228;digt oder fehlerhaft<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '262'"><!--XLATESTART-->INI-Abschnitt existiert nicht<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '263'"><!--XLATESTART-->INI-Schl&#252;ssel existiert nicht<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '264'"><!--XLATESTART-->INI-Wert verformt, besch&#228;digt oder fehlerhaft<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '270'"><!--XLATESTART-->Ungen&#252;gende Zugriffsrechte<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '271'"><!--XLATESTART-->Ung&#252;ltiger Parametername oder -wert <!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '272'"><!--XLATESTART-->Nicht gen&#252;gend Speicher vorhanden<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '280'"><!--XLATESTART-->XML-Datei nicht gefunden<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '281'"><!--XLATESTART-->XML verformt, besch&#228;digt oder fehlerhaft<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '282'"><!--XLATESTART-->XML-Knoten existiert nicht<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '283'"><!--XLATESTART-->XML-Wert verformt, besch&#228;digt oder fehlerhaft<!--XLATESTOP--></xsl:when>
			<xsl:otherwise>SMStatus: <xsl:value-of select="$status"/></xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="*">
</xsl:template>
</xsl:stylesheet>
