<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" />
	<xsl:strip-space elements="*"/>
	<xsl:template match="OMA">
		<xsl:choose>
			<xsl:when test="SMStatus != '0'">
				<DataArea printable="false">
					<PageTitle>
						<xsl:attribute name="display">
							<xsl:call-template name="smstatus">
								<xsl:with-param name="status"><xsl:value-of select="SMStatus"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
					</PageTitle>
				</DataArea>
			</xsl:when>
			<xsl:otherwise>
				<DataArea validate="true" onLoad="true">
				<xsl:attribute name="backpagedisplay"><!--XLATESTART-->Sondas de ventilador<!--XLATESTOP--></xsl:attribute>
					<xsl:apply-templates select="ServletArguments"/>
					<xsl:apply-templates select="FanProbe"/>
				</DataArea>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="FanProbe">
		<PageTitle></PageTitle>
		<SubHeader >
			<xsl:attribute name="display"><xsl:value-of select="ProbeLocation"/></xsl:attribute>
			<xsl:attribute name="status"><xsl:value-of select="@status"/></xsl:attribute>
		</SubHeader>
		<xsl:choose>
			<xsl:when test="(ProbeThresholds/LCThreshold &gt; 0) and (ProbeThresholds/UCThreshold &gt; 0) and (ProbeThresholds/LNCThreshold &gt; 0) and (ProbeThresholds/UNCThreshold &gt; 0) and (ProbeReading &gt;= 0)">
				<Guage  digits="0">
				<xsl:attribute name="units"> <!--XLATESTART-->RPM<!--XLATESTOP--></xsl:attribute>
					<Reading><xsl:value-of select="ProbeReading"/></Reading>
					<MFThresh><xsl:value-of select="ProbeThresholds/LCThreshold"/></MFThresh>
					<MXFThresh><xsl:value-of select="ProbeThresholds/UCThreshold"/></MXFThresh>
					<MWThresh><xsl:value-of select="ProbeThresholds/LNCThreshold"/></MWThresh>
					<MXWThresh><xsl:value-of select="ProbeThresholds/UNCThreshold"/></MXWThresh>
					<ListData>
						<Data display="Estado">
							<xsl:call-template name="StatusToStr">
								<xsl:with-param name="status"><xsl:value-of select="@status"/></xsl:with-param>
							</xsl:call-template>
						</Data>
						<Data display="Lectura" reading="true">
							<xsl:attribute name="value"><xsl:value-of select="ProbeReading"/> <!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
						</Data>
						<Data display="Umbral de falla m&#237;nimo">
							<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/LCThreshold"/><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
						</Data>
						<Data display="Umbral de falla m&#225;ximo">
							<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/UCThreshold"/><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
						</Data>
						<xsl:choose>
						<xsl:when test="(Capabilities/ProbeUNCDefSetEnabled = 'true') or (Capabilities/ProbeLNCDefSetEnabled = 'true')">
						<Data display="Valores de umbral" type="radio"  state="1">
							<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
							<xsl:attribute name="value">Establecer como predeterminado</xsl:attribute>
						</Data>
							<xsl:if test="(Capabilities/ProbeUNCSetEnabled = 'true') or (Capabilities/ProbeLNCSetEnabled = 'true')">
							<Data type="radio">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
							<xsl:attribute name="value">Establecer en valores</xsl:attribute>
							</Data>
							</xsl:if>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="(Capabilities/ProbeUNCSetEnabled = 'true') or (Capabilities/ProbeLNCSetEnabled = 'true')">
							<Data display="Valores de umbral" type="radio"  state="1">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
							<xsl:attribute name="value">Establecer en valores</xsl:attribute>
							</Data>
							</xsl:if>
						</xsl:otherwise>
						</xsl:choose>
						<xsl:if test="(Capabilities/ProbeLNCSetEnabled = 'true')">
						<Data display="Umbral de advertencia m&#237;nimo" type="editbox">
							<xsl:attribute name="textboxname">LNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
						</Data>
						</xsl:if>
						<xsl:if test="(Capabilities/ProbeUNCSetEnabled = 'true')">
						<Data display="Umbral de advertencia m&#225;ximo" type="editbox">
							<xsl:attribute name="textboxname">UNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
						</Data>
						</xsl:if>
					</ListData>
				</Guage>
			</xsl:when>
			<xsl:otherwise>
				<ListData>
					<Data display="Estado">
						<xsl:call-template name="StatusToStr">
							<xsl:with-param name="status"><xsl:value-of select="@status"/></xsl:with-param>
						</xsl:call-template>
					</Data>
					<Data display="Lectura">
						<xsl:attribute name="value"><xsl:value-of select="ProbeReading"/><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
					</Data>
					<Data display="Umbral de falla m&#237;nimo">
						<xsl:choose>
							<xsl:when test="ProbeThresholds/LCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/LCThreshold"/><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value"><!--XLATESTART-->Desconocido<!--XLATESTOP--></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</Data>			
					<Data display="Umbral de falla m&#225;ximo">
						<xsl:choose>
							<xsl:when test="ProbeThresholds/UCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/UCThreshold"/><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value"><!--XLATESTART-->Desconocido<!--XLATESTOP--></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</Data>
					<Data display="Valores de umbral" type="radio"  state="1">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
						<xsl:attribute name="value">Establecer como predeterminado</xsl:attribute>
					</Data>
					<Data type="radio">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
							<xsl:attribute name="value">Establecer en valores</xsl:attribute>
					</Data>
					<Data display="Umbral de advertencia m&#237;nimo" type="editbox" size="5">
						<xsl:attribute name="name">LNCVal</xsl:attribute>
						<xsl:choose>
							<xsl:when test="ProbeThresholds/LNCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value">0</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:attribute name="unit"><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
					</Data>
					<Data display="Umbral de advertencia m&#225;ximo" type="editbox" size="5">
						<xsl:attribute name="name">UNCVal</xsl:attribute>
						<xsl:choose>
							<xsl:when test="ProbeThresholds/UNCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value">0</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:attribute name="unit"><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
					</Data>
				</ListData>
			</xsl:otherwise>
		</xsl:choose>
		<script language="javascript">
			isProbeUNCSetEnabled 		= <xsl:value-of select="Capabilities/ProbeUNCSetEnabled"/>;
			isProbeLNCSetEnabled 		= <xsl:value-of select="Capabilities/ProbeLNCSetEnabled"/>;
			isProbeUNCDefSetEnabled 	= <xsl:value-of select="Capabilities/ProbeUNCDefSetEnabled"/>;
			isProbeLNCDefSetEnabled 	= <xsl:value-of select="Capabilities/ProbeLNCDefSetEnabled"/>;
		
			setToDefault	= true;
			setToValues	= false;

if( (( ! isProbeUNCDefSetEnabled )  &amp;&amp; (! isProbeLNCDefSetEnabled)) &amp;&amp; ( isProbeUNCSetEnabled || isProbeLNCSetEnabled ) )
{
	setToValues	= true;
}

			function initializationRoutine()
			{
				if( isProbeUNCSetEnabled )
				{
					document.getElementById("UNCVal").value = <xsl:value-of select="ProbeThresholds/UNCThreshold"/>;
					document.getElementById("UNCVal").disabled = false;
					if ( ( isProbeUNCDefSetEnabled || isProbeLNCDefSetEnabled ) &amp;&amp; setToDefault )
					{
						document.getElementById("UNCVal").disabled = true;
					}
				}

				if( isProbeLNCSetEnabled )
				{
					document.getElementById("LNCVal").value = <xsl:value-of select="ProbeThresholds/LNCThreshold"/>;
					document.getElementById("LNCVal").disabled = false;
					if ( ( isProbeUNCDefSetEnabled || isProbeLNCDefSetEnabled ) &amp;&amp; setToDefault )
					{
						document.getElementById("LNCVal").disabled = true;
					}
				}
				
				if( isProbeUNCDefSetEnabled || isProbeLNCDefSetEnabled )
				{
					document.getElementById("threshsetting").checked = true;
				}
			}
			
			function setToVal()
			{
				setToValues = true;
				setToDefault = false;
				if( isProbeUNCSetEnabled )
				{
					document.getElementById("UNCVal").disabled = false;
				}

				if( isProbeLNCSetEnabled )
				{
					document.getElementById("LNCVal").disabled = false;
				}
			}
			
			function setToDef()
			{
				setToDefault = true;
				setToValues = false;
				if( isProbeUNCSetEnabled )
				{
					document.getElementById("UNCVal").disabled = true;
				}

				if( isProbeLNCSetEnabled )
				{
					document.getElementById("LNCVal").disabled = true;
				}
			}

			function validate()
			{
				<xsl:choose>
					<xsl:when test="ProbeThresholds/UCThreshold &gt; 0 ">
						var UC 	= parseFloat("<xsl:value-of select="ProbeThresholds/UCThreshold"/>");
						var preUNC = <xsl:value-of select="ProbeThresholds/UNCThreshold"/>;
					</xsl:when>
					<xsl:otherwise>
						var UC 	= 0;
						var preUNC = <xsl:value-of select="ProbeThresholds/UNCThreshold"/>;
					</xsl:otherwise>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="ProbeThresholds/LCThreshold &gt; 0 ">
						var LC = parseFloat("<xsl:value-of select="ProbeThresholds/LCThreshold"/>");
						var preLNC = <xsl:value-of select="ProbeThresholds/LNCThreshold"/>;
					</xsl:when>
					<xsl:otherwise>
						var LC = 0;
						var preLNC = <xsl:value-of select="ProbeThresholds/LNCThreshold"/>;
					</xsl:otherwise>
				</xsl:choose>
				
				if(setToValues)
				{
					// user has changed the threshold settings.
					
					<xsl:if test="Capabilities/ProbeUNCSetEnabled = 'true' ">
						document.getElementById("UNCVal").disabled = false;
						var tempUNC = document.getElementById("UNCVal").value;
						
						if(isNaN(tempUNC) == true)
						{
							alert("Error: se esperaba un n&#250;mero para el umbral de advertencia m&#225;ximo, se ha le&#237;do: " + tempUNC);
							document.getElementById("UNCVal").value = preUNC;
							document.getElementById("LNCVal").value = preLNC;
							return false;
						}
						
						if(isNaN(parseFloat(tempUNC)) == true)
						{
							alert("Error: se esperaba un n&#250;mero completo para el umbral de advertencia m&#225;ximo, se ha le&#237;do: " + tempUNC);
						document.getElementById("UNCVal").value = preUNC;
						document.getElementById("LNCVal").value = preLNC;
						return false;
					}
					else
					{
						if(tempUNC.indexOf(".") != "-1")
														{
															alert("Error: se esperaba un n&#250;mero completo para el umbral de advertencia m&#225;ximo, se ha le&#237;do: " + tempUNC);
								document.getElementById("UNCVal").value = preUNC;
								return false;
							}
						}
						
						var UNC 	= parseFloat(document.getElementById("UNCVal").value);
					</xsl:if>
					
					<xsl:if test="Capabilities/ProbeLNCSetEnabled = 'true' ">
						document.getElementById("LNCVal").disabled = false;
						var tempLNC 	= document.getElementById("LNCVal").value;
						
						if( isNaN(tempLNC) == true)
						{
							alert("Error: se esperaba un n&#250;mero para el umbral de advertencia m&#237;nimo, se ha le&#237;do: " + tempLNC);
							document.getElementById("UNCVal").value = preUNC;
							document.getElementById("LNCVal").value = preLNC;
							return false;
						}
						
						
						if( isNaN(parseFloat(tempLNC)) == true)
						{
							alert("Error: se esperaba un n&#250;mero completo para el umbral de advertencia m&#237;nimo, se ha le&#237;do: " + tempLNC);
						document.getElementById("UNCVal").value = preUNC;
						document.getElementById("LNCVal").value = preLNC;
						return false;
					}
					else
					{
						if(tempLNC.indexOf(".") != "-1")
														{
															alert("Error: se esperaba un n&#250;mero completo para el umbral de advertencia m&#237;nimo, se ha le&#237;do: " + tempLNC);
								document.getElementById("LNCVal").value = preLNC;
								return false;
							}
						}
						
						var LNC 	= parseFloat(document.getElementById("LNCVal").value);
					</xsl:if>
							
					if( isProbeUNCSetEnabled &amp;&amp; (! isProbeLNCSetEnabled) )
					{
						// only upper warning threshold is settable.

						if((UC &gt; 0) &amp;&amp; (LC &gt; 0))
						{
							if((UC &gt; UNC) &amp;&amp; (UNC &gt; LC))
							{
								return true;
							}
							else
							{
								alert("Error: el valor [" + UNC + "] no se encuentra en el intervalo entre " + LC + " RPM y " + UC + " RPM para el umbral de advertencia m&#225;ximo" );
							}
						}
						else
						{
							// UC and LC are not available to do validation of UNC value.
							return true;
						}
						
						document.getElementById("UNCVal").value = preUNC;
					}
					else if( (! isProbeUNCSetEnabled ) &amp;&amp; isProbeLNCSetEnabled )
					{
						// only lower warning threshold is settable.
						
						if((UC &gt; 0) &amp;&amp; (LC &gt; 0))
						{
							if((UC &gt; LNC) &amp;&amp; (LNC &gt; LC))
							{
								return true;
							}
							else
							{
								alert("Error! el valor [" + LNC + "] no se encuentra en el intervalo entre " + LC + " RPM y " + UC + " RPM para el umbral de advertencia m&#237;nimo" );
							}
						}
						else
						{
							// UC and LC are not available to do validation of LNC value.
							return true;
						}
						
						document.getElementById("LNCVal").value = preLNC;
					}
					else
					{
						// both are settable
						
						if((UC &gt; 0) &amp;&amp; (LC &gt; 0))
						{
							if((UC &gt; UNC) &amp;&amp; (UNC &gt; LC))
							{
								if(UNC &gt; LNC)
								{
									if(LNC &gt; LC)
									{
										return true;
									}
									else
									{
										alert("Error: el valor [" + LNC + "] no se encuentra en el intervalo entre " + LC + " y " + UNC + " RPM para el umbral de advertencia m&#237;nimo" );
								}
							}
							else
							{
								alert("Error: el valor de umbral de advertencia m&#237;nimo no puede ser igual o superior al valor de umbral de advertencia m&#225;ximo" );
						}
					}
					else
					{
						if((UC &gt; LNC) &amp;&amp; (LNC &gt; LC))
						{
							alert("Error: el valor [" + UNC + "] no se encuentra en el intervalo entre " + LNC + " y " + UC + " RPM para el umbral de advertencia m&#225;ximo" );
							}
							else
							{
								alert("Error: el valor [" + UNC + "] no se encuentra en el intervalo entre " + preLNC + " y " + UC + " RPM para el umbral de advertencia m&#225;ximo" );
							}
						}
					}
					else
					{
							<!-- UC and LC have invalid values. Accept the user values if they are positive-->						
							if( UNC &gt; 0)
						{
							if( LNC &gt; 0)
							{
								if(UNC &gt; LNC)
								{
									return true;
								}
								else
								{
									alert("Error: el valor de umbral de advertencia m&#237;nimo no puede ser igual o superior al valor de umbral de advertencia m&#225;ximo" );
								}
							}
							else
							{
								alert("Error: se esperaba un n&#250;mero sin signo para el umbral de advertencia m&#237;nimo, se ha le&#237;do: " + LNC);
							}
						}
						else
						{
							alert("Error: se esperaba un n&#250;mero sin signo para el umbral de advertencia m&#225;ximo, se ha le&#237;do: " + UNC);
							}
						}

						document.getElementById("UNCVal").value = preUNC;
						document.getElementById("LNCVal").value = preLNC;
					}
				}
				else
				{
					// do not validate the values if user has selected default threshold settings.
					return true;
				}
				
				<!--  returning false doesn't submit the form -->
				return false;
			}
		</script>
	</xsl:template>
	<xsl:template match="ServletArguments">
		<xsl:attribute name="submit">/servlet/SubmitForm?plugin=com.dell.hip.webplugins.SetFanWebPlugin&amp;oid=<xsl:value-of select="@OID"/>&amp;poid=<xsl:value-of select="@POID"/>&amp;objtype=<xsl:value-of select="@PObjType"/>
</xsl:attribute>
		<xsl:attribute name="backpagetarget">/servlet/DataArea?plugin=com.dell.hip.webplugins.FanProbesWebPlugin&amp;poid=<xsl:value-of select="@POID"/>&amp;help=Fans</xsl:attribute>
		<CustomButton>
			<Data  name="" >
			<xsl:attribute name="display"><!--XLATESTART-->Actualizar<!--XLATESTOP--></xsl:attribute>
							<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.hip.webplugins.EditFanProbeWebPlugin&amp;oid=<xsl:value-of select="@OID"/>&amp;poid=<xsl:value-of select="@POID"/>&amp;help=EditFanProbe</xsl:attribute>
			</Data>
		</CustomButton>
	</xsl:template>
		<xsl:template name="StatusToStr">
		<xsl:param name="status"/>
		<xsl:choose>
			<xsl:when test="$status = 1">
				<xsl:attribute name="value">Unknown</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 2">
				<xsl:attribute name="value">OK</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 3">
				<xsl:attribute name="value">Non Critical</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 4">
				<xsl:attribute name="value">Critical</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 5">
				<xsl:attribute name="value">Non Recoverable</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:attribute name="value">Other</xsl:attribute>
			</xsl:otherwise>
		</xsl:choose>				
	</xsl:template>
	<xsl:template name="DataType">
		<xsl:param name="name"/>
		<xsl:param name="display"/>
		<xsl:param name="value"/>
		<xsl:param name="type"/>
		<xsl:param name="link"/>
		<xsl:param name="href"/>		
		<Data >
			<xsl:attribute name="name"><xsl:value-of select="$name"/></xsl:attribute>
			<xsl:attribute name="display"><xsl:value-of select="$display"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$value"/></xsl:attribute>
			<xsl:attribute name="link"><xsl:value-of select="$link"/></xsl:attribute>
			<xsl:attribute name="href"><xsl:value-of select="$href"/></xsl:attribute>
			<xsl:attribute name="type"><xsl:value-of select="$type"/></xsl:attribute>
		</Data>
	</xsl:template>
		<xsl:template name="smstatus">
		<xsl:param name="status"/>
		<xsl:param name="mssg"/>
		<xsl:choose>
			<xsl:when test="$status = '-1'"><!--XLATESTART-->Comando no satisfactorio<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '0'"><!--XLATESTART-->Comando satisfactorio<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '1'"><!--XLATESTART-->Comando no implementado<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '2'"><!--XLATESTART-->Comando err&#243;neo<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '3'"><!--XLATESTART-->Tiempo de espera de comando<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '4'"><!--XLATESTART-->Comando cancelado<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '5'"><!--XLATESTART-->Comando anulado<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '6'"><!--XLATESTART-->Comando pendiente<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '7'"><!--XLATESTART-->No existe ese dispositivo<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '8'"><!--XLATESTART-->Dispositivo ocupado<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '9'"><!--XLATESTART-->Dispositivo err&#243;neo<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '10'"><!--XLATESTART-->Interrupci&#243;n falsa<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '11'"><!--XLATESTART-->Recurso bloqueado<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '12'"><!--XLATESTART-->&#205;ndice no v&#225;lido<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '13'"><!--XLATESTART-->Error SMB<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '14'"><!--XLATESTART-->Los datos solicitados no est&#225;n disponibles<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '15'"><!--XLATESTART-->Los datos solicitados son m&#225;s que los disponibles<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '16'"><!--XLATESTART-->Los datos solicitados son menos que los disponibles<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '17'"><!--XLATESTART-->El dispositivo no est&#225; listo para aceptar comandos. Int&#233;ntelo m&#225;s tarde<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '18'"><!--XLATESTART-->El dispositivo no tiene datos<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '19'"><!--XLATESTART-->El dispositivo se ha quedado sin memoria<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '20'"><!--XLATESTART-->El dispositivo ya existe<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '256'"><!--XLATESTART-->No se encuentra el objeto de ventilador<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '257'"><!--XLATESTART-->Objeto de ventilador mal formado, da&#241;ado o err&#243;neo<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '258'"><!--XLATESTART-->El objeto de ventilador ya existe<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '260'"><!--XLATESTART-->No se encuentra el archivo INI<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '261'"><!--XLATESTART-->INI mal formado, da&#241;ado o err&#243;neo<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '262'"><!--XLATESTART-->La secci&#243;n de INI no existe<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '263'"><!--XLATESTART-->La clave de INI no existe<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '264'"><!--XLATESTART-->Valor de INI mal formado, da&#241;ado o err&#243;neo<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '270'"><!--XLATESTART-->Derechos de acceso insuficientes<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '271'"><!--XLATESTART-->Valor o nombre de par&#225;metro no v&#225;lido: <!--XLATESTOP--><xsl:value-of select="$mssg"/></xsl:when>
			<xsl:when test="$status = '272'"><!--XLATESTART-->Sin memoria<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '280'"><!--XLATESTART-->No se encuentra el archivo XML<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '281'"><!--XLATESTART-->XML mal formado, da&#241;ado o err&#243;neo<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '282'"><!--XLATESTART-->El nodo de XML no existe<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '283'"><!--XLATESTART-->Valor de XML mal formado, da&#241;ado o err&#243;neo<!--XLATESTOP--></xsl:when>
		<xsl:otherwise>SMStatus: <xsl:value-of select="$status"/></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="*"/>
</xsl:stylesheet>
