<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="xml" omit-xml-declaration="yes"/>
	<xsl:strip-space elements="*"/>
	<xsl:template match="/OMA">
		<Summary>
			<xsl:apply-templates/>
		</Summary>
	</xsl:template>

	<xsl:template match="System">
		<Section name="System">
			<xsl:attribute name="display"><!--XLATESTART-->Sistema<!--XLATESTOP--></xsl:attribute>
			<ListData name="system">
				<xsl:attribute name="display"><!--XLATESTART-->Sistema<!--XLATESTOP--></xsl:attribute>
				<Data name="HostName">
					<xsl:attribute name="display"><!--XLATESTART-->Nombre de host<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="HostName"/></xsl:attribute>
				</Data>
				<Data name="SystemLocation">
					<xsl:attribute name="display"><!--XLATESTART-->Ubicaci&#243;n del sistema<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="SystemInfo/SystemLocation"/></xsl:attribute>
				</Data>
			</ListData>
		</Section>
	</xsl:template>
	<xsl:template match="ChassisList">
			<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="Chassis">
		<Section>
			<xsl:attribute name="name">chassis_<xsl:value-of select="@index" /></xsl:attribute>
			<xsl:attribute name="display">
				<xsl:choose>
					<xsl:when test="@display = 'Main System Chassis'"><!--XLATESTART-->Chasis del sistema principal<!--XLATESTOP--></xsl:when>
					<xsl:otherwise><xsl:value-of select="@display" /></xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:apply-templates select="ChassisInfo" />
			<xsl:apply-templates select="Hardware" />
		</Section>
		<xsl:apply-templates select="Network" />
		<xsl:apply-templates select="Software" />
	</xsl:template>
	<xsl:template match="ChassisInfo">
			<ListData name="ChassisInformation">
				<xsl:attribute name="display"><!--XLATESTART-->Informaci&#243;n de chasis<!--XLATESTOP--></xsl:attribute>
				<Data name="ChassModel">
					<xsl:attribute name="display"><!--XLATESTART-->Modelo de chasis<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ChassisProps1/ChassModel"/></xsl:attribute>
				</Data>
				<Data name="ServiceTag">
					<xsl:attribute name="display"><!--XLATESTART-->Etiqueta de servicio del chasis<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ChassisProps2/ServiceTag"/></xsl:attribute>
				</Data>
				
				<Data name="ChassLock">
					<xsl:attribute name="display"><!--XLATESTART-->Seguro del chasis<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="ChassisProps1/ChassLockPresent = 'true'"><!--XLATESTART-->Presente<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><!--XLATESTART-->No disponible<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				
				
					<Data name="AssetTag">
					<xsl:attribute name="display">
					<xsl:choose>
					<xsl:when test="/OMA/BaseBoardList/BaseBoard"><!--XLATESTART-->Etiqueta de servicio del m&#243;dulo de servidor<!--XLATESTOP-->
					</xsl:when>
					<xsl:otherwise><!--XLATESTART-->Etiqueta de propiedad del chasis<!--XLATESTOP--></xsl:otherwise>
			    		</xsl:choose>
					</xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ChassisProps2/AssetTag"/></xsl:attribute>
					</Data>

				
				
				<xsl:if test="/OMA/BaseBoardList/@count > '0'">
					<xsl:call-template name="BaseBoard"/>
				</xsl:if>
			</ListData>
	</xsl:template>
	
	<xsl:template name="BaseBoard">
		<xsl:for-each select="/OMA/BaseBoardList/BaseBoard">
			<xsl:if test="FeatureFlags/HostingBoard='true'">
				<Data name="BladeServiceTag" type="ustring">
					<xsl:attribute name="display"><!--XLATESTART-->Etiqueta de servicio del m&#243;dulo de servidor<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ServiceTag"/></xsl:attribute>
				</Data>
				
				<Data name="BladeLocation" type="ustring">
					<xsl:attribute name="display"><!--XLATESTART-->Ubicaci&#243;n del m&#243;dulo de servidor<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="BoardLocation"/></xsl:attribute>
				</Data>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="Hardware">
		<xsl:apply-templates/>
		<xsl:apply-templates select="parent::node()/FirmwareList" />
	</xsl:template>
	<xsl:template match="ProcessorList">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="DevProcessor">
		<ListData name="processor">
			<xsl:attribute name="display"><xsl:value-of select="ExtName"/></xsl:attribute>
			<xsl:attribute name="display"><!--XLATESTART-->Procesador<!--XLATESTOP--> <xsl:value-of select="@index + 1"/></xsl:attribute>
			<Data name="ProcessorManufacturer">
				<xsl:attribute name="display"><!--XLATESTART-->Fabricante del procesador<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Manufacturer"/></xsl:attribute>
			</Data>
			<Data name="ProcessorFamily">
				<xsl:attribute name="display"><!--XLATESTART-->Familia del procesador<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="Family='1'"><!--XLATESTART-->Otro<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='3'"><!--XLATESTART-->8086<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='4'"><!--XLATESTART-->286<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='5'"><!--XLATESTART-->386<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='6'"><!--XLATESTART-->486<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='7'"><!--XLATESTART-->8087<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='8'"><!--XLATESTART-->287<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='9'"><!--XLATESTART-->387<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='10'"><!--XLATESTART-->487<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='11'"><!--XLATESTART-->Pentium<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='12'"><!--XLATESTART-->Pentium Pro<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='13'"><!--XLATESTART-->Pentium II<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='14'"><!--XLATESTART-->Pentium con tecnolog&#237;a MMX<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='15'"><!--XLATESTART-->Celeron<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='16'"><!--XLATESTART-->Pentium II Xeon<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='17'"><!--XLATESTART-->Pentium III<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='130'"><!--XLATESTART-->Itanium<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='176'"><!--XLATESTART-->Pentium III Xeon<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='177'"><!--XLATESTART-->Pentium III con tecnolog&#237;a Intel SpeedStep<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='178'"><!--XLATESTART-->Pentium IV<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='179'"><!--XLATESTART-->Xeon<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='181'"><!--XLATESTART-->Xeon MP<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><!--XLATESTART-->Desconocido<!--XLATESTOP--></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data name="ProcessorVersion">
				<xsl:attribute name="display"><!--XLATESTART-->Versi&#243;n del procesador<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Version"/></xsl:attribute>
			</Data>
			<Data name="CurrentSpeed">
				<xsl:attribute name="display"><!--XLATESTART-->Velocidad actual<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="CurSpeed"/><xsl:text> </xsl:text><xsl:value-of select="CurSpeed/@unit"/></xsl:attribute>
			</Data>
			<Data name="MaximumSpeed">
				<xsl:attribute name="display"><!--XLATESTART-->Velocidad m&#225;xima<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="MaxSpeed"/><xsl:text> </xsl:text><xsl:value-of select="MaxSpeed/@unit"/></xsl:attribute>
			</Data>
			<Data name="ExtClockSpeed">
				<xsl:attribute name="display"><!--XLATESTART-->Velocidad del reloj externo<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="ExtClockSpeed"/><xsl:text> </xsl:text><xsl:value-of select="ExtClockSpeed/@unit"/></xsl:attribute>
			</Data>
			<Data name="Voltage">
				<xsl:attribute name="display"><!--XLATESTART-->Voltaje<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Voltage"/><xsl:text> </xsl:text><xsl:value-of select="Voltage/@unit"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="MemoryArrayList">
		<ListData name="Memory">
			<xsl:attribute name="display"><!--XLATESTART-->Memoria<!--XLATESTOP--></xsl:attribute>
			<Data name="InstalledSize">
				<xsl:attribute name="display"><!--XLATESTART-->Capacidad instalada total<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="../MaxInstalledSizeMBCumulative"/><xsl:text> </xsl:text><xsl:value-of select="../MaxInstalledSizeMBCumulative/@unit"/>
				</xsl:attribute>
			</Data>
			<Data name="OSInstalledSize">
				<xsl:attribute name="display"><!--XLATESTART-->Capacidad instalada total disponible en el sistema operativo<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="../MemoryInfo/TotalPhysMemorySizeMB"/><xsl:text> </xsl:text><xsl:value-of select="../MemoryInfo/TotalPhysMemorySizeMB/@unit"/>
				</xsl:attribute>
			</Data>
			<Data name="TotalSize">
				<xsl:attribute name="display"><!--XLATESTART-->Capacidad m&#225;xima total<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="../MaxSizeMBCumulative"/><xsl:text> </xsl:text><xsl:value-of select="../MaxSizeMBCumulative/@unit"/>
				</xsl:attribute>
			</Data>
			<Data name="MemoryArrays">
				<xsl:attribute name="display"><!--XLATESTART-->Recuento de matriz de memoria<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="@count"/></xsl:attribute>
			</Data>
		</ListData>
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="MemoryArray">
		<ListData name="MemoryArray">
			<xsl:attribute name="display"><!--XLATESTART-->Matriz de memoria<!--XLATESTOP--> <xsl:value-of select="@index + 1"/></xsl:attribute>
			<Data name="Location">
				<xsl:attribute name="display"><!--XLATESTART-->Ubicaci&#243;n<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="Location='1'"><!--XLATESTART-->Otro<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='3'"><!--XLATESTART-->Placa del sistema o placa base<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='4'"><!--XLATESTART-->Tarjeta adicional ISA<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='5'"><!--XLATESTART-->Tarjeta adicional EISA<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='6'"><!--XLATESTART-->Tarjeta adicional PCI<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='7'"><!--XLATESTART-->Tarjeta adicional MCA<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='8'"><!--XLATESTART-->Tarjeta adicional PCMCIA<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='9'"><!--XLATESTART-->Tarjeta adicional patentada<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='16'"><!--XLATESTART-->NuBus<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='160'"><!--XLATESTART-->Tarjeta adicional PC-98/C20<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='161'"><!--XLATESTART-->Tarjeta adicional PC-98/C24<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='162'"><!--XLATESTART-->Tarjeta adicional PC-98/E<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='163'"><!--XLATESTART-->Tarjeta adicional PC-98/Bus local<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='164'"><!--XLATESTART-->Tarjeta adicional PC-98/Ranura de tarjeta<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><!--XLATESTART-->Desconocido<!--XLATESTOP--></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data name="Use">
				<xsl:attribute name="display"><!--XLATESTART-->Uso<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="Location='1'"><!--XLATESTART-->Otro<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='3'"><!--XLATESTART-->Memoria del sistema<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='4'"><!--XLATESTART-->Memoria de v&#237;deo<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='5'"><!--XLATESTART-->Memoria flash<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='6'"><!--XLATESTART-->RAM no vol&#225;til<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='7'"><!--XLATESTART-->Memoria cach&#233;<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><!--XLATESTART-->Desconocido<!--XLATESTOP--></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data name="InstalledSize">
				<xsl:attribute name="display"><!--XLATESTART-->Capacidad instalada<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="InstalledSizeMBCumulative"/><xsl:text> </xsl:text><xsl:value-of select="InstalledSizeMBCumulative/@unit"/></xsl:attribute>
			</Data>
			<Data name="MaximumCapacity">
				<xsl:attribute name="display"><!--XLATESTART-->Capacidad m&#225;xima<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="MaxSizeMB"/><xsl:text> </xsl:text><xsl:value-of select="MaxSizeMB/@unit"/></xsl:attribute>
			</Data>
			<Data name="NumSocketsTotal">
				<xsl:attribute name="display"><!--XLATESTART-->Ranuras disponibles<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="NumSocketsTotal"/></xsl:attribute>
			</Data>
			<Data name="NumSocketsInUse">
				<xsl:attribute name="display"><!--XLATESTART-->Ranuras utilizadas<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="NumSocketsInUse"/></xsl:attribute>
			</Data>
			<Data name="ErrCorrType">
				<xsl:attribute name="display"><!--XLATESTART-->Correcci&#243;n de errores<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="ErrCorrType='1'"><!--XLATESTART-->Otro<!--XLATESTOP--></xsl:when>
						<xsl:when test="ErrCorrType='3'"><!--XLATESTART-->Ninguna<!--XLATESTOP--></xsl:when>
						<xsl:when test="ErrCorrType='4'"><!--XLATESTART-->Paridad<!--XLATESTOP--></xsl:when>
						<xsl:when test="ErrCorrType='5'"><!--XLATESTART-->ECC de un bit<!--XLATESTOP--></xsl:when>
						<xsl:when test="ErrCorrType='6'"><!--XLATESTART-->ECC multibit<!--XLATESTOP--></xsl:when>
						<xsl:when test="ErrCorrType='7'"><!--XLATESTART-->CRC<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><!--XLATESTART-->Desconocido<!--XLATESTOP--></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="SlotsList">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="Slot">
		<xsl:if test="ExtName != 'Embedded'">
			<ListData>
				<xsl:attribute name="name">slot<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><!--XLATESTART-->Ranura <!--XLATESTOP--> <xsl:value-of select="ExtName"/></xsl:attribute>
				<Data name="adapter">
					<xsl:attribute name="display"><!--XLATESTART-->Adaptador<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="SlotDevice"><xsl:value-of select="SlotDevice/DeviceDesc" /></xsl:when>
							<xsl:otherwise><!--XLATESTART-->No ocupado<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="Type"  editable="false" type="ustring">
					<xsl:attribute name="display"><!--XLATESTART-->Tipo<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="Type='1'"><!--XLATESTART-->Otro<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='3'"><!--XLATESTART-->ISA<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='4'"><!--XLATESTART-->MCA<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='5'"><!--XLATESTART-->EISA<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='6'"><!--XLATESTART-->PCI<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='7'"><!--XLATESTART-->PCMCIA<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='8'"><!--XLATESTART-->VL VESA<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='9'"><!--XLATESTART-->Patentado<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='10'"><!--XLATESTART-->Tarjeta de procesador<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='11'"><!--XLATESTART-->Tarjeta de memoria patentada<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='12'"><!--XLATESTART-->Tarjeta vertical de ES<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='13'"><!--XLATESTART-->NuBus<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='14'"><!--XLATESTART-->PCI 66Mhz<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='15'"><!--XLATESTART-->AGP<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='16'"><!--XLATESTART-->AGP 2X<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='17'"><!--XLATESTART-->AGP 4X<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='18'"><!--XLATESTART-->PCI X<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='160'"><!--XLATESTART-->PC98 C20<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='161'"><!--XLATESTART-->PC98 C24<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='162'"><!--XLATESTART-->PC98 E<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='163'"><!--XLATESTART-->PC98 Bus local<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='164'"><!--XLATESTART-->Tarjeta PC98<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><!--XLATESTART-->Desconocido<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="DataBusWidth">
					<xsl:attribute name="display"><!--XLATESTART-->Amplitud del bus de datos<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='1'"><!--XLATESTART-->Otro<!--XLATESTOP--></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='3'"><!--XLATESTART-->8 bits<!--XLATESTOP--></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='4'"><!--XLATESTART-->16 bits<!--XLATESTOP--></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='5'"><!--XLATESTART-->32 bits<!--XLATESTOP--></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='6'"><!--XLATESTART-->64 bits<!--XLATESTOP--></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='7'"><!--XLATESTART-->128 bits<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><!--XLATESTART-->Desconocido<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="Speed"  editable="false" type="ustring">
					<xsl:attribute name="display"><!--XLATESTART-->Velocidad<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="HotPlugSystemSlot/SlotSpeed='0'"><!--XLATESTART-->Desconocido<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><xsl:value-of select="HotPlugSystemSlot/SlotSpeed"/><xsl:text> </xsl:text><xsl:value-of select="HotPlugSystemSlot/SlotSpeed/@unit"/></xsl:otherwise>
						</xsl:choose></xsl:attribute>
				</Data>
				<Data name="SlotLength">
					<xsl:attribute name="display"><!--XLATESTART-->Longitud de ranura<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="Length='1'"><!--XLATESTART-->Otro<!--XLATESTOP--></xsl:when>
							<xsl:when test="Length='3'"><!--XLATESTART-->Corta<!--XLATESTOP--></xsl:when>
							<xsl:when test="Length='4'"><!--XLATESTART-->Larga<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><!--XLATESTART-->Desconocido<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="VoltSupply"  editable="false" type="ustring">
					<xsl:attribute name="display"><!--XLATESTART-->Voltaje de alimentaci&#243;n<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:if test="IsVolt33='true'">3.3 <!--XLATESTART-->Voltios<!--XLATESTOP--><xsl:if test="IsVolt5='true'">, </xsl:if></xsl:if>
						<xsl:if test="IsVolt5='true'">5 <!--XLATESTART-->Voltios<!--XLATESTOP--></xsl:if>
					</xsl:attribute>
				</Data>
			</ListData>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SystemBIOS">
		<ListData name="SystemBIOS">
			<xsl:attribute name="display"><!--XLATESTART-->Informaci&#243;n del BIOS<!--XLATESTOP--></xsl:attribute>
			<Data name="Manufacturer">
				<xsl:attribute name="display"><!--XLATESTART-->Fabricante<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Manufacturer"/></xsl:attribute>
			</Data>
			<Data name="Version">
				<xsl:attribute name="display"><!--XLATESTART-->Versi&#243;n<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Version"/></xsl:attribute>
			</Data>
			<Data name="ReleaseDate">
				<xsl:attribute name="display"><!--XLATESTART-->Fecha de lanzamiento<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="ReleaseDate"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="Network">
		<Section name="Network">
			<xsl:attribute name="display"><!--XLATESTART-->Datos de red<!--/XLATESTOP--></xsl:attribute>
			<xsl:choose>
				<xsl:when test="NICList">
					<xsl:apply-templates select="NICList" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
		</Section>
	</xsl:template>
	<xsl:template match="NICList">
			<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="NICCard">
		<ListData>
			<xsl:attribute name="name">NICList<xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="display"><!--XLATESTART-->Tarjeta de interfaz de red <xsl:value-of select="@index"/> Datos<!--/XLATESTOP--></xsl:attribute>
			<Data>
				<xsl:attribute name="name">IPAddr<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><!--XLATESTART-->Direcci&#243;n IP<!--/XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="IPAddress = ''"><!--XLATESTART-->No obtenido<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><xsl:value-of select="IPAddress"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">SubnetMask<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><!--XLATESTART-->M&#225;scara de subred<!--/XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="SubnetMask = ''"><!--XLATESTART-->No obtenido<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><xsl:value-of select="SubnetMask"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">DefaultGateway<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><!--XLATESTART-->Puerta de enlace predeterminada<!--/XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="DefaultGateway = ''"><!--XLATESTART-->No obtenido<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><xsl:value-of select="DefaultGateway"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">MacAddr<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><!--XLATESTART-->Direcci&#243;n MAC<!--/XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="CurrentMACAddr = ''"><!--XLATESTART-->No obtenido<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><xsl:value-of select="CurrentMACAddr"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="IPAddrList">
		<ListData name="IPAddrList">
			<xsl:attribute name="display"><!--XLATESTART-->Datos de direcci&#243;n IP<!--XLATESTOP--></xsl:attribute>
			<xsl:apply-templates/>
		</ListData>
	</xsl:template>
	<xsl:template match="IPAddr">
		<Data name="IPAddr">
			<xsl:attribute name="name">IPAddr<xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="display"><!--XLATESTART-->Direcci&#243;n IP <!--XLATESTOP--><xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
		</Data>
	</xsl:template>
	<xsl:template match="Software">
		<Section name="Software">
			<xsl:attribute name="display"><!--XLATESTART-->Perfil de software<!--XLATESTOP--></xsl:attribute>
			<xsl:apply-templates/>
		</Section>
	</xsl:template>
	<xsl:template match="OSInfo">
		<ListData name="OSInfo">
			<xsl:attribute name="display"><!--XLATESTART-->Sistema operativo<!--XLATESTOP--></xsl:attribute>
			<Data name="OSName">
				<xsl:attribute name="display"><!--XLATESTART-->Nombre<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="OSName"/></xsl:attribute>
			</Data>
			<Data name="OSVersion">
				<xsl:attribute name="display"><!--XLATESTART-->Versi&#243;n<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="OSVersion"/></xsl:attribute>
			</Data>
			<Data name="SystemTime">
				<xsl:attribute name="display"><!--XLATESTART-->Hora del sistema<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="//System/SystemInfo/SystemTime"/></xsl:attribute>
			</Data>
			<Data name="SystemBootupTime">
				<xsl:attribute name="display"><!--XLATESTART-->Hora de inicio del sistema<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="//System/SystemInfo/SystemBootupTime"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="FirmwareList">
		<xsl:apply-templates />
	</xsl:template>
	<xsl:template match="Firmware">
		<ListData>
			<xsl:attribute name="name">Firmware_<xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="display"><!--XLATESTART-->Informaci&#243;n del firmware<!--XLATESTOP--></xsl:attribute>
			<Data name="Name">
				<xsl:attribute name="display"><!--XLATESTART-->Nombre<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="FWText"/></xsl:attribute>
			</Data>
			<Data name="Version">
				<xsl:attribute name="display"><!--XLATESTART-->Versi&#243;n<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="FWVersion"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>

	<xsl:template match="ClusterInfo">
		<Section name="ClusterInfo">
			<xsl:attribute name="display"><!--XLATESTART-->Informaci&#243;n de cl&#250;ster<!--XLATESTOP--></xsl:attribute>
			<ListData name="Information">
				<xsl:attribute name="display"><!--XLATESTART-->Informaci&#243;n de cl&#250;ster<!--XLATESTOP--></xsl:attribute>
				<Data name="ClusterName">
					<xsl:attribute name="display"><!--XLATESTART-->Nombre de cl&#250;ster<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ClusterName"/></xsl:attribute>
				</Data>
				<Data name="TypeDescription">
					<xsl:attribute name="display"><!--XLATESTART-->Descripci&#243;n de cl&#250;ster<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="TypeDescription"/></xsl:attribute>
				</Data>
				<Data name="ClusterType">
					<xsl:attribute name="display"><!--XLATESTART-->Tipo de cl&#250;ster<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="ClusterType='2'"><!--XLATESTART-->Microsoft Cluster Server<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><!--XLATESTART-->Desconocido<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
			</ListData>
		</Section>
	</xsl:template>

	<xsl:template match="*"/>

</xsl:stylesheet>
