<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="xml" omit-xml-declaration="yes"/>
	<xsl:strip-space elements="*"/>
	<xsl:template match="/OMA">
		<xsl:call-template name="SystemBIOS"/>
		<xsl:call-template name="Firmware"/>
		<xsl:call-template name="OSInfo"/>
		<xsl:call-template name="OEMInfo"/>
		<xsl:call-template name="DRSCInfo"/>
		<xsl:call-template name="PERCAMAdaptersInfo"/>
		<xsl:call-template name="StorageEnclosuresInfo"/>
		<xsl:call-template name="PERCAdaptersInfo"/>
		<xsl:call-template name="DriverInfo"/>
	</xsl:template>
	<xsl:template name="SystemBIOS">
		<xsl:if test="count(SystemBIOS) != '0'">
			<Application name="bios" update_href="1">
				<xsl:attribute name="display"><!--XLATESTART-->BIOS<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="version"><xsl:value-of select="SystemBIOS/Version"/></xsl:attribute>
			</Application>
		</xsl:if>
	</xsl:template>
	<xsl:template name="Firmware">
		<xsl:for-each select="FirmwareList/Firmware">
			<Application name="firmware" update_href="1">
				<xsl:attribute name="display"><xsl:value-of select="FWText"/></xsl:attribute>
				<xsl:attribute name="version"><xsl:value-of select="FWVersion"/></xsl:attribute>
			</Application>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="OSInfo">
		<xsl:if test="count(OSInfo) != '0'">
			<Application name="osinfo" update_href="1">
				<xsl:attribute name="display"><xsl:value-of select="OSInfo/OSName"/></xsl:attribute>
				<xsl:attribute name="version"><xsl:value-of select="OSInfo/OSVersion"/></xsl:attribute>
			</Application>
		</xsl:if>
	</xsl:template>
	<xsl:template name="OEMInfo">
		<xsl:if test="count(OEM/Name) != '0'">
			<Application name="OMSA" update_href="1">
				<xsl:choose>
					<xsl:when test="OEM/Name/@display = 'Dell'">
						<xsl:attribute name="display"><!--XLATESTART-->Dell <xsl:value-of select="OEM/ProdName"/><!--XLATESTOP--></xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="display"><xsl:value-of select="OEM/ProdName"/></xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:attribute name="version"><xsl:value-of select="About/ProductVersion"/></xsl:attribute>
			</Application>
		</xsl:if>
	</xsl:template>
	<xsl:template name="DRSCInfo">
		<xsl:if test="count(DRSIdentificationObj) != '0'">
			<xsl:choose>
				<xsl:when test="ADMINISTRATOR = '1'">
					<Application name="DRSC" update_href="/servlet/SelectServlet?component=RAC&amp;snb=Update">
						<xsl:attribute name="display"><!--XLATESTART-->Firmware de controlador de acceso remoto<!--XLATESTOP--></xsl:attribute>
						<xsl:attribute name="version"><xsl:value-of select="DRSIdentificationObj/VersionInfo"/></xsl:attribute>
					</Application>
				</xsl:when>
				<xsl:otherwise>
					<Application name="DRSC" update_href="1">
						<xsl:attribute name="display"><!--XLATESTART-->Firmware de controlador de acceso remoto<!--XLATESTOP--></xsl:attribute>
						<xsl:attribute name="version"><xsl:value-of select="DRSIdentificationObj/VersionInfo"/></xsl:attribute>
					</Application>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	
		
		
			
				

	
	
	<xsl:template name="PERCAMAdaptersInfo">
		<xsl:for-each select="AMADAPTERS/DCStorageObject">
			<Application name="PERCAMAdapters" update_href="1">
				<xsl:attribute name="display"><xsl:value-of select="Name"/><!--XLATESTART--> Versi&#243;n del firmware<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="version"><xsl:value-of select="FirmwareVer"/></xsl:attribute>
			</Application>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="StorageEnclosuresInfo">
		<xsl:for-each select="ENCLOSURES/DCStorageObject">
			<xsl:if test="Type!='1'">
				<Application name="StorageEnclosures" update_href="1">
					<xsl:attribute name="display"><!--XLATESTART-->Gabinete de almacenamiento<!--XLATESTOP--><xsl:value-of select="Name"/></xsl:attribute>
					<xsl:attribute name="version"><xsl:value-of select="AppVer"/></xsl:attribute>
				</Application>
			</xsl:if>
			</xsl:for-each>
			</xsl:template>
			<xsl:template name="PERCAdaptersInfo">
				<xsl:for-each select="ADAPTERS/Result/Inventory/Entry">
					<Application name="PERCAdapters" update_href="1">
						<xsl:attribute name="display"><xsl:value-of select="@name"/></xsl:attribute>
						<xsl:attribute name="version"><xsl:value-of select="@vendorVersion"/></xsl:attribute>
					</Application>
				</xsl:for-each>
			</xsl:template>
			<xsl:template name="DriverInfo">
				<xsl:for-each select="DriverInfo/Result/Inventory/Entry">
					<Application name="Driver" update_href="1">
						<xsl:attribute name="display"><xsl:value-of select="@name"/></xsl:attribute>
						<xsl:attribute name="version"><xsl:value-of select="@vendorVersion"/></xsl:attribute>
					</Application>
				</xsl:for-each>
	</xsl:template>
	<xsl:template match="*"/>
</xsl:stylesheet>
