<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" />
	<xsl:strip-space elements="*"/>
	<xsl:template match="OMA">
		<xsl:choose>
			<xsl:when test="SMStatus != '0'">
				<DataArea printable="false">
					<PageTitle>
						<xsl:attribute name="display">
							<xsl:call-template name="smstatus">
								<xsl:with-param name="status"><xsl:value-of select="SMStatus"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
					</PageTitle>
				</DataArea>
			</xsl:when>
			<xsl:otherwise>
				<DataArea validate="true" onLoad="true">
				<xsl:attribute name="backpagedisplay"><!--XLATESTART-->Capteurs des ventilateurs<!--XLATESTOP--></xsl:attribute>
					<xsl:apply-templates select="ServletArguments"/>
					<xsl:apply-templates select="FanProbe"/>
				</DataArea>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="FanProbe">
		<PageTitle></PageTitle>
		<SubHeader >
			<xsl:attribute name="display"><xsl:value-of select="ProbeLocation"/></xsl:attribute>
			<xsl:attribute name="status"><xsl:value-of select="@status"/></xsl:attribute>
		</SubHeader>
		<xsl:choose>
			<xsl:when test="(ProbeThresholds/LCThreshold &gt; 0) and (ProbeThresholds/UCThreshold &gt; 0) and (ProbeThresholds/LNCThreshold &gt; 0) and (ProbeThresholds/UNCThreshold &gt; 0) and (ProbeReading &gt;= 0)">
				<Guage  digits="0">
				<xsl:attribute name="units"> <!--XLATESTART-->tr/min<!--XLATESTOP--></xsl:attribute>
					<Reading><xsl:value-of select="ProbeReading"/></Reading>
					<MFThresh><xsl:value-of select="ProbeThresholds/LCThreshold"/></MFThresh>
					<MXFThresh><xsl:value-of select="ProbeThresholds/UCThreshold"/></MXFThresh>
					<MWThresh><xsl:value-of select="ProbeThresholds/LNCThreshold"/></MWThresh>
					<MXWThresh><xsl:value-of select="ProbeThresholds/UNCThreshold"/></MXWThresh>
					<ListData>
						<Data display="Condition">
							<xsl:call-template name="StatusToStr">
								<xsl:with-param name="status"><xsl:value-of select="@status"/></xsl:with-param>
							</xsl:call-template>
						</Data>
						<Data display="Mesure" reading="true">
							<xsl:attribute name="value"><xsl:value-of select="ProbeReading"/> <!--XLATESTART--> tr/min<!--XLATESTOP--></xsl:attribute>
						</Data>
						<Data display="Seuil min. de panne">
							<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/LCThreshold"/><!--XLATESTART--> tr/min<!--XLATESTOP--></xsl:attribute>
						</Data>
						<Data display="Seuil max. de panne">
							<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/UCThreshold"/><!--XLATESTART--> tr/min<!--XLATESTOP--></xsl:attribute>
						</Data>
						<xsl:choose>
						<xsl:when test="(Capabilities/ProbeUNCDefSetEnabled = 'true') or (Capabilities/ProbeLNCDefSetEnabled = 'true')">
						<Data display="Param&#232;tres des seuils" type="radio"  state="1">
							<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
							<xsl:attribute name="value">D&#233;finir sur les valeurs par d&#233;faut</xsl:attribute>
						</Data>
							<xsl:if test="(Capabilities/ProbeUNCSetEnabled = 'true') or (Capabilities/ProbeLNCSetEnabled = 'true')">
							<Data type="radio">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">D&#233;finir sur les valeurs</xsl:attribute>
							</Data>
							</xsl:if>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="(Capabilities/ProbeUNCSetEnabled = 'true') or (Capabilities/ProbeLNCSetEnabled = 'true')">
							<Data display="Param&#232;tres des seuils" type="radio"  state="1">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">D&#233;finir sur les valeurs</xsl:attribute>
							</Data>
							</xsl:if>
						</xsl:otherwise>
						</xsl:choose>
						<xsl:if test="(Capabilities/ProbeLNCSetEnabled = 'true')">
						<Data display="Seuil min. d&apos;avertissement" type="editbox">							<xsl:attribute name="textboxname">LNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART--> tr/min<!--XLATESTOP--></xsl:attribute>
						</Data>
						</xsl:if>
						<xsl:if test="(Capabilities/ProbeUNCSetEnabled = 'true')">
						<Data display="Seuil max. d&apos;avertissement" type="editbox">							<xsl:attribute name="textboxname">UNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART--> tr/min<!--XLATESTOP--></xsl:attribute>
						</Data>
						</xsl:if>
					</ListData>
				</Guage>
			</xsl:when>
			<xsl:otherwise>
				<ListData>
					<Data display="Condition">
						<xsl:call-template name="StatusToStr">
							<xsl:with-param name="status"><xsl:value-of select="@status"/></xsl:with-param>
						</xsl:call-template>
					</Data>
					<Data display="Mesure">
						<xsl:attribute name="value"><xsl:value-of select="ProbeReading"/><!--XLATESTART--> tr/min<!--XLATESTOP--></xsl:attribute>
					</Data>
					<Data display="Seuil minimum de panne">
						<xsl:choose>
							<xsl:when test="ProbeThresholds/LCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/LCThreshold"/><!--XLATESTART--> tr/min<!--XLATESTOP--></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value"><!--XLATESTART-->Inconnu<!--XLATESTOP--></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</Data>			
					<Data display="Seuil maximum de panne">
						<xsl:choose>
							<xsl:when test="ProbeThresholds/UCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/UCThreshold"/><!--XLATESTART--> tr/min<!--XLATESTOP--></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value"><!--XLATESTART-->Inconnu<!--XLATESTOP--></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</Data>
					<Data display="Param&#232;tres des seuils" type="radio"  state="1">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
						<xsl:attribute name="value">D Default</xsl:attribute>
					</Data>
					<Data type="radio">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
						<xsl:attribute name="value">D&#233;finir sur les valeurs</xsl:attribute>
					</Data>
					<Data display="Seuil min. d&apos;avertissement" type="editbox" size="5">						<xsl:attribute name="name">LNCVal</xsl:attribute>
						<xsl:choose>
							<xsl:when test="ProbeThresholds/LNCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value">0</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:attribute name="unit"><!--XLATESTART--> tr/min<!--XLATESTOP--></xsl:attribute>
					</Data>
					<Data display="Seuil max. d&apos;avertissement" type="editbox" size="5">						<xsl:attribute name="name">UNCVal</xsl:attribute>
						<xsl:choose>
							<xsl:when test="ProbeThresholds/UNCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value">0</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:attribute name="unit"><!--XLATESTART--> tr/min<!--XLATESTOP--></xsl:attribute>
					</Data>
				</ListData>
			</xsl:otherwise>
		</xsl:choose>
		<script language="javascript">
			isProbeUNCSetEnabled 		= <xsl:value-of select="Capabilities/ProbeUNCSetEnabled"/>;
			isProbeLNCSetEnabled 		= <xsl:value-of select="Capabilities/ProbeLNCSetEnabled"/>;
			isProbeUNCDefSetEnabled 	= <xsl:value-of select="Capabilities/ProbeUNCDefSetEnabled"/>;
			isProbeLNCDefSetEnabled 	= <xsl:value-of select="Capabilities/ProbeLNCDefSetEnabled"/>;
		
			setToDefault	= true;
			setToValues	= false;

if( (( ! isProbeUNCDefSetEnabled )  &amp;&amp; (! isProbeLNCDefSetEnabled)) &amp;&amp; ( isProbeUNCSetEnabled || isProbeLNCSetEnabled ) )
{
	setToValues	= true;
}

			function initializationRoutine()
			{
				if( isProbeUNCSetEnabled )
				{
					document.getElementById("UNCVal").value = <xsl:value-of select="ProbeThresholds/UNCThreshold"/>;
					document.getElementById("UNCVal").disabled = false;
					if ( ( isProbeUNCDefSetEnabled || isProbeLNCDefSetEnabled ) &amp;&amp; setToDefault )
					{
						document.getElementById("UNCVal").disabled = true;
					}
				}

				if( isProbeLNCSetEnabled )
				{
					document.getElementById("LNCVal").value = <xsl:value-of select="ProbeThresholds/LNCThreshold"/>;
					document.getElementById("LNCVal").disabled = false;
					if ( ( isProbeUNCDefSetEnabled || isProbeLNCDefSetEnabled ) &amp;&amp; setToDefault )
					{
						document.getElementById("LNCVal").disabled = true;
					}
				}
				
				if( isProbeUNCDefSetEnabled || isProbeLNCDefSetEnabled )
				{
					document.getElementById("threshsetting").checked = true;
				}
			}
			
			function setToVal()
			{
				setToValues = true;
				setToDefault = false;
				if( isProbeUNCSetEnabled )
				{
					document.getElementById("UNCVal").disabled = false;
				}

				if( isProbeLNCSetEnabled )
				{
					document.getElementById("LNCVal").disabled = false;
				}
			}
			
			function setToDef()
			{
				setToDefault = true;
				setToValues = false;
				if( isProbeUNCSetEnabled )
				{
					document.getElementById("UNCVal").disabled = true;
				}

				if( isProbeLNCSetEnabled )
				{
					document.getElementById("LNCVal").disabled = true;
				}
			}

			function validate()
			{
				<xsl:choose>
					<xsl:when test="ProbeThresholds/UCThreshold &gt; 0 ">
						var UC 	= parseFloat("<xsl:value-of select="ProbeThresholds/UCThreshold"/>");
						var preUNC = <xsl:value-of select="ProbeThresholds/UNCThreshold"/>;
					</xsl:when>
					<xsl:otherwise>
						var UC 	= 0;
						var preUNC = <xsl:value-of select="ProbeThresholds/UNCThreshold"/>;
					</xsl:otherwise>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="ProbeThresholds/LCThreshold &gt; 0 ">
						var LC = parseFloat("<xsl:value-of select="ProbeThresholds/LCThreshold"/>");
						var preLNC = <xsl:value-of select="ProbeThresholds/LNCThreshold"/>;
					</xsl:when>
					<xsl:otherwise>
						var LC = 0;
						var preLNC = <xsl:value-of select="ProbeThresholds/LNCThreshold"/>;
					</xsl:otherwise>
				</xsl:choose>
				
				if(setToValues)
				{
					// user has changed the threshold settings.
					
					<xsl:if test="Capabilities/ProbeUNCSetEnabled = 'true' ">
						document.getElementById("UNCVal").disabled = false;
						var tempUNC = document.getElementById("UNCVal").value;
						
						if(isNaN(tempUNC) == true)
						{
							alert("Erreur ! Attendait un nombre pour le seuil d'avertissement maximal, a lu : " + tempUNC);
							document.getElementById("UNCVal").value = preUNC;
							document.getElementById("LNCVal").value = preLNC;
							return false;
						}
						
						if(isNaN(parseFloat(tempUNC)) == true)
						{
							alert("Erreur ! Attendait un nombre entier pour le seuil d'avertissement maximal, a lu : " + tempUNC);
						document.getElementById("UNCVal").value = preUNC;
						document.getElementById("LNCVal").value = preLNC;
						return false;
					}
					else
					{
						if(tempUNC.indexOf(".") != "-1")
														{
															alert("Erreur ! Attendait un nombre entier pour le seuil d'avertissement maximal, a lu : " + tempUNC);
								document.getElementById("UNCVal").value = preUNC;
								return false;
							}
						}
						
						var UNC 	= parseFloat(document.getElementById("UNCVal").value);
					</xsl:if>
					
					<xsl:if test="Capabilities/ProbeLNCSetEnabled = 'true' ">
						document.getElementById("LNCVal").disabled = false;
						var tempLNC 	= document.getElementById("LNCVal").value;
						
						if( isNaN(tempLNC) == true)
						{
							alert("Erreur ! Attendait un nombre pour le seuil d'avertissement minimal, a lu : " + tempLNC);
							document.getElementById("UNCVal").value = preUNC;
							document.getElementById("LNCVal").value = preLNC;
							return false;
						}
						
						
						if( isNaN(parseFloat(tempLNC)) == true)
						{
							alert("Erreur ! Attendait un nombre entier pour le seuil maximum d'avertissement, a lu : " + tempLNC);
						document.getElementById("UNCVal").value = preUNC;
						document.getElementById("LNCVal").value = preLNC;
						return false;
					}
					else
					{
						if(tempLNC.indexOf(".") != "-1")
														{
															alert("Erreur ! Attendait un nombre entier pour le seuil d'avertissement mimimum, a lu : " + tempLNC);
								document.getElementById("LNCVal").value = preLNC;
								return false;
							}
						}
						
						var LNC 	= parseFloat(document.getElementById("LNCVal").value);
					</xsl:if>
							
					if( isProbeUNCSetEnabled &amp;&amp; (! isProbeLNCSetEnabled) )
					{
						// only upper warning threshold is settable.

						if((UC &gt; 0) &amp;&amp; (LC &gt; 0))
						{
							if((UC &gt; UNC) &amp;&amp; (UNC &gt; LC))
							{
								return true;
							}
							else
							{
								alert("Erreur ! La valeur [" + UNC + "] sort de la plage du seuil maximum d'avertissement allant de " + LC + " tr/min &#224; " + UC + " tr/min." );
							}
						}
						else
						{
							// UC and LC are not available to do validation of UNC value.
							return true;
						}
						
						document.getElementById("UNCVal").value = preUNC;
					}
					else if( (! isProbeUNCSetEnabled ) &amp;&amp; isProbeLNCSetEnabled )
					{
						// only lower warning threshold is settable.
						
						if((UC &gt; 0) &amp;&amp; (LC &gt; 0))
						{
							if((UC &gt; LNC) &amp;&amp; (LNC &gt; LC))
							{
								return true;
							}
							else
							{
								alert("Erreur! La valeur [" + LNC + "] n'est pas comprise dans la plage du seuil minimum d'avertissement allant de " + LC + " tr/min &#224; " + UC + " tr/min." );
							}
						}
						else
						{
							// UC and LC are not available to do validation of LNC value.
							return true;
						}
						
						document.getElementById("LNCVal").value = preLNC;
					}
					else
					{
						// both are settable
						
						if((UC &gt; 0) &amp;&amp; (LC &gt; 0))
						{
							if((UC &gt; UNC) &amp;&amp; (UNC &gt; LC))
							{
								if(UNC &gt; LNC)
								{
									if(LNC &gt; LC)
									{
										return true;
									}
									else
									{
										alert("Erreur! La valeur [" + LNC + "] n'est pas comprise dans la plage du seuil minimum d'avertissement allant de " + LC + " tr/min &#224; " + UNC + " tr/min." );
								}
							}
							else
							{
								alert("Erreur ! La valeur du seuil d'avertissement minimal ne peut pas &#234;tre sup&#233;rieure ou &#233;gale &#224; la valeur du seuil d'avertissement maximal." );
						}
					}
					else
					{
						if((UC &gt; LNC) &amp;&amp; (LNC &gt; LC))
						{
							alert("Erreur ! La valeur [" + UNC + "] n'est pas comprise dans la plage du seuil maximum d'avertissement allant de " + LNC + " tr/min &#224; " + UC + " tr/min." );
							}
							else
							{
								alert("Erreur ! La valeur [" + UNC + "] n'est pas comprise dans la plage du seuil maximum d'avertissement allant de " + preLNC + " tr/min &#224; " + UC + " tr/min." );
							}
						}
					}
					else
					{
							<!-- UC and LC have invalid values. Accept the user values if they are positive-->						
							if( UNC &gt; 0)
						{
							if( LNC &gt; 0)
							{
								if(UNC &gt; LNC)
								{
									return true;
								}
								else
								{
									alert("Erreur ! la valeur de seuil d'avertissement minimal ne peut pas &#234;tre sup&#233;rieure ou &#233;gale &#224; la valeur de seuil d'avertissement maximal" );
								}
							}
							else
							{
								alert("Erreur ! Attendait un nombre non sign&#233; pour le seuil minimum d'avertissement, a lu : " + LNC);
							}
						}
						else
						{
							alert("Erreur ! Attendait un nombre non sign&#233; pour le seuil d'avertissement maximal, a lu : " + UNC);
							}
						}

						document.getElementById("UNCVal").value = preUNC;
						document.getElementById("LNCVal").value = preLNC;
					}
				}
				else
				{
					// do not validate the values if user has selected default threshold settings.
					return true;
				}
				
				<!--  returning false doesn't submit the form -->
				return false;
			}
		</script>
	</xsl:template>
	<xsl:template match="ServletArguments">
		<xsl:attribute name="submit">/servlet/SubmitForm?plugin=com.dell.hip.webplugins.SetFanWebPlugin&amp;oid=<xsl:value-of select="@OID"/>&amp;poid=<xsl:value-of select="@POID"/>&amp;objtype=<xsl:value-of select="@PObjType"/>
</xsl:attribute>
		<xsl:attribute name="backpagetarget">/servlet/DataArea?plugin=com.dell.hip.webplugins.FanProbesWebPlugin&amp;poid=<xsl:value-of select="@POID"/>&amp;help=Fans</xsl:attribute>
		<CustomButton>
			<Data  name="" >
			<xsl:attribute name="display"><!--XLATESTART-->Actualiser<!--XLATESTOP--></xsl:attribute>
							<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.hip.webplugins.EditFanProbeWebPlugin&amp;oid=<xsl:value-of select="@OID"/>&amp;poid=<xsl:value-of select="@POID"/>&amp;help=EditFanProbe</xsl:attribute>
			</Data>
		</CustomButton>
	</xsl:template>
		<xsl:template name="StatusToStr">
		<xsl:param name="status"/>
		<xsl:choose>
			<xsl:when test="$status = 1">
				<xsl:attribute name="value">Unknown</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 2">
				<xsl:attribute name="value">OK</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 3">
				<xsl:attribute name="value">Non Critical</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 4">
				<xsl:attribute name="value">Critical</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 5">
				<xsl:attribute name="value">Non Recoverable</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:attribute name="value">Other</xsl:attribute>
			</xsl:otherwise>
		</xsl:choose>				
	</xsl:template>
	<xsl:template name="DataType">
		<xsl:param name="name"/>
		<xsl:param name="display"/>
		<xsl:param name="value"/>
		<xsl:param name="type"/>
		<xsl:param name="link"/>
		<xsl:param name="href"/>		
		<Data >
			<xsl:attribute name="name"><xsl:value-of select="$name"/></xsl:attribute>
			<xsl:attribute name="display"><xsl:value-of select="$display"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$value"/></xsl:attribute>
			<xsl:attribute name="link"><xsl:value-of select="$link"/></xsl:attribute>
			<xsl:attribute name="href"><xsl:value-of select="$href"/></xsl:attribute>
			<xsl:attribute name="type"><xsl:value-of select="$type"/></xsl:attribute>
		</Data>
	</xsl:template>
		<xsl:template name="smstatus">
		<xsl:param name="status"/>
		<xsl:param name="mssg"/>
		<xsl:choose>
			<xsl:when test="$status = '-1'"><!--XLATESTART-->&#201;chec de la commande<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '0'"><!--XLATESTART-->Commande r&#233;ussie<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '1'"><!--XLATESTART-->Commande non impl&#233;ment&#233;e<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '2'"><!--XLATESTART-->Mauvaise commande<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '3'"><!--XLATESTART-->Expiration du d&#233;lai de la commande<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '4'"><!--XLATESTART-->Commande annul&#233;e<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '5'"><!--XLATESTART-->Commande interrompue<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '6'"><!--XLATESTART-->Commande en attente<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '7'"><!--XLATESTART-->Pas de p&#233;riph&#233;rique de ce type<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '8'"><!--XLATESTART-->P&#233;riph&#233;rique occup&#233;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '9'"><!--XLATESTART-->Mauvais p&#233;riph&#233;rique<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '10'"><!--XLATESTART-->Fausse interruption<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '11'"><!--XLATESTART-->Ressource verrouill&#233;e<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '12'"><!--XLATESTART-->L'index n'est pas valide.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '13'"><!--XLATESTART-->Erreur SMB<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '14'"><!--XLATESTART-->Les donn&#233;es requises ne sont pas disponibles<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '15'"><!--XLATESTART-->Les donn&#233;es requises sont plus nombreuses que les donn&#233;es disponibles<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '16'"><!--XLATESTART-->Les donn&#233;es requises sont moins nombreuses que les donn&#233;es disponibles<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '17'"><!--XLATESTART-->Le p&#233;riph&#233;rique n'est pas encore pr&#234;t &#224; accepter les commandes. Ressayer plus tard<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '18'"><!--XLATESTART-->Le p&#233;riph&#233;rique ne dispose pas de donn&#233;es.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '19'"><!--XLATESTART-->Le p&#233;riph&#233;rique est &#224; cours de m&#233;moire.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '20'"><!--XLATESTART-->Le p&#233;riph&#233;rique existe d&#233;j&#224;.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '256'"><!--XLATESTART-->L'objet Ventilateur est introuvable.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '257'"><!--XLATESTART-->L'objet Ventilateur est malform&#233;, corrompu ou mauvais.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '258'"><!--XLATESTART-->L'objet Ventilateur existe d&#233;j&#224;.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '260'"><!--XLATESTART-->Le fichier INI est introuvable.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '261'"><!--XLATESTART-->L'INI est malform&#233;, corrompu ou mauvais.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '262'"><!--XLATESTART-->La section INI n'existe pas.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '263'"><!--XLATESTART-->La cl&#233; INI n'existe pas.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '264'"><!--XLATESTART-->La valeur INI est malform&#233;e, corrompue ou mauvaise.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '270'"><!--XLATESTART-->Privil&#232;ges d'acc&#232;s insuffisants<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '271'"><!--XLATESTART-->Le nom ou la valeur du param&#232;tre n'est pas valide : <!--XLATESTOP--><xsl:value-of select="$mssg"/></xsl:when>
			<xsl:when test="$status = '272'"><!--XLATESTART-->&#192; cours de m&#233;moire<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '280'"><!--XLATESTART-->Le fichier XML est introuvable.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '281'"><!--XLATESTART-->Le XML est malform&#233;, corrompu ou mauvais.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '282'"><!--XLATESTART-->Le n&#339;ud XML n'existe pas.<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '283'"><!--XLATESTART-->La valeur XML est malform&#233;e, corrompue ou mauvaise.<!--XLATESTOP--></xsl:when>
		<xsl:otherwise>SMStatus: <xsl:value-of select="$status"/></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="*"/>
</xsl:stylesheet>
