<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="xml" omit-xml-declaration="yes"/>
	<xsl:strip-space elements="*"/>
	<xsl:template match="/OMA">
		<Summary>
			<xsl:apply-templates/>
		</Summary>
	</xsl:template>

	<xsl:template match="System">
		<Section name="System">
			<xsl:attribute name="display"><!--XLATESTART-->Syst&#232;me<!--XLATESTOP--></xsl:attribute>
			<ListData name="system">
				<xsl:attribute name="display"><!--XLATESTART-->Syst&#232;me<!--XLATESTOP--></xsl:attribute>
				<Data name="HostName">
					<xsl:attribute name="display"><!--XLATESTART-->Nom d'h&#244;te<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="HostName"/></xsl:attribute>
				</Data>
				<Data name="SystemLocation">
					<xsl:attribute name="display"><!--XLATESTART-->Emplacement du syst&#232;me<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="SystemInfo/SystemLocation"/></xsl:attribute>
				</Data>
			</ListData>
		</Section>
	</xsl:template>
	<xsl:template match="ChassisList">
			<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="Chassis">
		<Section>
			<xsl:attribute name="name">chassis_<xsl:value-of select="@index" /></xsl:attribute>
			<xsl:attribute name="display">
				<xsl:choose>
					<xsl:when test="@display = 'Main System Chassis'"><!--XLATESTART-->Ch&#226;ssis principal du syst&#232;me<!--XLATESTOP--></xsl:when>
					<xsl:otherwise><xsl:value-of select="@display" /></xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:apply-templates select="ChassisInfo" />
			<xsl:apply-templates select="Hardware" />
		</Section>
		<xsl:apply-templates select="Network" />
		<xsl:apply-templates select="Software" />
	</xsl:template>
	<xsl:template match="ChassisInfo">
			<ListData name="ChassisInformation">
				<xsl:attribute name="display"><!--XLATESTART-->Informations sur le ch&#226;ssis<!--XLATESTOP--></xsl:attribute>
				<Data name="ChassModel">
					<xsl:attribute name="display"><!--XLATESTART-->Mod&#232;le de ch&#226;ssis<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ChassisProps1/ChassModel"/></xsl:attribute>
				</Data>
				<Data name="ServiceTag">
					<xsl:attribute name="display"><!--XLATESTART-->&#201;tiquette de service du ch&#226;ssis<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ChassisProps2/ServiceTag"/></xsl:attribute>
				</Data>
				
				<Data name="ChassLock">
					<xsl:attribute name="display"><!--XLATESTART-->Verrou du ch&#226;ssis<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="ChassisProps1/ChassLockPresent = 'true'"><!--XLATESTART-->Pr&#233;sent<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><!--XLATESTART-->Pas disponible<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				
				
				<Data name="AssetTag">
					<xsl:attribute name="display">
					<xsl:choose>
					<xsl:when test="/OMA/BaseBoardList/BaseBoard"><!--XLATESTART-->&#201;tiquette de service du module de Serveur<!--XLATESTOP-->
					</xsl:when>
					<xsl:otherwise><!--XLATESTART-->Num&#233;ro d'inventaire du ch&#226;ssis<!--XLATESTOP--></xsl:otherwise>
			    		</xsl:choose>
					</xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ChassisProps2/AssetTag"/></xsl:attribute>
				</Data>

				
				
				<xsl:if test="/OMA/BaseBoardList/@count > '0'">
					<xsl:call-template name="BaseBoard"/>
				</xsl:if>
			</ListData>
	</xsl:template>
	
	<xsl:template name="BaseBoard">
		<xsl:for-each select="/OMA/BaseBoardList/BaseBoard">
			<xsl:if test="FeatureFlags/HostingBoard='true'">
				<Data name="BladeServiceTag" type="ustring">
					<xsl:attribute name="display"><!--XLATESTART-->&#201;tiquette de service du module de Serveur<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ServiceTag"/></xsl:attribute>
				</Data>
				<Data name="BladeLocation" type="ustring">
					<xsl:attribute name="display"><!--XLATESTART-->Emplacement du module de serveur<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="BoardLocation"/></xsl:attribute>
				</Data>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="Hardware">
		<xsl:apply-templates/>
		<xsl:apply-templates select="parent::node()/FirmwareList" />
	</xsl:template>
	<xsl:template match="ProcessorList">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="DevProcessor">
		<ListData name="processor">
			<xsl:attribute name="display"><xsl:value-of select="ExtName"/></xsl:attribute>
			<xsl:attribute name="display"><!--XLATESTART-->Processeur<!--XLATESTOP--> <xsl:value-of select="@index + 1"/></xsl:attribute>
			<Data name="ProcessorManufacturer">
				<xsl:attribute name="display"><!--XLATESTART-->Fabricant du processeur<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Manufacturer"/></xsl:attribute>
			</Data>
			<Data name="ProcessorFamily">
				<xsl:attribute name="display"><!--XLATESTART-->Gamme du processeur<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="Family='1'"><!--XLATESTART-->Autre<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='3'"><!--XLATESTART-->8086<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='4'"><!--XLATESTART-->286<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='5'"><!--XLATESTART-->386<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='6'"><!--XLATESTART-->486<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='7'"><!--XLATESTART-->8087<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='8'"><!--XLATESTART-->287<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='9'"><!--XLATESTART-->387<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='10'"><!--XLATESTART-->487<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='11'"><!--XLATESTART-->Pentium<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='12'"><!--XLATESTART-->Pentium Pro<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='13'"><!--XLATESTART-->Pentium II<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='14'"><!--XLATESTART-->Pentium avec technologie MMX<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='15'"><!--XLATESTART-->Celeron<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='16'"><!--XLATESTART-->Pentium II Xeon<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='17'"><!--XLATESTART-->Pentium III<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='130'"><!--XLATESTART-->Itanium<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='176'"><!--XLATESTART-->Pentium III Xeon<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='177'"><!--XLATESTART-->Pentium III avec technologie Intel SpeedStep<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='178'"><!--XLATESTART-->Pentium IV<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='179'"><!--XLATESTART-->Xeon<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='181'"><!--XLATESTART-->Xeon MP<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><!--XLATESTART-->Inconnu<!--XLATESTOP--></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data name="ProcessorVersion">
				<xsl:attribute name="display"><!--XLATESTART-->Version du processeur<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Version"/></xsl:attribute>
			</Data>
			<Data name="CurrentSpeed">
				<xsl:attribute name="display"><!--XLATESTART-->Vitesse actuelle<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="CurSpeed"/><xsl:text> </xsl:text><xsl:value-of select="CurSpeed/@unit"/></xsl:attribute>
			</Data>
			<Data name="MaximumSpeed">
				<xsl:attribute name="display"><!--XLATESTART-->Vitesse maximale<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="MaxSpeed"/><xsl:text> </xsl:text><xsl:value-of select="MaxSpeed/@unit"/></xsl:attribute>
			</Data>
			<Data name="ExtClockSpeed">
				<xsl:attribute name="display"><!--XLATESTART-->Vitesse de l'horloge externe<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="ExtClockSpeed"/><xsl:text> </xsl:text><xsl:value-of select="ExtClockSpeed/@unit"/></xsl:attribute>
			</Data>
			<Data name="Voltage">
				<xsl:attribute name="display"><!--XLATESTART-->Tension<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Voltage"/><xsl:text> </xsl:text><xsl:value-of select="Voltage/@unit"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="MemoryArrayList">
		<ListData name="Memory">
			<xsl:attribute name="display"><!--XLATESTART-->M&#233;moire<!--XLATESTOP--></xsl:attribute>
			<Data name="InstalledSize">
				<xsl:attribute name="display"><!--XLATESTART-->Capacit&#233; totale install&#233;e<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="../MaxInstalledSizeMBCumulative"/><xsl:text> </xsl:text><xsl:value-of select="../MaxInstalledSizeMBCumulative/@unit"/>
				</xsl:attribute>
			</Data>
			<Data name="OSInstalledSize">
				<xsl:attribute name="display"><!--XLATESTART-->Capacit&#233; totale install&#233;e disponible au syst&#232;me d'exploitation<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="../MemoryInfo/TotalPhysMemorySizeMB"/><xsl:text> </xsl:text><xsl:value-of select="../MemoryInfo/TotalPhysMemorySizeMB/@unit"/>
				</xsl:attribute>
			</Data>
			<Data name="TotalSize">
				<xsl:attribute name="display"><!--XLATESTART-->Capacit&#233; totale maximale<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="../MaxSizeMBCumulative"/><xsl:text> </xsl:text><xsl:value-of select="../MaxSizeMBCumulative/@unit"/>
				</xsl:attribute>
			</Data>
			<Data name="MemoryArrays">
				<xsl:attribute name="display"><!--XLATESTART-->Nombre de matrices de m&#233;moire<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="@count"/></xsl:attribute>
			</Data>
		</ListData>
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="MemoryArray">
		<ListData name="MemoryArray">
			<xsl:attribute name="display"><!--XLATESTART-->Matrice de m&#233;moire<!--XLATESTOP--> <xsl:value-of select="@index + 1"/></xsl:attribute>
			<Data name="Location">
				<xsl:attribute name="display"><!--XLATESTART-->Emplacement<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="Location='1'"><!--XLATESTART-->Autre<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='3'"><!--XLATESTART-->Carte syst&#232;me ou carte m&#232;re<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='4'"><!--XLATESTART-->Carte d'extension ISA<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='5'"><!--XLATESTART-->Carte d'extension EISA<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='6'"><!--XLATESTART-->Carte d'extension PCI<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='7'"><!--XLATESTART-->Carte d'extension MCA<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='8'"><!--XLATESTART-->Carte d'extension PCMCIA<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='9'"><!--XLATESTART-->Carte d'extension propri&#233;taire<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='16'"><!--XLATESTART-->NuBus<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='160'"><!--XLATESTART-->Carte d'extension PC-98/C20<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='161'"><!--XLATESTART-->Carte d'extension PC-98/C24<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='162'"><!--XLATESTART-->Carte d'extension PC-98/E<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='163'"><!--XLATESTART-->Carte d'extension PC-98/bus local<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='164'"><!--XLATESTART-->Carte d'extension PC-98/logement de carte<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><!--XLATESTART-->Inconnu<!--XLATESTOP--></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data name="Use">
				<xsl:attribute name="display"><!--XLATESTART-->Utilisation<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="Location='1'"><!--XLATESTART-->Autre<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='3'"><!--XLATESTART-->M&#233;moire syst&#232;me<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='4'"><!--XLATESTART-->M&#233;moire vid&#233;o<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='5'"><!--XLATESTART-->M&#233;moire flash<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='6'"><!--XLATESTART-->M&#233;moire vive r&#233;manente<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='7'"><!--XLATESTART-->M&#233;moire cache<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><!--XLATESTART-->Inconnu<!--XLATESTOP--></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data name="InstalledSize">
				<xsl:attribute name="display"><!--XLATESTART-->Capacit&#233; install&#233;e<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="InstalledSizeMBCumulative"/><xsl:text> </xsl:text><xsl:value-of select="InstalledSizeMBCumulative/@unit"/></xsl:attribute>
			</Data>
			<Data name="MaximumCapacity">
				<xsl:attribute name="display"><!--XLATESTART-->Capacit&#233; maximale<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="MaxSizeMB"/><xsl:text> </xsl:text><xsl:value-of select="MaxSizeMB/@unit"/></xsl:attribute>
			</Data>
			<Data name="NumSocketsTotal">
				<xsl:attribute name="display"><!--XLATESTART-->Logements disponibles<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="NumSocketsTotal"/></xsl:attribute>
			</Data>
			<Data name="NumSocketsInUse">
				<xsl:attribute name="display"><!--XLATESTART-->Logements utilis&#233;s<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="NumSocketsInUse"/></xsl:attribute>
			</Data>
			<Data name="ErrCorrType">
				<xsl:attribute name="display"><!--XLATESTART-->Correction d'erreur<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="ErrCorrType='1'"><!--XLATESTART-->Autre<!--XLATESTOP--></xsl:when>
						<xsl:when test="ErrCorrType='3'"><!--XLATESTART-->Aucun<!--XLATESTOP--></xsl:when>
						<xsl:when test="ErrCorrType='4'"><!--XLATESTART-->Parit&#233;<!--XLATESTOP--></xsl:when>
						<xsl:when test="ErrCorrType='5'"><!--XLATESTART-->ECC bit simple<!--XLATESTOP--></xsl:when>
						<xsl:when test="ErrCorrType='6'"><!--XLATESTART-->ECC multi-bits<!--XLATESTOP--></xsl:when>
						<xsl:when test="ErrCorrType='7'"><!--XLATESTART-->Contr&#244;le de redondance cyclique<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><!--XLATESTART-->Inconnu<!--XLATESTOP--></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="SlotsList">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="Slot">
		<xsl:if test="ExtName != 'Embedded'">
			<ListData>
				<xsl:attribute name="name">slot<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><!--XLATESTART-->Logement <!--XLATESTOP--> <xsl:value-of select="ExtName"/></xsl:attribute>
				<Data name="adapter">
					<xsl:attribute name="display"><!--XLATESTART-->Adaptateur<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="SlotDevice"><xsl:value-of select="SlotDevice/DeviceDesc" /></xsl:when>
							<xsl:otherwise><!--XLATESTART-->Pas occup&#233;<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="Type"  editable="false" type="ustring">
					<xsl:attribute name="display"><!--XLATESTART-->Type<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="Type='1'"><!--XLATESTART-->Autre<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='3'"><!--XLATESTART-->ISA<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='4'"><!--XLATESTART-->MCA<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='5'"><!--XLATESTART-->EISA<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='6'"><!--XLATESTART-->PCI<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='7'"><!--XLATESTART-->PCMCIA<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='8'"><!--XLATESTART-->VL VESA<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='9'"><!--XLATESTART-->Propri&#233;taire<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='10'"><!--XLATESTART-->Carte processeur<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='11'"><!--XLATESTART-->Carte m&#233;moire propri&#233;taire<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='12'"><!--XLATESTART-->Carte de montage d'E-S<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='13'"><!--XLATESTART-->NuBus<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='14'"><!--XLATESTART-->PCI 66Mhz<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='15'"><!--XLATESTART-->AGP<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='16'"><!--XLATESTART-->AGP 2X<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='17'"><!--XLATESTART-->AGP 4X<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='18'"><!--XLATESTART-->PCI X<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='160'"><!--XLATESTART-->PC98 C20<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='161'"><!--XLATESTART-->PC98 C24<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='162'"><!--XLATESTART-->PC98 E<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='163'"><!--XLATESTART-->Bus local PC98<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='164'"><!--XLATESTART-->Carte PC98<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><!--XLATESTART-->Inconnu<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="DataBusWidth">
					<xsl:attribute name="display"><!--XLATESTART-->Largeur du bus de donn&#233;es<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='1'"><!--XLATESTART-->Autre<!--XLATESTOP--></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='3'"><!--XLATESTART-->8 bits<!--XLATESTOP--></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='4'"><!--XLATESTART-->16 bits<!--XLATESTOP--></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='5'"><!--XLATESTART-->32 bits<!--XLATESTOP--></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='6'"><!--XLATESTART-->64 bits<!--XLATESTOP--></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='7'"><!--XLATESTART-->128 bits<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><!--XLATESTART-->Inconnu<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="Speed"  editable="false" type="ustring">
					<xsl:attribute name="display"><!--XLATESTART-->Vitesse<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="HotPlugSystemSlot/SlotSpeed='0'"><!--XLATESTART-->Inconnue<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><xsl:value-of select="HotPlugSystemSlot/SlotSpeed"/><xsl:text> </xsl:text><xsl:value-of select="HotPlugSystemSlot/SlotSpeed/@unit"/></xsl:otherwise>
						</xsl:choose></xsl:attribute>
				</Data>
				<Data name="SlotLength">
					<xsl:attribute name="display"><!--XLATESTART-->Longueur du logement<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="Length='1'"><!--XLATESTART-->Autre<!--XLATESTOP--></xsl:when>
							<xsl:when test="Length='3'"><!--XLATESTART-->Court<!--XLATESTOP--></xsl:when>
							<xsl:when test="Length='4'"><!--XLATESTART-->Long<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><!--XLATESTART-->Inconnu<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="VoltSupply"  editable="false" type="ustring">
					<xsl:attribute name="display"><!--XLATESTART-->Source de tension<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:if test="IsVolt33='true'">3.3 <!--XLATESTART-->volts<!--XLATESTOP--><xsl:if test="IsVolt5='true'">, </xsl:if></xsl:if>
						<xsl:if test="IsVolt5='true'">5 <!--XLATESTART-->volts<!--XLATESTOP--></xsl:if>
					</xsl:attribute>
				</Data>
			</ListData>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SystemBIOS">
		<ListData name="SystemBIOS">
			<xsl:attribute name="display"><!--XLATESTART-->Informations sur le BIOS<!--XLATESTOP--></xsl:attribute>
			<Data name="Manufacturer">
				<xsl:attribute name="display"><!--XLATESTART-->Fabricant<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Manufacturer"/></xsl:attribute>
			</Data>
			<Data name="Version">
				<xsl:attribute name="display"><!--XLATESTART-->Version<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Version"/></xsl:attribute>
			</Data>
			<Data name="ReleaseDate">
				<xsl:attribute name="display"><!--XLATESTART-->Date de diffusion<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="ReleaseDate"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="Network">
		<Section name="Network">
			<xsl:attribute name="display"><!--XLATESTART-->Donn&#233;es r&#233;seau<!--/XLATESTOP--></xsl:attribute>
			<xsl:choose>
				<xsl:when test="NICList">
					<xsl:apply-templates select="NICList" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
		</Section>
	</xsl:template>
	<xsl:template match="NICList">
			<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="NICCard">
		<ListData>
			<xsl:attribute name="name">NICList<xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="display"><!--XLATESTART--> Donn&#233;es de la carte d'interface r&#233;seau <xsl:value-of select="@index"/> <!--/XLATESTOP--></xsl:attribute>
			<Data>
				<xsl:attribute name="name">IPAddr<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><!--XLATESTART-->Adresse IP<!--/XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="IPAddress = ''"><!--XLATESTART-->Pas obtenue<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><xsl:value-of select="IPAddress"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">SubnetMask<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><!--XLATESTART-->Masque de sous-r&#233;seau<!--/XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="SubnetMask = ''"><!--XLATESTART-->Pas obtenu<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><xsl:value-of select="SubnetMask"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">DefaultGateway<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><!--XLATESTART-->Passerelle par d&#233;faut<!--/XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="DefaultGateway = ''"><!--XLATESTART-->Pas obtenue<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><xsl:value-of select="DefaultGateway"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">MacAddr<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><!--XLATESTART-->Adresse MAC<!--/XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="CurrentMACAddr = ''"><!--XLATESTART-->Pas obtenue<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><xsl:value-of select="CurrentMACAddr"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="IPAddrList">
		<ListData name="IPAddrList">
			<xsl:attribute name="display"><!--XLATESTART-->Donn&#233;es de l'adresse IP<!--XLATESTOP--></xsl:attribute>
			<xsl:apply-templates/>
		</ListData>
	</xsl:template>
	<xsl:template match="IPAddr">
		<Data name="IPAddr">
			<xsl:attribute name="name">IPAddr<xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="display"><!--XLATESTART-->Adresse IP <!--XLATESTOP--><xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
		</Data>
	</xsl:template>
	<xsl:template match="Software">
		<Section name="Software">
			<xsl:attribute name="display"><!--XLATESTART-->Profil du logiciel<!--XLATESTOP--></xsl:attribute>
			<xsl:apply-templates/>
		</Section>
	</xsl:template>
	<xsl:template match="OSInfo">
		<ListData name="OSInfo">
			<xsl:attribute name="display"><!--XLATESTART-->Syst&#232;me d'exploitation<!--XLATESTOP--></xsl:attribute>
			<Data name="OSName">
				<xsl:attribute name="display"><!--XLATESTART-->Nom<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="OSName"/></xsl:attribute>
			</Data>
			<Data name="OSVersion">
				<xsl:attribute name="display"><!--XLATESTART-->Version<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="OSVersion"/></xsl:attribute>
			</Data>
			<Data name="SystemTime">
				<xsl:attribute name="display"><!--XLATESTART-->Heure syst&#232;me<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="//System/SystemInfo/SystemTime"/></xsl:attribute>
			</Data>
			<Data name="SystemBootupTime">
				<xsl:attribute name="display"><!--XLATESTART-->Heure d'initialisation du syst&#232;me<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="//System/SystemInfo/SystemBootupTime"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="FirmwareList">
		<xsl:apply-templates />
	</xsl:template>
	<xsl:template match="Firmware">
		<ListData>
			<xsl:attribute name="name">Firmware_<xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="display"><!--XLATESTART-->Informations sur le micrologiciel<!--XLATESTOP--></xsl:attribute>
			<Data name="Name">
				<xsl:attribute name="display"><!--XLATESTART-->Nom<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="FWText"/></xsl:attribute>
			</Data>
			<Data name="Version">
				<xsl:attribute name="display"><!--XLATESTART-->Version<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="FWVersion"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>

	<xsl:template match="ClusterInfo">
		<Section name="ClusterInfo">
			<xsl:attribute name="display"><!--XLATESTART-->Informations sur le cluster<!--XLATESTOP--></xsl:attribute>
			<ListData name="Information">
				<xsl:attribute name="display"><!--XLATESTART-->Informations sur le cluster<!--XLATESTOP--></xsl:attribute>
				<Data name="ClusterName">
					<xsl:attribute name="display"><!--XLATESTART-->Nom du cluster<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ClusterName"/></xsl:attribute>
				</Data>
				<Data name="TypeDescription">
					<xsl:attribute name="display"><!--XLATESTART-->Description du cluster<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="TypeDescription"/></xsl:attribute>
				</Data>
				<Data name="ClusterType">
					<xsl:attribute name="display"><!--XLATESTART-->Type de cluster<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="ClusterType='2'"><!--XLATESTART-->Microsoft Cluster Server<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><!--XLATESTART-->Inconnu<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
			</ListData>
		</Section>
	</xsl:template>

	<xsl:template match="*"/>

</xsl:stylesheet>
