<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" />
	<xsl:strip-space elements="*"/>
	<xsl:template match="OMA">
		<xsl:choose>
			<xsl:when test="SMStatus != '0'">
				<DataArea printable="false">
					<PageTitle>
						<xsl:attribute name="display">
							<xsl:call-template name="smstatus">
								<xsl:with-param name="status"><xsl:value-of select="SMStatus"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
					</PageTitle>
				</DataArea>
			</xsl:when>
			<xsl:otherwise>
				<DataArea validate="true" onLoad="true">
				<xsl:attribute name="backpagedisplay"><!--XLATESTART-->&#12501;&#12449;&#12531; &#12503;&#12525;&#12540;&#12502;<!--XLATESTOP--></xsl:attribute>
					<xsl:apply-templates select="ServletArguments"/>
					<xsl:apply-templates select="FanProbe"/>
				</DataArea>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="FanProbe">
		<PageTitle></PageTitle>
		<SubHeader >
			<xsl:attribute name="display"><xsl:value-of select="ProbeLocation"/></xsl:attribute>
			<xsl:attribute name="status"><xsl:value-of select="@status"/></xsl:attribute>
		</SubHeader>
		<xsl:choose>
			<xsl:when test="(ProbeThresholds/LCThreshold &gt; 0) and (ProbeThresholds/UCThreshold &gt; 0) and (ProbeThresholds/LNCThreshold &gt; 0) and (ProbeThresholds/UNCThreshold &gt; 0) and (ProbeReading &gt;= 0)">
				<Guage  digits="0">
				<xsl:attribute name="units"> <!--XLATESTART-->RPM<!--XLATESTOP--></xsl:attribute>
					<Reading><xsl:value-of select="ProbeReading"/></Reading>
					<MFThresh><xsl:value-of select="ProbeThresholds/LCThreshold"/></MFThresh>
					<MXFThresh><xsl:value-of select="ProbeThresholds/UCThreshold"/></MXFThresh>
					<MWThresh><xsl:value-of select="ProbeThresholds/LNCThreshold"/></MWThresh>
					<MXWThresh><xsl:value-of select="ProbeThresholds/UNCThreshold"/></MXWThresh>
					<ListData>
						<Data display="&#12473;&#12486;&#12540;&#12479;&#12473;">
							<xsl:call-template name="StatusToStr">
								<xsl:with-param name="status"><xsl:value-of select="@status"/></xsl:with-param>
							</xsl:call-template>
						</Data>
						<Data display="&#35501;&#12415;&#21462;&#12426;&#20516;" reading="true">
							<xsl:attribute name="value"><xsl:value-of select="ProbeReading"/> <!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
						</Data>
						<Data display="&#26368;&#23567;&#12456;&#12521;&#12540;&#12375;&#12365;&#12356;&#20516;">
							<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/LCThreshold"/><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
						</Data>
						<Data display="&#26368;&#22823;&#12456;&#12521;&#12540;&#12375;&#12365;&#12356;&#20516;">
							<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/UCThreshold"/><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
						</Data>
						<xsl:choose>
						<xsl:when test="(Capabilities/ProbeUNCDefSetEnabled = 'true') or (Capabilities/ProbeLNCDefSetEnabled = 'true')">
						<Data display="&#12375;&#12365;&#12356;&#20516;&#12398;&#35373;&#23450;" type="radio"  state="1">
							<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
							<xsl:attribute name="value">&#12487;&#12501;&#12457;&#12523;&#12488;&#12395;&#35373;&#23450;</xsl:attribute>
						</Data>
							<xsl:if test="(Capabilities/ProbeUNCSetEnabled = 'true') or (Capabilities/ProbeLNCSetEnabled = 'true')">
							<Data type="radio">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">&#20516;&#12395;&#35373;&#23450;</xsl:attribute>
							</Data>
							</xsl:if>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="(Capabilities/ProbeUNCSetEnabled = 'true') or (Capabilities/ProbeLNCSetEnabled = 'true')">
							<Data display="&#12375;&#12365;&#12356;&#20516;&#12398;&#35373;&#23450;" type="radio"  state="1">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">&#20516;&#12395;&#35373;&#23450;</xsl:attribute>
							</Data>
							</xsl:if>
						</xsl:otherwise>
						</xsl:choose>
						<xsl:if test="(Capabilities/ProbeLNCSetEnabled = 'true')">
						<Data display="&#26368;&#23567;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;" type="editbox">
							<xsl:attribute name="textboxname">LNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
						</Data>
						</xsl:if>
						<xsl:if test="(Capabilities/ProbeUNCSetEnabled = 'true')">
						<Data display="&#26368;&#22823;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;" type="editbox">
							<xsl:attribute name="textboxname">UNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
						</Data>
						</xsl:if>
					</ListData>
				</Guage>
			</xsl:when>
			<xsl:otherwise>
				<ListData>
					<Data display="&#12473;&#12486;&#12540;&#12479;&#12473;">
						<xsl:call-template name="StatusToStr">
							<xsl:with-param name="status"><xsl:value-of select="@status"/></xsl:with-param>
						</xsl:call-template>
					</Data>
					<Data display="&#35501;&#12415;&#21462;&#12426;&#20516;">
						<xsl:attribute name="value"><xsl:value-of select="ProbeReading"/><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
					</Data>
					<Data display="&#26368;&#23567;&#12456;&#12521;&#12540;&#12375;&#12365;&#12356;&#20516;">
						<xsl:choose>
							<xsl:when test="ProbeThresholds/LCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/LCThreshold"/><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value"><!--XLATESTART-->&#19981;&#26126;<!--XLATESTOP--></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</Data>			
					<Data display="&#26368;&#22823;&#12456;&#12521;&#12540;&#12375;&#12365;&#12356;&#20516;">
						<xsl:choose>
							<xsl:when test="ProbeThresholds/UCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/UCThreshold"/><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value"><!--XLATESTART-->&#19981;&#26126;<!--XLATESTOP--></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</Data>
					<Data display="&#12375;&#12365;&#12356;&#20516;&#12398;&#35373;&#23450;" type="radio"  state="1">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
						<xsl:attribute name="value">Set to Default</xsl:attribute>
					</Data>
					<Data type="radio">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
						<xsl:attribute name="value">Set to Values</xsl:attribute>
					</Data>
					<Data display="&#26368;&#23567;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;" type="editbox" size="5">
						<xsl:attribute name="name">LNCVal</xsl:attribute>
						<xsl:choose>
							<xsl:when test="ProbeThresholds/LNCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value">0</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:attribute name="unit"><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
					</Data>
					<Data display="&#26368;&#22823;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;" type="editbox" size="5">
						<xsl:attribute name="name">UNCVal</xsl:attribute>
						<xsl:choose>
							<xsl:when test="ProbeThresholds/UNCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value">0</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:attribute name="unit"><!--XLATESTART--> RPM<!--XLATESTOP--></xsl:attribute>
					</Data>
				</ListData>
			</xsl:otherwise>
		</xsl:choose>
		<script language="javascript">
			isProbeUNCSetEnabled 		= <xsl:value-of select="Capabilities/ProbeUNCSetEnabled"/>;
			isProbeLNCSetEnabled 		= <xsl:value-of select="Capabilities/ProbeLNCSetEnabled"/>;
			isProbeUNCDefSetEnabled 	= <xsl:value-of select="Capabilities/ProbeUNCDefSetEnabled"/>;
			isProbeLNCDefSetEnabled 	= <xsl:value-of select="Capabilities/ProbeLNCDefSetEnabled"/>;
		
			setToDefault	= true;
			setToValues	= false;

if( (( ! isProbeUNCDefSetEnabled )  &amp;&amp; (! isProbeLNCDefSetEnabled)) &amp;&amp; ( isProbeUNCSetEnabled || isProbeLNCSetEnabled ) )
{
	setToValues	= true;
}

			function initializationRoutine()
			{
				if( isProbeUNCSetEnabled )
				{
					document.getElementById("UNCVal").value = <xsl:value-of select="ProbeThresholds/UNCThreshold"/>;
					document.getElementById("UNCVal").disabled = false;
					if ( ( isProbeUNCDefSetEnabled || isProbeLNCDefSetEnabled ) &amp;&amp; setToDefault )
					{
						document.getElementById("UNCVal").disabled = true;
					}
				}

				if( isProbeLNCSetEnabled )
				{
					document.getElementById("LNCVal").value = <xsl:value-of select="ProbeThresholds/LNCThreshold"/>;
					document.getElementById("LNCVal").disabled = false;
					if ( ( isProbeUNCDefSetEnabled || isProbeLNCDefSetEnabled ) &amp;&amp; setToDefault )
					{
						document.getElementById("LNCVal").disabled = true;
					}
				}
				
				if( isProbeUNCDefSetEnabled || isProbeLNCDefSetEnabled )
				{
					document.getElementById("threshsetting").checked = true;
				}
			}
			
			function setToVal()
			{
				setToValues = true;
				setToDefault = false;
				if( isProbeUNCSetEnabled )
				{
					document.getElementById("UNCVal").disabled = false;
				}

				if( isProbeLNCSetEnabled )
				{
					document.getElementById("LNCVal").disabled = false;
				}
			}
			
			function setToDef()
			{
				setToDefault = true;
				setToValues = false;
				if( isProbeUNCSetEnabled )
				{
					document.getElementById("UNCVal").disabled = true;
				}

				if( isProbeLNCSetEnabled )
				{
					document.getElementById("LNCVal").disabled = true;
				}
			}

			function validate()
			{
				<xsl:choose>
					<xsl:when test="ProbeThresholds/UCThreshold &gt; 0 ">
						var UC 	= parseFloat("<xsl:value-of select="ProbeThresholds/UCThreshold"/>");
						var preUNC = <xsl:value-of select="ProbeThresholds/UNCThreshold"/>;
					</xsl:when>
					<xsl:otherwise>
						var UC 	= 0;
						var preUNC = <xsl:value-of select="ProbeThresholds/UNCThreshold"/>;
					</xsl:otherwise>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="ProbeThresholds/LCThreshold &gt; 0 ">
						var LC = parseFloat("<xsl:value-of select="ProbeThresholds/LCThreshold"/>");
						var preLNC = <xsl:value-of select="ProbeThresholds/LNCThreshold"/>;
					</xsl:when>
					<xsl:otherwise>
						var LC = 0;
						var preLNC = <xsl:value-of select="ProbeThresholds/LNCThreshold"/>;
					</xsl:otherwise>
				</xsl:choose>
				
				if(setToValues)
				{
					// &#12518;&#12540;&#12470;&#12399;&#12375;&#12365;&#12356;&#20516;&#12434;&#22793;&#26356;&#12375;&#12414;&#12375;&#12383;&#12290;
					
					<xsl:if test="Capabilities/ProbeUNCSetEnabled = 'true' ">
						document.getElementById("UNCVal").disabled = false;
						var tempUNC = document.getElementById("UNCVal").value;
						
						if(isNaN(tempUNC) == true)
						{
							alert("&#12456;&#12521;&#12540;! &#26368;&#22823;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12399;&#25968;&#23383;&#12391;&#12394;&#12369;&#12428;&#12400;&#12356;&#12369;&#12414;&#12379;&#12435;&#12290;&#35501;&#12415;&#21462;&#12426;&#20516;: " + tempUNC);
							document.getElementById("UNCVal").value = preUNC;
							document.getElementById("LNCVal").value = preLNC;
							return false;
						}
						
						if(isNaN(parseFloat(tempUNC)) == true)
						{
							alert("&#12456;&#12521;&#12540;! &#26368;&#22823;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12399;&#25972;&#25968;&#12391;&#12394;&#12369;&#12428;&#12400;&#12356;&#12369;&#12414;&#12379;&#12435;&#12290;&#35501;&#12415;&#21462;&#12426;&#20516;: " + tempUNC);
						document.getElementById("UNCVal").value = preUNC;
						document.getElementById("LNCVal").value = preLNC;
						return false;
					}
					else
					{
						if(tempUNC.indexOf(".") != "-1")
								{
									alert("&#12456;&#12521;&#12540;! &#26368;&#22823;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12399;&#25972;&#25968;&#12391;&#12394;&#12369;&#12428;&#12400;&#12356;&#12369;&#12414;&#12379;&#12435;&#12290;&#35501;&#12415;&#21462;&#12426;&#20516;: " + tempUNC);
								document.getElementById("UNCVal").value = preUNC;
								return false;
							}
						}
						
						var UNC 	= parseFloat(document.getElementById("UNCVal").value);
					</xsl:if>
					
					<xsl:if test="Capabilities/ProbeLNCSetEnabled = 'true' ">
						document.getElementById("LNCVal").disabled = false;
						var tempLNC 	= document.getElementById("LNCVal").value;
						
						if( isNaN(tempLNC) == true)
						{
							alert("&#12456;&#12521;&#12540;! &#26368;&#23567;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12399;&#25968;&#23383;&#12391;&#12394;&#12369;&#12428;&#12400;&#12356;&#12369;&#12414;&#12379;&#12435;&#12290;&#35501;&#12415;&#21462;&#12426;&#20516;: " + tempLNC);
							document.getElementById("UNCVal").value = preUNC;
							document.getElementById("LNCVal").value = preLNC;
							return false;
						}
						
						
						if( isNaN(parseFloat(tempLNC)) == true)
						{
							alert("&#12456;&#12521;&#12540;! &#26368;&#23567;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12399;&#25972;&#25968;&#12391;&#12394;&#12369;&#12428;&#12400;&#12356;&#12369;&#12414;&#12379;&#12435;&#12290;&#35501;&#12415;&#21462;&#12426;&#20516;: " + tempLNC);
						document.getElementById("UNCVal").value = preUNC;
						document.getElementById("LNCVal").value = preLNC;
						return false;
					}
					else
					{
						if(tempLNC.indexOf(".") != "-1")
								{
									alert("&#12456;&#12521;&#12540;! &#26368;&#23567;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12399;&#25972;&#25968;&#12391;&#12394;&#12369;&#12428;&#12400;&#12356;&#12369;&#12414;&#12379;&#12435;&#12290;&#35501;&#12415;&#21462;&#12426;&#20516;: " + tempLNC);
								document.getElementById("LNCVal").value = preLNC;
								return false;
							}
						}
						
						var LNC 	= parseFloat(document.getElementById("LNCVal").value);
					</xsl:if>
							
					if( isProbeUNCSetEnabled &amp;&amp; (! isProbeLNCSetEnabled) )
					{
						// &#19978;&#37096;&#12398;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12398;&#12415;&#12364;&#35373;&#23450;&#21487;&#33021;&#12391;&#12377;&#12290;

						if((UC &gt; 0) &amp;&amp; (LC &gt; 0))
						{
							if((UC &gt; UNC) &amp;&amp; (UNC &gt; LC))
							{
								return true;
							}
							else
							{
								alert("&#12456;&#12521;&#12540;! [" + UNC + "] &#12398;&#26368;&#22823;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12364; " + LC + " RPM~ " + UC + "RPM &#12398;&#31684;&#22258;&#12391;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;" );
							}
						}
						else
						{
							// UC and  LC are not available to do validation of UNC value.
							return true;
						}
						
						document.getElementById("UNCVal").value = preUNC;
					}
					else if( (! isProbeUNCSetEnabled ) &amp;&amp; isProbeLNCSetEnabled )
					{
						// &#20302;&#12356;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12398;&#12415;&#12364;&#35373;&#23450;&#21487;&#33021;&#12391;&#12377;&#12290;
						
						if((UC &gt; 0) &amp;&amp; (LC &gt; 0))
						{
							if((UC &gt; LNC) &amp;&amp; (LNC &gt; LC))
							{
								return true;
							}
							else
							{
								alert("&#12456;&#12521;&#12540;! &#26368;&#23567;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516; [" + LNC + "] &#12399; " + LC + " RPM ~ " + UC + " RPM &#12398;&#31684;&#22258;&#12391;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;" );
							}
						}
						else
						{
							// UC and LC are not available to do validation of LNC value.
							return true;
						}
						
						document.getElementById("LNCVal").value = preLNC;
					}
					else
					{
						// both are settable
						
						if((UC &gt; 0) &amp;&amp; (LC &gt; 0))
						{
							if((UC &gt; UNC) &amp;&amp; (UNC &gt; LC))
							{
								if(UNC &gt; LNC)
								{
									if(LNC &gt; LC)
									{
										return true;
									}
									else
									{
										alert("&#12456;&#12521;&#12540;! [" + LNC + "] &#12398;&#26368;&#23567;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12364; " + LC + " RPM &#65374; " + UNC + " RPM &#12398;&#31684;&#22258;&#12391;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;" );
								}
							}
							else
							{
								alert("&#12456;&#12521;&#12540;! &#26368;&#23567;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12434;&#26368;&#22823;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12392;&#21516;&#12376;&#12414;&#12383;&#12399;&#12381;&#12428;&#12424;&#12426;&#22823;&#12365;&#12367;&#12377;&#12427;&#12371;&#12392;&#12399;&#12391;&#12365;&#12414;&#12379;&#12435;" );
						}
					}
					else
					{
						if((UC &gt; LNC) &amp;&amp; (LNC &gt; LC))
						{
							alert("&#12456;&#12521;&#12540;! [" + UNC + "] &#12398;&#26368;&#22823;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12364; " + LNC + " RPM &#65374; " + UC + " RPM &#12398;&#31684;&#22258;&#12391;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;" );
							}
							else
							{
								alert("&#12456;&#12521;&#12540;! [" + UNC + "] &#12398;&#26368;&#22823;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12364;&#12289; " + preLNC + " RPM &#65374; " + UC + " RPM &#12398;&#31684;&#22258;&#12391;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;" );
							}
						}
					}
					else
					{
							<!-- UC and LC have invalid values. Accept the user values if they are positive-->						
							if( UNC &gt; 0)
						{
							if( LNC &gt; 0)
							{
								if(UNC &gt; LNC)
								{
									return true;
								}
								else
								{
									alert("&#12456;&#12521;&#12540;! &#26368;&#23567;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12434;&#26368;&#22823;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12392;&#21516;&#12376;&#12363;&#12381;&#12428;&#12424;&#12426;&#22823;&#12365;&#12367;&#12377;&#12427;&#12371;&#12392;&#12399;&#12391;&#12365;&#12414;&#12379;&#12435;" );
								}
							}
							else
							{
								alert("&#12456;&#12521;&#12540;! &#26368;&#23567;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12399;&#31526;&#21495;&#12398;&#12388;&#12356;&#12390;&#12356;&#12394;&#12356;&#25968;&#20516;&#12391;&#12394;&#12369;&#12428;&#12400;&#12356;&#12369;&#12414;&#12379;&#12435;&#12290;&#35501;&#12415;&#21462;&#12426;&#20516;: " + LNC);
							}
						}
						else
						{
							alert("&#12456;&#12521;&#12540;! &#26368;&#22823;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12399;&#31526;&#21495;&#12398;&#12388;&#12356;&#12390;&#12356;&#12394;&#12356;&#25968;&#20516;&#12391;&#12394;&#12369;&#12428;&#12400;&#12356;&#12369;&#12414;&#12379;&#12435;&#12290;&#35501;&#12415;&#21462;&#12426;&#20516;: " + UNC);
							}
						}

						document.getElementById("UNCVal").value = preUNC;
						document.getElementById("LNCVal").value = preLNC;
					}
				}
				else
				{
					// do not validate the values if user has selected default threshold settings.
					return true;
				}
				
				<!--  returning false doesn't submit the form -->
				return false;
			}
		</script>
	</xsl:template>
	<xsl:template match="ServletArguments">
		<xsl:attribute name="submit">/servlet/SubmitForm?plugin=com.dell.hip.webplugins.SetFanWebPlugin&amp;oid=<xsl:value-of select="@OID"/>&amp;poid=<xsl:value-of select="@POID"/>&amp;objtype=<xsl:value-of select="@PObjType"/>
</xsl:attribute>
		<xsl:attribute name="backpagetarget">/servlet/DataArea?plugin=com.dell.hip.webplugins.FanProbesWebPlugin&amp;poid=<xsl:value-of select="@POID"/>&amp;help=Fans</xsl:attribute>
		<CustomButton>
			<Data  name="" >
			<xsl:attribute name="display"><!--XLATESTART-->&#26356;&#26032;<!--XLATESTOP--></xsl:attribute>
							<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.hip.webplugins.EditFanProbeWebPlugin&amp;oid=<xsl:value-of select="@OID"/>&amp;poid=<xsl:value-of select="@POID"/>&amp;help=EditFanProbe</xsl:attribute>
			</Data>
		</CustomButton>
	</xsl:template>
		<xsl:template name="StatusToStr">
		<xsl:param name="status"/>
		<xsl:choose>
			<xsl:when test="$status = 1">
				<xsl:attribute name="value">Unknown</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 2">
				<xsl:attribute name="value">OK</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 3">
				<xsl:attribute name="value">Non Critical</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 4">
				<xsl:attribute name="value">Critical</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 5">
				<xsl:attribute name="value">Non Recoverable</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:attribute name="value">Other</xsl:attribute>
			</xsl:otherwise>
		</xsl:choose>				
	</xsl:template>
	<xsl:template name="DataType">
		<xsl:param name="name"/>
		<xsl:param name="display"/>
		<xsl:param name="value"/>
		<xsl:param name="type"/>
		<xsl:param name="link"/>
		<xsl:param name="href"/>		
		<Data >
			<xsl:attribute name="name"><xsl:value-of select="$name"/></xsl:attribute>
			<xsl:attribute name="display"><xsl:value-of select="$display"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$value"/></xsl:attribute>
			<xsl:attribute name="link"><xsl:value-of select="$link"/></xsl:attribute>
			<xsl:attribute name="href"><xsl:value-of select="$href"/></xsl:attribute>
			<xsl:attribute name="type"><xsl:value-of select="$type"/></xsl:attribute>
		</Data>
	</xsl:template>
		<xsl:template name="smstatus">
		<xsl:param name="status"/>
		<xsl:param name="mssg"/>
		<xsl:choose>
			<xsl:when test="$status = '-1'"><!--XLATESTART-->&#12467;&#12510;&#12531;&#12489;&#22833;&#25943;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '0'"><!--XLATESTART-->&#12467;&#12510;&#12531;&#12489;&#25104;&#21151;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '1'"><!--XLATESTART-->&#12467;&#12510;&#12531;&#12489;&#26410;&#23455;&#35013;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '2'"><!--XLATESTART-->&#19981;&#27491;&#12467;&#12510;&#12531;&#12489;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '3'"><!--XLATESTART-->&#12467;&#12510;&#12531;&#12489; &#12479;&#12452;&#12512;&#12450;&#12454;&#12488;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '4'"><!--XLATESTART-->&#12467;&#12510;&#12531;&#12489; &#12461;&#12515;&#12531;&#12475;&#12523;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '5'"><!--XLATESTART-->&#12467;&#12510;&#12531;&#12489;&#20013;&#27490;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '6'"><!--XLATESTART-->&#12467;&#12510;&#12531;&#12489;&#20445;&#30041;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '7'"><!--XLATESTART-->&#12487;&#12496;&#12452;&#12473;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '8'"><!--XLATESTART-->&#12487;&#12496;&#12452;&#12473;&#12399;&#20351;&#29992;&#20013;&#12391;&#12377;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '9'"><!--XLATESTART-->&#19981;&#27491;&#12394;&#12487;&#12496;&#12452;&#12473;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '10'"><!--XLATESTART-->&#19981;&#27491;&#12394;&#20013;&#26029;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '11'"><!--XLATESTART-->&#12522;&#12477;&#12540;&#12473;&#12364;&#12525;&#12483;&#12463;&#12373;&#12428;&#12390;&#12356;&#12414;&#12377;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '12'"><!--XLATESTART-->&#28961;&#21177;&#12394;&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '13'"><!--XLATESTART-->SMB &#12456;&#12521;&#12540;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '14'"><!--XLATESTART-->&#35201;&#27714;&#12373;&#12428;&#12383;&#12487;&#12540;&#12479;&#12399;&#20837;&#25163;&#12391;&#12365;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '15'"><!--XLATESTART-->&#35201;&#27714;&#12373;&#12428;&#12383;&#12487;&#12540;&#12479;&#12399;&#20351;&#29992;&#12391;&#12365;&#12427;&#12487;&#12540;&#12479;&#12434;&#19978;&#22238;&#12387;&#12390;&#12356;&#12414;&#12377;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '16'"><!--XLATESTART-->&#35201;&#27714;&#12373;&#12428;&#12383;&#12487;&#12540;&#12479;&#12399;&#20351;&#29992;&#12391;&#12365;&#12427;&#12487;&#12540;&#12479;&#12434;&#19979;&#22238;&#12387;&#12390;&#12356;&#12414;&#12377;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '17'"><!--XLATESTART-->&#12487;&#12496;&#12452;&#12473;&#12391;&#12467;&#12510;&#12531;&#12489;&#12434;&#21463;&#29702;&#12377;&#12427;&#28310;&#20633;&#12364;&#12391;&#12365;&#12390;&#12356;&#12414;&#12379;&#12435; &#20877;&#35430;&#34892;&#12375;&#12390;&#12367;&#12384;&#12373;&#12356;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '18'"><!--XLATESTART-->&#12487;&#12496;&#12452;&#12473;&#12395;&#12487;&#12540;&#12479;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '19'"><!--XLATESTART-->&#12487;&#12496;&#12452;&#12473;&#12364;&#12513;&#12514;&#12522;&#19981;&#36275;&#12391;&#12377;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '20'"><!--XLATESTART-->&#12487;&#12496;&#12452;&#12473;&#12399;&#26082;&#12395;&#23384;&#22312;&#12375;&#12414;&#12377;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '256'"><!--XLATESTART-->&#12501;&#12449;&#12531; &#12458;&#12502;&#12472;&#12455;&#12463;&#12488;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '257'"><!--XLATESTART-->&#12501;&#12449;&#12531;&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;&#12398;&#24418;&#24335;&#12364;&#35492;&#12387;&#12390;&#12356;&#12427;&#12363;&#12289;&#30772;&#25613;&#12375;&#12390;&#12356;&#12427;&#12363;&#19981;&#27491;&#12391;&#12377;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '258'"><!--XLATESTART-->&#12501;&#12449;&#12531;&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;&#12399;&#26082;&#12395;&#23384;&#22312;&#12375;&#12414;&#12377;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '260'"><!--XLATESTART-->INI &#12501;&#12449;&#12452;&#12523;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '261'"><!--XLATESTART-->INI &#12398;&#24418;&#24335;&#12364;&#35492;&#12387;&#12390;&#12356;&#12427;&#12363;&#12289;&#30772;&#25613;&#12375;&#12390;&#12356;&#12427;&#12363;&#19981;&#27491;&#12391;&#12377;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '262'"><!--XLATESTART-->INI &#12475;&#12463;&#12471;&#12519;&#12531;&#12364;&#23384;&#22312;&#12375;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '263'"><!--XLATESTART-->INI &#12461;&#12540;&#12364;&#23384;&#22312;&#12375;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '264'"><!--XLATESTART-->INI &#12398;&#20516;&#12398;&#24418;&#24335;&#12364;&#35492;&#12387;&#12390;&#12356;&#12427;&#12363;&#12289;&#30772;&#25613;&#12375;&#12390;&#12356;&#12427;&#12363;&#19981;&#27491;&#12391;&#12377;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '270'"><!--XLATESTART-->&#12450;&#12463;&#12475;&#12473;&#27177;&#12364;&#21313;&#20998;&#12391;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '271'"><!--XLATESTART-->&#12497;&#12521;&#12513;&#12540;&#12479;&#21517;&#12414;&#12383;&#12399;&#20516;&#12364;&#28961;&#21177;&#12391;&#12377;: <!--XLATESTOP--><xsl:value-of select="$mssg"/></xsl:when>
			<xsl:when test="$status = '272'"><!--XLATESTART-->&#12513;&#12514;&#12522;&#19981;&#36275;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '280'"><!--XLATESTART-->XML &#12501;&#12449;&#12452;&#12523;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '281'"><!--XLATESTART-->XML &#12398;&#24418;&#24335;&#12364;&#35492;&#12387;&#12390;&#12356;&#12427;&#12363;&#12289;&#30772;&#25613;&#12375;&#12390;&#12356;&#12427;&#12363;&#19981;&#27491;&#12391;&#12377;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '282'"><!--XLATESTART-->XML &#12494;&#12540;&#12489;&#12364;&#23384;&#22312;&#12375;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '283'"><!--XLATESTART-->XML &#12398;&#20516;&#12398;&#24418;&#24335;&#12364;&#35492;&#12387;&#12390;&#12356;&#12427;&#12363;&#12289;&#30772;&#25613;&#12375;&#12390;&#12356;&#12427;&#12363;&#19981;&#27491;&#12391;&#12377;<!--XLATESTOP--></xsl:when>
		<xsl:otherwise>SMStatus: <xsl:value-of select="$status"/></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="*"/>
</xsl:stylesheet>
