<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
<xsl:template match="OMA">
	<xsl:if test="(OMAUserRights = '7') or (OMAUserRights = '3')">
		<xsl:choose>
			<xsl:when test="(VoltageProbe/ProbeThresholds/LCThreshold != '-2147483648') and (VoltageProbe/ProbeThresholds/UCThreshold != '-2147483648') and (VoltageProbe/ProbeThresholds/LNCThreshold != '-2147483648') and (VoltageProbe/ProbeThresholds/UNCThreshold != '-2147483648') and (VoltageProbe/ProbeReading != '-2147483648')">
				<xsl:choose>
					<xsl:when test="SMStatus='0'"><xsl:apply-templates select="VoltageProbe"/></xsl:when>
					<xsl:otherwise><xsl:call-template name="failure"/></xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise><xsl:call-template name="invalid"/></xsl:otherwise>
		</xsl:choose>
	</xsl:if>
</xsl:template>

<xsl:template name="failure">
	<DataArea>
		<PageTitle>
			<xsl:attribute name="display"><!--XLATESTART-->&#38651;&#22311;&#12503;&#12525;&#12540;&#12502;<!--XLATESTOP--></xsl:attribute>
		</PageTitle>
		<TableData>
			<Row>
				<Data name=""  display="">
					<xsl:attribute name="value">
						<xsl:call-template name="smstatus">
							<xsl:with-param name="status"><xsl:value-of select="SMStatus"/></xsl:with-param>
						</xsl:call-template>
					</xsl:attribute>
				</Data>
			</Row>
		</TableData>
	</DataArea>
</xsl:template>

<xsl:template name="invalid">
	<DataArea>
		<PageTitle>
			<xsl:attribute name="display"><!--XLATESTART-->&#38651;&#22311;&#12503;&#12525;&#12540;&#12502;<!--XLATESTOP--></xsl:attribute>
		</PageTitle>
		<PromptText><!--XLATESTART-->&#38651;&#22311;&#12503;&#12525;&#12540;&#12502;&#12375;&#12365;&#12356;&#20516;&#12289;&#12414;&#12383;&#12399;&#12503;&#12525;&#12540;&#12502;&#35501;&#12415;&#21462;&#12426;&#20516;&#12395;&#28961;&#21177;&#12394;&#20516;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;<!--XLATESTOP--></PromptText>
	</DataArea>
</xsl:template>

<xsl:template match="VoltageProbe">
	<DataArea  backpagedisplay="&#38651;&#22311;&#12503;&#12525;&#12540;&#12502;" validate="true"  onLoad="true">
		<xsl:attribute name="submit">/servlet/SubmitForm?plugin=com.dell.hip.webplugins.SetVoltageWebPlugin&amp;oid=<xsl:value-of select="@oid"/></xsl:attribute>
		<xsl:attribute name="backpagetarget">/servlet/DataArea?plugin=com.dell.hip.webplugins.ListVoltageWebPlugin&amp;poid=<xsl:value-of select="@poid"/>&amp;help=Voltages</xsl:attribute>
		<PageTitle>PageTitle</PageTitle>
		<Header>Header</Header>
		<SubHeader>
			<xsl:attribute name="display"><xsl:value-of select="ProbeLocation"/></xsl:attribute>
			<xsl:attribute name="status"><xsl:value-of select="@status"/></xsl:attribute>
		</SubHeader>
		<CustomButton>
			<Data name="Refresh">
			<xsl:attribute name="display"><!--XLATESTART-->&#26356;&#26032;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="href">
					/servlet/DataArea?plugin=com.dell.hip.webplugins.VoltageWebPlugin&amp;oid=<xsl:value-of select="@oid"/>&amp;poid=<xsl:value-of select="@poid"/>&amp;help=EditVoltageProbes
				</xsl:attribute>
			</Data>
		</CustomButton>
		<xsl:choose>
			<xsl:when test="(ProbeThresholds/LCThreshold != '-2147483648') and (ProbeThresholds/UCThreshold != '-2147483648') and (ProbeThresholds/LNCThreshold != '-2147483648') and (ProbeThresholds/UNCThreshold != '-2147483648') and (ProbeReading != '-2147483648')">
				<Guage digits="3">
					<xsl:attribute name="units"><!--XLATESTART-->V<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="showdecsep"><!--XLATESTART-->.<!--XLATESTOP--></xsl:attribute>
					<Reading>
						<xsl:call-template name="calVolt">
							<xsl:with-param name="volt"><xsl:value-of select="ProbeReading"/></xsl:with-param>
						</xsl:call-template>
					</Reading>
					<MFThresh>
						<xsl:call-template name="calVolt">
							<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LCThreshold"/></xsl:with-param>
						</xsl:call-template>
					</MFThresh>
					<MXFThresh>
						<xsl:call-template name="calVolt">
							<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param>
						</xsl:call-template>
					</MXFThresh>
					<MWThresh>
						<xsl:call-template name="calVolt">
							<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:with-param>
						</xsl:call-template>
					</MWThresh>
					<MXWThresh>
						<xsl:call-template name="calVolt">
							<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param>
						</xsl:call-template>
					</MXWThresh>
					<ListData>
						<Data display="&#12473;&#12486;&#12540;&#12479;&#12473;" type="status-text">							<xsl:attribute name="value"><xsl:value-of select="@status"/></xsl:attribute>
						</Data>
						<Data display="&#35501;&#12415;&#21462;&#12426;&#20516;" reading="true">
							<xsl:attribute name="value">
								<xsl:call-template name="showcalVolt">
									<xsl:with-param name="volt"><xsl:value-of select="ProbeReading"/></xsl:with-param>
								</xsl:call-template><!--XLATESTART-->V<!--XLATESTOP-->
							</xsl:attribute>
						</Data>
						<Data display="&#26368;&#23567;&#12456;&#12521;&#12540;&#12375;&#12365;&#12356;&#20516;">
							<xsl:attribute name="value">
								<xsl:call-template name="showcalVolt">
									<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LCThreshold"/></xsl:with-param>
								</xsl:call-template><!--XLATESTART-->V<!--XLATESTOP-->
							</xsl:attribute>
						</Data>
						<Data display="&#26368;&#22823;&#12456;&#12521;&#12540;&#12375;&#12365;&#12356;&#20516;">
							<xsl:attribute name="value">
								<xsl:call-template name="showcalVolt">
									<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param>
								</xsl:call-template><!--XLATESTART-->V<!--XLATESTOP-->
							</xsl:attribute>
						</Data>
						<xsl:choose>
							<xsl:when test="(Capabilities/ProbeUNCDefSetEnabled = 'true') or (Capabilities/ProbeLNCDefSetEnabled = 'true')">			
							<Data display="&#12375;&#12365;&#12356;&#20516;&#12398;&#35373;&#23450;" type="radio"  state="1">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
						<xsl:attribute name="value">Set to Default</xsl:attribute>
							</Data>						
							<Data type="radio">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">Set to Values</xsl:attribute>
							</Data>
							</xsl:when>
							<xsl:otherwise>
							<Data display="&#12375;&#12365;&#12356;&#20516;&#12398;&#35373;&#23450;" type="radio"  state="1">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">Set to Values</xsl:attribute>
							</Data>												
							</xsl:otherwise>
						</xsl:choose>
						<Data display="&#26368;&#23567;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;" type="editbox">
							<xsl:attribute name="textboxname">LNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue">
								<xsl:call-template name="showcalVolt">
									<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:with-param>
								</xsl:call-template>
							</xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART-->V<!--XLATESTOP--></xsl:attribute>
						</Data>
						<Data display="&#26368;&#22823;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;" type="editbox">
							<xsl:attribute name="textboxname">UNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue">
								<xsl:call-template name="showcalVolt">
									<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param>
								</xsl:call-template>
							</xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART--> V<!--XLATESTOP--></xsl:attribute>
						</Data>
					</ListData>
				</Guage>
			</xsl:when>
			<xsl:otherwise>
				<ListData>
					<Data name="plugin" type="hidden">
						<xsl:attribute name="returnvalue">com.dell.hip.webplugins.SetVoltageWebPlugin</xsl:attribute>
					</Data>
					<Data name="oid" type="hidden">
						<xsl:attribute name="returnvalue"><xsl:value-of select="@oid"/></xsl:attribute>
					</Data>
								<xsl:element name="Data"><xsl:attribute name="name">Status</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="@status"/></xsl:attribute>
						<xsl:attribute name="display"><!--XLATESTART-->&#29366;&#24907;<!--XLATESTOP--></xsl:attribute>
						<xsl:attribute name="type">status-text</xsl:attribute>
					</xsl:element>
					<xsl:element name="Data">
						<xsl:attribute name="value">
							<xsl:call-template name="showcalVolt">
								<xsl:with-param name="volt"><xsl:value-of select="ProbeReading"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:attribute name="display"><!--XLATESTART-->&#35501;&#12415;&#21462;&#12426;&#20516;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="type">ustring</xsl:attribute>
						<xsl:attribute name="unit"><!--XLATESTART--> V<!--XLATESTOP--></xsl:attribute>
					</xsl:element>
					<xsl:element name="Data">
						<xsl:attribute name="value">
							<xsl:call-template name="showcalVolt">
								<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LCThreshold"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:attribute name="display"><!--XLATESTART-->&#26368;&#23567;&#12456;&#12521;&#12540;&#12375;&#12365;&#12356;&#20516;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="type">ustring</xsl:attribute>
						<xsl:attribute name="unit"> <!--XLATESTART-->
V<!--XLATESTOP--></xsl:attribute>
					</xsl:element>
					<xsl:element name="Data">
						<xsl:attribute name="value">
							<xsl:call-template name="showcalVolt">
								<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:attribute name="display"><!--XLATESTART-->&#26368;&#22823;&#12456;&#12521;&#12540;&#12375;&#12365;&#12356;&#20516;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="type">ustring</xsl:attribute>
						<xsl:attribute name="unit"><!--XLATESTART--> V<!--XLATESTOP--></xsl:attribute>
					</xsl:element>
					<Data display="&#12375;&#12365;&#12356;&#20516;&#12398;&#35373;&#23450;" type="radio"  state="1">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
						<xsl:attribute name="value">Set to Default</xsl:attribute>
					</Data>
					<Data type="radio">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">Set to Values</xsl:attribute>
					</Data>
					<Data display="&#26368;&#23567;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;" type="editbox" size="6">						<xsl:attribute name="name">LNCVal</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:call-template name="showcalVolt">
								<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:attribute name="unit"><!--XLATESTART--> V<!--XLATESTOP--></xsl:attribute>
					</Data>
					<Data display="&#26368;&#22823;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;" type="editbox" size="6">						<xsl:attribute name="name">UNCVal</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:call-template name="showcalVolt">
								<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:attribute name="unit"><!--XLATESTART--> V<!--XLATESTOP--></xsl:attribute>
					</Data>
				</ListData>
			</xsl:otherwise>
		</xsl:choose>
		
		<script language="javascript" src="/oma/js/Probe.js" />
		
		<script language="javascript">
		
			var setToDefault	= true;
			var setToValues	= false;
			var UC;
			var LC;
			var preUNC;
			var preLNC;
			var UCTxt;
			var LCTxt;
			var preUNCTxt;
			var preLNCTxt;
			var toggleunivDecsep = <!--XLATESTART-->"."<!--XLATESTOP-->; //In German ,French and Spanish, change it to ",". In en, it should be ".".
			var togglelocalDecsep = <!--XLATESTART-->","<!--XLATESTOP-->;//In German ,French and Spanish, change it to ".".In en, it should be ",".
			var univDecsep = "."; // don't translate.
			var unit =  <!--XLATESTART-->"V"<!--XLATESTOP-->;
			var multiplier = 1000;
			var lengthval = 4;
			var msg1 = <!--XLATESTART-->"&#12456;&#12521;&#12540;! &#25968;&#23383;&#12398;&#23567;&#25968;&#28857;&#20197;&#19979;&#12399;&#26368;&#22823; 3 &#26689;&#12414;&#12391;&#12391;&#12377;&#12290;&#35501;&#12415;&#21462;&#12426;&#20516;: "<!--XLATESTOP-->;
			var msg2 = <!--XLATESTART-->"&#12456;&#12521;&#12540;! &#20516; ["<!--XLATESTOP-->;
			var msg3 = <!--XLATESTART-->"] &#12398;&#31684;&#22258;&#12391;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;"<!--XLATESTOP-->;
			var msg4 = <!--XLATESTART-->"  &#65374; "<!--XLATESTOP-->;
			var msg5 = <!--XLATESTART-->" &#26368;&#23567;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12398; "<!--XLATESTOP-->;
			var msg6 = <!--XLATESTART-->" &#26368;&#22823;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12398;"<!--XLATESTOP-->;
			var msg7 = <!--XLATESTART-->"&#12456;&#12521;&#12540;! &#26368;&#23567;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12434;&#26368;&#22823;&#35686;&#21578;&#12375;&#12365;&#12356;&#20516;&#12392;&#21516;&#12376;&#12363;&#12381;&#12428;&#12424;&#12426;&#22823;&#12365;&#12367;&#12377;&#12427;&#12371;&#12392;&#12399;&#12391;&#12365;&#12414;&#12379;&#12435;" <!--XLATESTOP-->;
			
			function initializationRoutine()
			{
				document.getElementById("UNCVal").value = '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of 	select="ProbeThresholds/UNCThreshold"/></xsl:with-param></xsl:call-template>';
				document.getElementById("LNCVal").value = '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of 	select="ProbeThresholds/LNCThreshold"/></xsl:with-param></xsl:call-template>';
				
				document.getElementById("UNCVal").disabled = true;
				document.getElementById("LNCVal").disabled = true;
				document.getElementById("threshsetting").checked = true;
				assignVal();
				<xsl:if test="(Capabilities/ProbeUNCDefSetEnabled != 'true') and (Capabilities/ProbeLNCDefSetEnabled != 'true')">	
				 	setToVal();
				</xsl:if>
			}
			
			function assignVal(){
					var UCloc 			= parseFloat("<xsl:call-template name="calVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param></xsl:call-template>");
					var LCloc 			= parseFloat("<xsl:call-template name="calVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LCThreshold"/></xsl:with-param></xsl:call-template>");
					var preUNCloc 		= parseFloat("<xsl:call-template name="calVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param></xsl:call-template>");
					var preLNCloc 		= parseFloat("<xsl:call-template name="calVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:with-param></xsl:call-template>");
			
					var UCTxtloc		= '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param></xsl:call-template>';
					var LCTxtloc		= '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LCThreshold"/></xsl:with-param></xsl:call-template>';
		
					var preUNCTxtloc		= '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param></xsl:call-template>';
					var preLNCTxtloc 		= '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:with-param></xsl:call-template>';

					UC = UCloc;
					LC = LCloc;
					preUNC = preUNCloc;
					preLNC = preLNCloc;
					UCTxt = trim(UCTxtloc);
					LCTxt = trim(LCTxtloc);
					preUNCTxt = trim(preUNCTxtloc);
					preLNCTxt = trim(preLNCTxtloc);
			}
		</script>
		
	</DataArea>
</xsl:template>

<xsl:template name="showcalVolt">
	<xsl:param name="volt"/>
		<xsl:variable name="formatval"><xsl:value-of select="format-number($volt div 1000,'##0.000')"/></xsl:variable>
		<xsl:variable name="univdecsep">
			<xsl:choose>
				<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = '.'">.</xsl:when>
				<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = ','">,</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="localdecsep"><!--XLATESTART-->.<!--XLATESTOP--></xsl:variable>
		<xsl:value-of select="translate($formatval,$univdecsep,$localdecsep)"/>	
</xsl:template>

<xsl:template name="calVolt">
	<xsl:param name="volt"/>
		<xsl:variable name="formatval"><xsl:value-of select="format-number($volt div 1000,'##0.000')"/></xsl:variable>
		<xsl:variable name="univdecsep">
			<xsl:choose>
				<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = '.'">.</xsl:when>
				<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = ','">,</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="localdecsep">.</xsl:variable>
		<xsl:value-of select="translate($formatval,$univdecsep,$localdecsep)"/>	
</xsl:template>

<xsl:template name="smstatus">
	<xsl:param name="status"/>
	<xsl:choose>
		<xsl:when test="$status = '-1'"><!--XLATESTART-->&#12467;&#12510;&#12531;&#12489;&#22833;&#25943;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '1'"><!--XLATESTART-->&#12467;&#12510;&#12531;&#12489;&#26410;&#23455;&#35013;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '2'"><!--XLATESTART-->&#19981;&#27491;&#12467;&#12510;&#12531;&#12489;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '3'"><!--XLATESTART-->&#12467;&#12510;&#12531;&#12489; &#12479;&#12452;&#12512;&#12450;&#12454;&#12488;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '4'"><!--XLATESTART-->&#12467;&#12510;&#12531;&#12489; &#12461;&#12515;&#12531;&#12475;&#12523;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '5'"><!--XLATESTART-->&#12467;&#12510;&#12531;&#12489;&#20013;&#27490;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '6'"><!--XLATESTART-->&#12467;&#12510;&#12531;&#12489;&#20445;&#30041;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '7'"><!--XLATESTART-->&#12487;&#12496;&#12452;&#12473;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '8'"><!--XLATESTART-->&#12487;&#12496;&#12452;&#12473;&#12399;&#20351;&#29992;&#20013;&#12391;&#12377;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '9'"><!--XLATESTART-->&#19981;&#27491;&#12394;&#12487;&#12496;&#12452;&#12473;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '10'"><!--XLATESTART-->&#19981;&#27491;&#12394;&#20013;&#26029;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '11'"><!--XLATESTART-->&#12522;&#12477;&#12540;&#12473;&#12364;&#12525;&#12483;&#12463;&#12373;&#12428;&#12390;&#12356;&#12414;&#12377;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '12'"><!--XLATESTART-->&#28961;&#21177;&#12394;&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '13'"><!--XLATESTART-->SMB &#12456;&#12521;&#12540;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '14'"><!--XLATESTART-->&#35201;&#27714;&#12373;&#12428;&#12383;&#12487;&#12540;&#12479;&#12399;&#20837;&#25163;&#12391;&#12365;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '15'"><!--XLATESTART-->&#35201;&#27714;&#12373;&#12428;&#12383;&#12487;&#12540;&#12479;&#12399;&#20351;&#29992;&#12391;&#12365;&#12427;&#12487;&#12540;&#12479;&#12434;&#19978;&#22238;&#12387;&#12390;&#12356;&#12414;&#12377;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '16'"><!--XLATESTART-->&#35201;&#27714;&#12373;&#12428;&#12383;&#12487;&#12540;&#12479;&#12399;&#20351;&#29992;&#12391;&#12365;&#12427;&#12487;&#12540;&#12479;&#12434;&#19979;&#22238;&#12387;&#12390;&#12356;&#12414;&#12377;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '17'"><!--XLATESTART-->&#12487;&#12496;&#12452;&#12473;&#12391;&#12467;&#12510;&#12531;&#12489;&#12434;&#21463;&#29702;&#12377;&#12427;&#28310;&#20633;&#12364;&#12391;&#12365;&#12390;&#12356;&#12414;&#12379;&#12435; &#20877;&#35430;&#34892;&#12375;&#12390;&#12367;&#12384;&#12373;&#12356;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '18'"><!--XLATESTART-->&#12487;&#12496;&#12452;&#12473;&#12395;&#12487;&#12540;&#12479;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '19'"><!--XLATESTART-->&#12487;&#12496;&#12452;&#12473;&#12364;&#12513;&#12514;&#12522;&#19981;&#36275;&#12391;&#12377;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '20'"><!--XLATESTART-->&#12487;&#12496;&#12452;&#12473;&#12399;&#26082;&#12395;&#23384;&#22312;&#12375;&#12414;&#12377;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '256'"><!--XLATESTART-->&#38651;&#22311;&#12503;&#12525;&#12540;&#12502;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '257'"><!--XLATESTART-->&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;&#12398;&#24418;&#24335;&#12364;&#35492;&#12387;&#12390;&#12356;&#12427;&#12363;&#12289;&#30772;&#25613;&#12375;&#12390;&#12356;&#12427;&#12363;&#19981;&#27491;&#12391;&#12377;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '258'"><!--XLATESTART-->&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;&#12399;&#26082;&#12395;&#23384;&#22312;&#12375;&#12414;&#12377;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '260'"><!--XLATESTART-->INI &#12501;&#12449;&#12452;&#12523;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '261'"><!--XLATESTART-->INI &#12398;&#24418;&#24335;&#12364;&#35492;&#12387;&#12390;&#12356;&#12427;&#12363;&#12289;&#30772;&#25613;&#12375;&#12390;&#12356;&#12427;&#12363;&#19981;&#27491;&#12391;&#12377;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '262'"><!--XLATESTART-->INI &#12475;&#12463;&#12471;&#12519;&#12531;&#12364;&#23384;&#22312;&#12375;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '263'"><!--XLATESTART-->INI &#12461;&#12540;&#12364;&#23384;&#22312;&#12375;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '264'"><!--XLATESTART-->INI &#12398;&#20516;&#12398;&#24418;&#24335;&#12364;&#35492;&#12387;&#12390;&#12356;&#12427;&#12363;&#12289;&#30772;&#25613;&#12375;&#12390;&#12356;&#12427;&#12363;&#19981;&#27491;&#12391;&#12377;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '270'"><!--XLATESTART-->&#12450;&#12463;&#12475;&#12473;&#27177;&#12364;&#21313;&#20998;&#12391;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '271'"><!--XLATESTART-->&#12497;&#12521;&#12513;&#12540;&#12479;&#21517;&#12414;&#12383;&#12399;&#20516;&#12364;&#28961;&#21177;&#12391;&#12377; <!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '272'"><!--XLATESTART-->&#12513;&#12514;&#12522;&#19981;&#36275;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '280'"><!--XLATESTART-->XML &#12501;&#12449;&#12452;&#12523;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '281'"><!--XLATESTART-->XML &#12398;&#24418;&#24335;&#12364;&#35492;&#12387;&#12390;&#12356;&#12427;&#12363;&#12289;&#30772;&#25613;&#12375;&#12390;&#12356;&#12427;&#12363;&#19981;&#27491;&#12391;&#12377;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '282'"><!--XLATESTART-->XML &#12494;&#12540;&#12489;&#12364;&#23384;&#22312;&#12375;&#12414;&#12379;&#12435;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '283'"><!--XLATESTART-->XML &#12398;&#20516;&#12398;&#24418;&#24335;&#12364;&#35492;&#12387;&#12390;&#12356;&#12427;&#12363;&#12289;&#30772;&#25613;&#12375;&#12390;&#12356;&#12427;&#12363;&#19981;&#27491;&#12391;&#12377;<!--XLATESTOP--></xsl:when>
			<xsl:otherwise>SMStatus: <xsl:value-of select="$status"/></xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="*">
</xsl:template>
</xsl:stylesheet>
