<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:output method="xml" indent="no"/>
	<xsl:template match="OMA">
		<xsl:choose>
			<xsl:when test="SMStatus = '0'">
				<xsl:apply-templates select="ESMLog"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="failure"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="failure">
		<DataArea>
			<PageTitle display="&#38169;&#35823;&#65281;&#35813;&#31995;&#32479;&#20013;&#26410;&#25214;&#21040;&#23884;&#20837;&#24335;&#31995;&#32479;&#31649;&#29702; (ESM) &#26085;&#24535;&#12290;"></PageTitle>
			<xsl:attribute name="status"><xsl:value-of select="/OMA/ObjStatus"/></xsl:attribute>
		</DataArea>
	</xsl:template>
	<xsl:template match="ESMLog">
		<DataArea>
			<script language="javascript">
				function clearLog()
				{
					document.dataarea.action='/servlet/SubmitForm?plugin=com.dell.hip.webplugins.ClearESMLogWebPlugin';
					document.dataarea.submit();
				}
				function saveLog()
				{
					document.dataarea.action='/servlet/SubmitForm?plugin=com.dell.oma.webplugins.SaveLogWebPlugin';
					document.getElementById("pageCode").value = document.getElementsByTagName("HTML")[0].innerHTML;
					document.dataarea.submit();
				}
			</script>		
			<Header>Header</Header>
			<PageTitle>
				<xsl:attribute name="display"><!--XLATESTART-->&#23884;&#20837;&#24335;&#31995;&#32479;&#31649;&#29702; (ESM) &#26085;&#24535;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="status"><xsl:value-of select="/OMA/ObjStatus"/></xsl:attribute>
			</PageTitle>
			<xsl:choose>
				<xsl:when test="NumRecords = '0'">
					<PromptText><!--XLATESTART-->&#23884;&#20837;&#24335;&#31995;&#32479;&#31649;&#29702;&#26085;&#24535;&#21253;&#21547;... &#26410;&#25214;&#21040;&#20219;&#20309;&#26465;&#30446;<!--XLATESTOP--></PromptText>
				</xsl:when>
				<xsl:otherwise>
					<PromptText><!--XLATESTART-->&#23884;&#20837;&#24335;&#31995;&#32479;&#31649;&#29702;&#26085;&#24535;&#21253;&#21547;...<!--XLATESTOP--></PromptText>
				</xsl:otherwise>
			</xsl:choose>
			<CustomButton>
				<xsl:if test="(/OMA/OMAUserRights = '7') or (/OMA/OMAUserRights = '3')">		
					<Data name="Clear">
						<xsl:attribute name="display"><!--XLATESTART-->&#28165;&#38500;&#26085;&#24535;<!--XLATESTOP--></xsl:attribute>
						<xsl:attribute name="href">javascript:clearLog()</xsl:attribute>
					<xsl:attribute name="formSubmit">true</xsl:attribute>
					</Data>
					<Data name="Save" display="&#21478;&#23384;&#20026;">
						<xsl:attribute name="href">javascript:saveLog()</xsl:attribute>
					<xsl:attribute name="formSubmit">true</xsl:attribute>
					</Data>
				</xsl:if>
				<Data name="Refresh">
					<xsl:attribute name="display"><!--XLATESTART-->&#21047;&#26032;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.hip.webplugins.ESMLogWebPlugin</xsl:attribute>
				</Data>
			</CustomButton>
			<TableData>
				<Header>
					<Data name="Severity" align="center">
						<xsl:attribute name="display"><!--XLATESTART-->Severity<!--XLATESTOP--></xsl:attribute>
						<xsl:attribute name="value"><!--XLATESTART-->Severity<!--XLATESTOP--></xsl:attribute>
						<xsl:attribute name="link">true</xsl:attribute>
						<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.hip.webplugins.ESMLogSevWebPlugin</xsl:attribute>
					</Data>
					<Data name="Time">
						<xsl:attribute name="display"><!--XLATESTART-->Date &amp; Time<!--XLATESTOP--></xsl:attribute>
						<xsl:attribute name="value"><!--XLATESTART-->Date &amp; Time<!--XLATESTOP--></xsl:attribute>
						<xsl:attribute name="link">true</xsl:attribute>
					<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.hip.webplugins.ESMLogWebPlugin</xsl:attribute>
					</Data>
					<Data name="Event">
						<xsl:attribute name="display"><!--XLATESTART-->Description<!--XLATESTOP--></xsl:attribute>
						<xsl:attribute name="value"><!--XLATESTART-->Description<!--XLATESTOP--></xsl:attribute>
						<xsl:attribute name="link">true</xsl:attribute>
						<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.hip.webplugins.ESMLogDescWebPlugin</xsl:attribute>
					</Data>
				</Header>
				<xsl:apply-templates select="LogEntry">
					<xsl:sort select="TimeStampRaw" data-type="number" order="descending"/>
				</xsl:apply-templates>
			</TableData>
		</DataArea>
	</xsl:template>
	
	<xsl:template match="LogEntry">
		<Row>
			<Data name="severity" type="status" align="center" width="100">
				<xsl:attribute name="value"><xsl:value-of select="Status"/></xsl:attribute>
			</Data>
			<Data name="time" type="ustring" width="180">
				<xsl:attribute name="value"><xsl:value-of select="TimeStamp"/></xsl:attribute>
				<xsl:attribute name="display"><xsl:value-of select="TimeStampRaw"/></xsl:attribute>
			</Data>
			<Data name="description" type="ustring">
				<xsl:attribute name="value"><xsl:value-of select="Description"/></xsl:attribute>
			</Data>
		</Row>
	</xsl:template>
	
</xsl:stylesheet>
