<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" />
	<xsl:strip-space elements="*"/>
	<xsl:template match="OMA">
		<xsl:choose>
			<xsl:when test="SMStatus != '0'">
				<DataArea printable="false">
					<PageTitle>
						<xsl:attribute name="display">
							<xsl:call-template name="smstatus">
								<xsl:with-param name="status"><xsl:value-of select="SMStatus"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
					</PageTitle>
				</DataArea>
			</xsl:when>
			<xsl:otherwise>
				<DataArea validate="true" onLoad="true">
				<xsl:attribute name="backpagedisplay"><!--XLATESTART-->&#39118;&#25159;&#25506;&#27979;&#22120;<!--XLATESTOP--></xsl:attribute>
					<xsl:apply-templates select="ServletArguments"/>
					<xsl:apply-templates select="FanProbe"/>
				</DataArea>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="FanProbe">
		<PageTitle></PageTitle>
		<SubHeader >
			<xsl:attribute name="display"><xsl:value-of select="ProbeLocation"/></xsl:attribute>
			<xsl:attribute name="status"><xsl:value-of select="@status"/></xsl:attribute>
		</SubHeader>
		<xsl:choose>
			<xsl:when test="(ProbeThresholds/LCThreshold &gt; 0) and (ProbeThresholds/UCThreshold &gt; 0) and (ProbeThresholds/LNCThreshold &gt; 0) and (ProbeThresholds/UNCThreshold &gt; 0) and (ProbeReading &gt;= 0)">
				<Guage  digits="0">
				<xsl:attribute name="units"> <!--XLATESTART-->&#36716;/&#20998;<!--XLATESTOP--></xsl:attribute>
					<Reading><xsl:value-of select="ProbeReading"/></Reading>
					<MFThresh><xsl:value-of select="ProbeThresholds/LCThreshold"/></MFThresh>
					<MXFThresh><xsl:value-of select="ProbeThresholds/UCThreshold"/></MXFThresh>
					<MWThresh><xsl:value-of select="ProbeThresholds/LNCThreshold"/></MWThresh>
					<MXWThresh><xsl:value-of select="ProbeThresholds/UNCThreshold"/></MXWThresh>
					<ListData>
						<Data display="&#29366;&#24577;">
							<xsl:call-template name="StatusToStr">
								<xsl:with-param name="status"><xsl:value-of select="@status"/></xsl:with-param>
							</xsl:call-template>
						</Data>
						<Data display="&#35835;&#25968;" reading="true">
							<xsl:attribute name="value"><xsl:value-of select="ProbeReading"/> <!--XLATESTART--> &#36716;/&#20998;<!--XLATESTOP--></xsl:attribute>
						</Data>
						<Data display="&#26368;&#23567;&#25925;&#38556;&#38408;&#20540;">
							<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/LCThreshold"/><!--XLATESTART--> &#36716;/&#20998;<!--XLATESTOP--></xsl:attribute>
						</Data>
						<Data display="&#26368;&#22823;&#25925;&#38556;&#38408;&#20540;">
							<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/UCThreshold"/><!--XLATESTART--> &#36716;/&#20998;<!--XLATESTOP--></xsl:attribute>
						</Data>
						<xsl:choose>
						<xsl:when test="(Capabilities/ProbeUNCDefSetEnabled = 'true') or (Capabilities/ProbeLNCDefSetEnabled = 'true')">
						<Data display="&#38408;&#20540;&#35774;&#32622;" type="radio"  state="1">
							<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
							<xsl:attribute name="value">&#35774;&#32622;&#20026;&#40664;&#35748;&#20540;</xsl:attribute>
						</Data>
							<xsl:if test="(Capabilities/ProbeUNCSetEnabled = 'true') or (Capabilities/ProbeLNCSetEnabled = 'true')">
							<Data type="radio">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">&#35774;&#32622;&#20540;</xsl:attribute>
							</Data>
							</xsl:if>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="(Capabilities/ProbeUNCSetEnabled = 'true') or (Capabilities/ProbeLNCSetEnabled = 'true')">
							<Data display="&#38408;&#20540;&#35774;&#32622;" type="radio"  state="1">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">&#35774;&#32622;&#20540;</xsl:attribute>
							</Data>
							</xsl:if>
						</xsl:otherwise>
						</xsl:choose>
						<xsl:if test="(Capabilities/ProbeLNCSetEnabled = 'true')">
						<Data display="&#26368;&#23567;&#35686;&#21578;&#38408;&#20540;" type="editbox">
							<xsl:attribute name="textboxname">LNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART--> &#36716;/&#20998;<!--XLATESTOP--></xsl:attribute>
						</Data>
						</xsl:if>
						<xsl:if test="(Capabilities/ProbeUNCSetEnabled = 'true')">
						<Data display="&#26368;&#22823;&#35686;&#21578;&#38408;&#20540;" type="editbox">
							<xsl:attribute name="textboxname">UNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART--> &#36716;/&#20998;<!--XLATESTOP--></xsl:attribute>
						</Data>
						</xsl:if>
					</ListData>
				</Guage>
			</xsl:when>
			<xsl:otherwise>
				<ListData>
					<Data display="&#29366;&#24577;">
						<xsl:call-template name="StatusToStr">
							<xsl:with-param name="status"><xsl:value-of select="@status"/></xsl:with-param>
						</xsl:call-template>
					</Data>
					<Data display="&#35835;&#25968;">
						<xsl:attribute name="value"><xsl:value-of select="ProbeReading"/><!--XLATESTART--> &#36716;/&#20998;<!--XLATESTOP--></xsl:attribute>
					</Data>
					<Data display="&#26368;&#23567;&#25925;&#38556;&#38408;&#20540;">
						<xsl:choose>
							<xsl:when test="ProbeThresholds/LCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/LCThreshold"/><!--XLATESTART--> &#36716;/&#20998;<!--XLATESTOP--></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value"><!--XLATESTART-->&#26410;&#30693;<!--XLATESTOP--></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</Data>			
					<Data display="&#26368;&#22823;&#25925;&#38556;&#38408;&#20540;">
						<xsl:choose>
							<xsl:when test="ProbeThresholds/UCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/UCThreshold"/><!--XLATESTART--> &#36716;/&#20998;<!--XLATESTOP--></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value"><!--XLATESTART-->&#26410;&#30693;<!--XLATESTOP--></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</Data>
					<Data display="&#38408;&#20540;&#35774;&#32622;" type="radio"  state="1">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
						<xsl:attribute name="value">&#35774;&#32622;&#20026;&#40664;&#35748;&#20540;</xsl:attribute>
					</Data>
					<Data type="radio">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
						<xsl:attribute name="value">&#35774;&#32622;&#20540;</xsl:attribute>
					</Data>
					<Data display="&#26368;&#23567;&#35686;&#21578;&#38408;&#20540;" type="editbox" size="5">
						<xsl:attribute name="name">LNCVal</xsl:attribute>
						<xsl:choose>
							<xsl:when test="ProbeThresholds/LNCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value">0</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:attribute name="unit"><!--XLATESTART--> &#36716;/&#20998;<!--XLATESTOP--></xsl:attribute>
					</Data>
					<Data display="&#26368;&#22823;&#35686;&#21578;&#38408;&#20540;" type="editbox" size="5">
						<xsl:attribute name="name">UNCVal</xsl:attribute>
						<xsl:choose>
							<xsl:when test="ProbeThresholds/UNCThreshold &gt; 0">
								<xsl:attribute name="value"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="value">0</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:attribute name="unit"><!--XLATESTART--> &#36716;/&#20998;<!--XLATESTOP--></xsl:attribute>
					</Data>
				</ListData>
			</xsl:otherwise>
		</xsl:choose>
		<script language="javascript">
			isProbeUNCSetEnabled 		= <xsl:value-of select="Capabilities/ProbeUNCSetEnabled"/>;
			isProbeLNCSetEnabled 		= <xsl:value-of select="Capabilities/ProbeLNCSetEnabled"/>;
			isProbeUNCDefSetEnabled 	= <xsl:value-of select="Capabilities/ProbeUNCDefSetEnabled"/>;
			isProbeLNCDefSetEnabled 	= <xsl:value-of select="Capabilities/ProbeLNCDefSetEnabled"/>;
		
			setToDefault	= true;
			setToValues	= false;

if( (( ! isProbeUNCDefSetEnabled )  &amp;&amp; (! isProbeLNCDefSetEnabled)) &amp;&amp; ( isProbeUNCSetEnabled || isProbeLNCSetEnabled ) )
{
	setToValues	= true;
}

			function initializationRoutine()
			{
				if( isProbeUNCSetEnabled )
				{
					document.getElementById("UNCVal").value = <xsl:value-of select="ProbeThresholds/UNCThreshold"/>;
					document.getElementById("UNCVal").disabled = false;
					if ( ( isProbeUNCDefSetEnabled || isProbeLNCDefSetEnabled ) &amp;&amp; setToDefault )
					{
						document.getElementById("UNCVal").disabled = true;
					}
				}

				if( isProbeLNCSetEnabled )
				{
					document.getElementById("LNCVal").value = <xsl:value-of select="ProbeThresholds/LNCThreshold"/>;
					document.getElementById("LNCVal").disabled = false;
					if ( ( isProbeUNCDefSetEnabled || isProbeLNCDefSetEnabled ) &amp;&amp; setToDefault )
					{
						document.getElementById("LNCVal").disabled = true;
					}
				}
				
				if( isProbeUNCDefSetEnabled || isProbeLNCDefSetEnabled )
				{
					document.getElementById("threshsetting").checked = true;
				}
			}
			
			function setToVal()
			{
				setToValues = true;
				setToDefault = false;
				if( isProbeUNCSetEnabled )
				{
					document.getElementById("UNCVal").disabled = false;
				}

				if( isProbeLNCSetEnabled )
				{
					document.getElementById("LNCVal").disabled = false;
				}
			}
			
			function setToDef()
			{
				setToDefault = true;
				setToValues = false;
				if( isProbeUNCSetEnabled )
				{
					document.getElementById("UNCVal").disabled = true;
				}

				if( isProbeLNCSetEnabled )
				{
					document.getElementById("LNCVal").disabled = true;
				}
			}

			function validate()
			{
				<xsl:choose>
					<xsl:when test="ProbeThresholds/UCThreshold &gt; 0 ">
						var UC 	= parseFloat("<xsl:value-of select="ProbeThresholds/UCThreshold"/>");
						var preUNC = <xsl:value-of select="ProbeThresholds/UNCThreshold"/>;
					</xsl:when>
					<xsl:otherwise>
						var UC 	= 0;
						var preUNC = <xsl:value-of select="ProbeThresholds/UNCThreshold"/>;
					</xsl:otherwise>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="ProbeThresholds/LCThreshold &gt; 0 ">
						var LC = parseFloat("<xsl:value-of select="ProbeThresholds/LCThreshold"/>");
						var preLNC = <xsl:value-of select="ProbeThresholds/LNCThreshold"/>;
					</xsl:when>
					<xsl:otherwise>
						var LC = 0;
						var preLNC = <xsl:value-of select="ProbeThresholds/LNCThreshold"/>;
					</xsl:otherwise>
				</xsl:choose>
				
				if(setToValues)
				{
					// user has changed the threshold settings.
					
					<xsl:if test="Capabilities/ProbeUNCSetEnabled = 'true' ">
						document.getElementById("UNCVal").disabled = false;
						var tempUNC = document.getElementById("UNCVal").value;
						
						if(isNaN(tempUNC) == true)
						{
							alert("&#38169;&#35823;&#65281; &#26368;&#22823;&#35686;&#21578;&#38408;&#20540;&#24212;&#20026;&#25968;&#23383;&#65292;&#20294;&#26159;&#26174;&#31034;&#65306; " + tempUNC);
							document.getElementById("UNCVal").value = preUNC;
							document.getElementById("LNCVal").value = preLNC;
							return false;
						}
						
						if(isNaN(parseFloat(tempUNC)) == true)
						{
							alert("&#38169;&#35823;&#65281; &#26368;&#22823;&#35686;&#21578;&#38408;&#20540;&#24212;&#20026;&#25972;&#25968;&#65292;&#20294;&#26159;&#26174;&#31034;&#65306; " + tempUNC);
						document.getElementById("UNCVal").value = preUNC;
						document.getElementById("LNCVal").value = preLNC;
						return false;
					}
					else
					{
						if(tempUNC.indexOf(".") != "-1")
														{
															alert("&#38169;&#35823;&#65281; &#26368;&#22823;&#35686;&#21578;&#38408;&#20540;&#24212;&#20026;&#25972;&#25968;&#65292;&#20294;&#26159;&#26174;&#31034;&#65306; " + tempUNC);
								document.getElementById("UNCVal").value = preUNC;
								return false;
							}
						}
						
						var UNC 	= parseFloat(document.getElementById("UNCVal").value);
					</xsl:if>
					
					<xsl:if test="Capabilities/ProbeLNCSetEnabled = 'true' ">
						document.getElementById("LNCVal").disabled = false;
						var tempLNC 	= document.getElementById("LNCVal").value;
						
						if( isNaN(tempLNC) == true)
						{
							alert("&#38169;&#35823;&#65281; &#26368;&#23567;&#35686;&#21578;&#38408;&#20540;&#24212;&#20026;&#25968;&#23383;&#65292;&#20294;&#26159;&#26174;&#31034;&#65306; " + tempLNC);
							document.getElementById("UNCVal").value = preUNC;
							document.getElementById("LNCVal").value = preLNC;
							return false;
						}
						
						
						if( isNaN(parseFloat(tempLNC)) == true)
						{
							alert("&#38169;&#35823;&#65281; &#26368;&#23567;&#35686;&#21578;&#38408;&#20540;&#24212;&#20026;&#25972;&#25968;&#65292;&#20294;&#26159;&#26174;&#31034;&#65306; " + tempLNC);
						document.getElementById("UNCVal").value = preUNC;
						document.getElementById("LNCVal").value = preLNC;
						return false;
					}
					else
					{
						if(tempLNC.indexOf(".") != "-1")
														{
															alert("&#38169;&#35823;&#65281; &#26368;&#23567;&#35686;&#21578;&#38408;&#20540;&#24212;&#20026;&#25972;&#25968;&#65292;&#20294;&#26159;&#26174;&#31034;&#65306; " + tempLNC);
								document.getElementById("LNCVal").value = preLNC;
								return false;
							}
						}
						
						var LNC 	= parseFloat(document.getElementById("LNCVal").value);
					</xsl:if>
							
					if( isProbeUNCSetEnabled &amp;&amp; (! isProbeLNCSetEnabled) )
					{
						// only upper warning threshold is settable.

						if((UC &gt; 0) &amp;&amp; (LC &gt; 0))
						{
							if((UC &gt; UNC) &amp;&amp; (UNC &gt; LC))
							{
								return true;
							}
							else
							{
								alert("&#38169;&#35823;&#65281; &#26368;&#22823;&#35686;&#21578;&#38408;&#20540;&#30340;&#20540; [" + UNC + "] &#26410;&#22312;" + LC + " &#36716;/&#20998;&#21644;" + UC + " &#36716;/&#20998;&#33539;&#22260;&#20043;&#38388;" );
							}
						}
						else
						{
							// UC and LC are not available to do validation of UNC value.
							return true;
						}
						
						document.getElementById("UNCVal").value = preUNC;
					}
					else if( (! isProbeUNCSetEnabled ) &amp;&amp; isProbeLNCSetEnabled )
					{
						// only lower warning threshold is settable.
						
						if((UC &gt; 0) &amp;&amp; (LC &gt; 0))
						{
							if((UC &gt; LNC) &amp;&amp; (LNC &gt; LC))
							{
								return true;
							}
							else
							{
								alert("&#38169;&#35823;&#65281; &#26368;&#23567;&#35686;&#21578;&#38408;&#20540;&#30340;&#20540; [" + LNC + "] &#26410;&#22312;" + LC + " &#36716;/&#20998;&#21644;" + UC + " &#36716;/&#20998;&#33539;&#22260;&#20043;&#38388;" );
							}
						}
						else
						{
							// UC and LC are not available to do validation of LNC value.
							return true;
						}
						
						document.getElementById("LNCVal").value = preLNC;
					}
					else
					{
						// both are settable
						
						if((UC &gt; 0) &amp;&amp; (LC &gt; 0))
						{
							if((UC &gt; UNC) &amp;&amp; (UNC &gt; LC))
							{
								if(UNC &gt; LNC)
								{
									if(LNC &gt; LC)
									{
										return true;
									}
									else
									{
										alert("&#38169;&#35823;&#65281; &#26368;&#23567;&#35686;&#21578;&#38408;&#20540;&#30340;&#20540; [" + LNC + "] &#26410;&#22312;" + LC + " &#36716;/&#20998;&#21040;" + UNC + "&#36716;/&#20998;&#33539;&#22260;&#20043;&#38388;" );
								}
							}
							else
							{
								alert("&#38169;&#35823;&#65281; &#26368;&#23567;&#35686;&#21578;&#38408;&#20540;&#19981;&#24471;&#22823;&#20110;&#25110;&#31561;&#20110;&#26368;&#22823;&#35686;&#21578;&#38408;&#20540;" );
						}
					}
					else
					{
						if((UC &gt; LNC) &amp;&amp; (LNC &gt; LC))
						{
							alert("&#38169;&#35823;&#65281; &#26368;&#22823;&#35686;&#21578;&#38408;&#20540;&#30340;&#20540; [" + UNC + "] &#26410;&#22312;" + LNC + " &#36716;/&#20998;&#21040;" + UC + "&#36716;/&#20998;&#33539;&#22260;&#20043;&#38388;" );
							}
							else
							{
								alert("&#38169;&#35823;&#65281; &#26368;&#22823;&#35686;&#21578;&#38408;&#20540;&#30340;&#20540; [" + UNC + "] &#26410;&#22312;" + preLNC + " &#36716;/&#20998;&#21040;" + UC + " &#36716;/&#20998;&#33539;&#22260;&#20043;&#38388;" );
							}
						}
					}
					else
					{
							<!-- UC and LC have invalid values. Accept the user values if they are positive-->						
							if( UNC &gt; 0)
						{
							if( LNC &gt; 0)
							{
								if(UNC &gt; LNC)
								{
									return true;
								}
								else
								{
									alert("&#38169;&#35823;&#65281; &#26368;&#23567;&#35686;&#21578;&#38408;&#20540;&#19981;&#24471;&#22823;&#20110;&#25110;&#31561;&#20110;&#26368;&#22823;&#35686;&#21578;&#38408;&#20540;" );
								}
							}
							else
							{
								alert("&#38169;&#35823;&#65281; &#26368;&#23567;&#35686;&#21578;&#38408;&#20540;&#24212;&#20026;&#26080;&#31526;&#21495;&#30340;&#25968;&#23383;&#65292;&#20294;&#26159;&#26174;&#31034;&#65306; " + LNC);
							}
						}
						else
						{
							alert("&#38169;&#35823;&#65281; &#26368;&#22823;&#35686;&#21578;&#38408;&#20540;&#24212;&#20026;&#26080;&#31526;&#21495;&#30340;&#25968;&#23383;&#65292;&#20294;&#26159;&#26174;&#31034;&#65306; " + UNC);
							}
						}

						document.getElementById("UNCVal").value = preUNC;
						document.getElementById("LNCVal").value = preLNC;
					}
				}
				else
				{
					// do not validate the values if user has selected default threshold settings.
					return true;
				}
				
				<!--  returning false doesn't submit the form -->
				return false;
			}
		</script>
	</xsl:template>
	<xsl:template match="ServletArguments">
		<xsl:attribute name="submit">/servlet/SubmitForm?plugin=com.dell.hip.webplugins.SetFanWebPlugin&amp;oid=<xsl:value-of select="@OID"/>&amp;poid=<xsl:value-of select="@POID"/>&amp;objtype=<xsl:value-of select="@PObjType"/>
</xsl:attribute>
		<xsl:attribute name="backpagetarget">/servlet/DataArea?plugin=com.dell.hip.webplugins.FanProbesWebPlugin&amp;poid=<xsl:value-of select="@POID"/>&amp;help=Fans</xsl:attribute>
		<CustomButton>
			<Data  name="" >
			<xsl:attribute name="display"><!--XLATESTART-->&#21047;&#26032;<!--XLATESTOP--></xsl:attribute>
							<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.hip.webplugins.EditFanProbeWebPlugin&amp;oid=<xsl:value-of select="@OID"/>&amp;poid=<xsl:value-of select="@POID"/>&amp;help=EditFanProbe</xsl:attribute>
			</Data>
		</CustomButton>
	</xsl:template>
		<xsl:template name="StatusToStr">
		<xsl:param name="status"/>
		<xsl:choose>
			<xsl:when test="$status = 1">
				<xsl:attribute name="value">Unknown</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 2">
				<xsl:attribute name="value">OK</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 3">
				<xsl:attribute name="value">Non Critical</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 4">
				<xsl:attribute name="value">Critical</xsl:attribute>
			</xsl:when>
			<xsl:when test="$status = 5">
				<xsl:attribute name="value">Non Recoverable</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:attribute name="value">Other</xsl:attribute>
			</xsl:otherwise>
		</xsl:choose>				
	</xsl:template>
	<xsl:template name="DataType">
		<xsl:param name="name"/>
		<xsl:param name="display"/>
		<xsl:param name="value"/>
		<xsl:param name="type"/>
		<xsl:param name="link"/>
		<xsl:param name="href"/>		
		<Data >
			<xsl:attribute name="name"><xsl:value-of select="$name"/></xsl:attribute>
			<xsl:attribute name="display"><xsl:value-of select="$display"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="$value"/></xsl:attribute>
			<xsl:attribute name="link"><xsl:value-of select="$link"/></xsl:attribute>
			<xsl:attribute name="href"><xsl:value-of select="$href"/></xsl:attribute>
			<xsl:attribute name="type"><xsl:value-of select="$type"/></xsl:attribute>
		</Data>
	</xsl:template>
		<xsl:template name="smstatus">
		<xsl:param name="status"/>
		<xsl:param name="mssg"/>
		<xsl:choose>
			<xsl:when test="$status = '-1'"><!--XLATESTART-->&#21629;&#20196;&#26410;&#25104;&#21151;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '0'"><!--XLATESTART-->&#21629;&#20196;&#24050;&#25104;&#21151;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '1'"><!--XLATESTART-->&#21629;&#20196;&#26410;&#25191;&#34892;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '2'"><!--XLATESTART-->&#21629;&#20196;&#38169;&#35823;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '3'"><!--XLATESTART-->&#21629;&#20196;&#36229;&#26102;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '4'"><!--XLATESTART-->&#21629;&#20196;&#24050;&#21462;&#28040;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '5'"><!--XLATESTART-->&#21629;&#20196;&#24050;&#32456;&#27490;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '6'"><!--XLATESTART-->&#21629;&#20196;&#25346;&#36215;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '7'"><!--XLATESTART-->&#27809;&#26377;&#27492;&#31867;&#35774;&#22791;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '8'"><!--XLATESTART-->&#35774;&#22791;&#27491;&#24537;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '9'"><!--XLATESTART-->&#35774;&#22791;&#25925;&#38556;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '10'"><!--XLATESTART-->&#20551;&#20013;&#26029;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '11'"><!--XLATESTART-->&#36164;&#28304;&#38145;&#23450;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '12'"><!--XLATESTART-->&#32034;&#24341;&#26080;&#25928;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '13'"><!--XLATESTART-->SMB &#38169;&#35823;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '14'"><!--XLATESTART-->&#25152;&#35831;&#27714;&#30340;&#25968;&#25454;&#19981;&#21487;&#29992;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '15'"><!--XLATESTART-->&#25152;&#35831;&#27714;&#30340;&#25968;&#25454;&#22810;&#20110;&#21487;&#29992;&#25968;&#25454;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '16'"><!--XLATESTART-->&#25152;&#35831;&#27714;&#30340;&#25968;&#25454;&#23569;&#20110;&#21487;&#29992;&#25968;&#25454;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '17'"><!--XLATESTART-->&#35774;&#22791;&#23578;&#26410;&#20934;&#22791;&#22909;&#65292;&#26080;&#27861;&#25509;&#21463;&#21629;&#20196;&#12290; &#35831;&#31245;&#21518;&#37325;&#35797;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '18'"><!--XLATESTART-->&#35774;&#22791;&#19978;&#27809;&#26377;&#25968;&#25454;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '19'"><!--XLATESTART-->&#35774;&#22791;&#19978;&#20869;&#23384;&#19981;&#36275;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '20'"><!--XLATESTART-->&#35774;&#22791;&#24050;&#23384;&#22312;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '256'"><!--XLATESTART-->&#26410;&#25214;&#21040;&#39118;&#25159;&#23545;&#35937;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '257'"><!--XLATESTART-->&#39118;&#25159;&#23545;&#35937;&#21464;&#24418;&#12289;&#25439;&#22351;&#25110;&#26159;&#22351;&#30340;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '258'"><!--XLATESTART-->&#39118;&#25159;&#23545;&#35937;&#24050;&#23384;&#22312;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '260'"><!--XLATESTART-->&#26410;&#25214;&#21040; INI &#25991;&#20214;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '261'"><!--XLATESTART-->INI &#21464;&#24418;&#12289;&#25439;&#22351;&#25110;&#26159;&#22351;&#30340;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '262'"><!--XLATESTART-->INI &#37096;&#20998;&#19981;&#23384;&#22312;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '263'"><!--XLATESTART-->INI &#38190;&#19981;&#23384;&#22312;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '264'"><!--XLATESTART-->INI &#20540;&#21464;&#24418;&#12289;&#25439;&#22351;&#25110;&#26159;&#22351;&#30340;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '270'"><!--XLATESTART-->&#35775;&#38382;&#26435;&#38480;&#19981;&#36275;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '271'"><!--XLATESTART-->&#21442;&#25968;&#21517;&#31216;&#25110;&#20540;&#26080;&#25928;&#65306; <!--XLATESTOP--><xsl:value-of select="$mssg"/></xsl:when>
			<xsl:when test="$status = '272'"><!--XLATESTART-->&#20869;&#23384;&#19981;&#22815;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '280'"><!--XLATESTART-->&#26410;&#25214;&#21040; XML &#25991;&#20214;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '281'"><!--XLATESTART-->XML &#21464;&#24418;&#12289;&#25439;&#22351;&#25110;&#26159;&#22351;&#30340;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '282'"><!--XLATESTART-->XML &#33410;&#28857;&#19981;&#23384;&#22312;<!--XLATESTOP--></xsl:when>
			<xsl:when test="$status = '283'"><!--XLATESTART-->XML &#20540;&#21464;&#24418;&#12289;&#25439;&#22351;&#25110;&#26159;&#22351;&#30340;<!--XLATESTOP--></xsl:when>
		<xsl:otherwise>SMStatus: <xsl:value-of select="$status"/></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="*"/>
</xsl:stylesheet>
