<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
<xsl:template match="OMA">
	<xsl:if test="(OMAUserRights = '7') or (OMAUserRights = '3')">
		<xsl:choose>
			<xsl:when test="(VoltageProbe/ProbeThresholds/LCThreshold != '-2147483648') and (VoltageProbe/ProbeThresholds/UCThreshold != '-2147483648') and (VoltageProbe/ProbeThresholds/LNCThreshold != '-2147483648') and (VoltageProbe/ProbeThresholds/UNCThreshold != '-2147483648') and (VoltageProbe/ProbeReading != '-2147483648')">
				<xsl:choose>
					<xsl:when test="SMStatus='0'"><xsl:apply-templates select="VoltageProbe"/></xsl:when>
					<xsl:otherwise><xsl:call-template name="failure"/></xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise><xsl:call-template name="invalid"/></xsl:otherwise>
		</xsl:choose>
	</xsl:if>
</xsl:template>

<xsl:template name="failure">
	<DataArea>
		<PageTitle>
			<xsl:attribute name="display"><!--XLATESTART-->&#30005;&#21387;&#25506;&#27979;&#22120;<!--XLATESTOP--></xsl:attribute>
		</PageTitle>
		<TableData>
			<Row>
				<Data name=""  display="">
					<xsl:attribute name="value">
						<xsl:call-template name="smstatus">
							<xsl:with-param name="status"><xsl:value-of select="SMStatus"/></xsl:with-param>
						</xsl:call-template>
					</xsl:attribute>
				</Data>
			</Row>
		</TableData>
	</DataArea>
</xsl:template>

<xsl:template name="invalid">
	<DataArea>
		<PageTitle>
			<xsl:attribute name="display"><!--XLATESTART-->&#30005;&#21387;&#25506;&#27979;&#22120;<!--XLATESTOP--></xsl:attribute>
		</PageTitle>
		<PromptText><!--XLATESTART-->&#30005;&#21387;&#25506;&#27979;&#22120;&#38408;&#20540;&#25110;&#25506;&#27979;&#22120;&#35835;&#25968;&#21253;&#21547;&#26080;&#25928;&#20540;&#12290;<!--XLATESTOP--></PromptText>
	</DataArea>
</xsl:template>

<xsl:template match="VoltageProbe">
	<DataArea  backpagedisplay="&#30005;&#21387;&#25506;&#27979;&#22120;" validate="true"  onLoad="true">
		<xsl:attribute name="submit">/servlet/SubmitForm?plugin=com.dell.hip.webplugins.SetVoltageWebPlugin&amp;oid=<xsl:value-of select="@oid"/></xsl:attribute>
		<xsl:attribute name="backpagetarget">/servlet/DataArea?plugin=com.dell.hip.webplugins.ListVoltageWebPlugin&amp;poid=<xsl:value-of select="@poid"/>&amp;help=Voltages</xsl:attribute>
		<PageTitle>PageTitle</PageTitle>
			<Header>Header</Header>
		<SubHeader>
			<xsl:attribute name="display"><xsl:value-of select="ProbeLocation"/></xsl:attribute>
			<xsl:attribute name="status"><xsl:value-of select="@status"/></xsl:attribute>
		</SubHeader>
		<CustomButton>
			<Data name="Refresh">
			<xsl:attribute name="display"><!--XLATESTART-->&#21047;&#26032;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="href">
					/servlet/DataArea?plugin=com.dell.hip.webplugins.VoltageWebPlugin&amp;oid=<xsl:value-of select="@oid"/>&amp;poid=<xsl:value-of select="@poid"/>&amp;help=EditVoltageProbes
				</xsl:attribute>
			</Data>
		</CustomButton>
		<xsl:choose>
			<xsl:when test="(ProbeThresholds/LCThreshold != '-2147483648') and (ProbeThresholds/UCThreshold != '-2147483648') and (ProbeThresholds/LNCThreshold != '-2147483648') and (ProbeThresholds/UNCThreshold != '-2147483648') and (ProbeReading != '-2147483648')">
				<Guage digits="3">
					<xsl:attribute name="units"><!--XLATESTART-->&#20239;&#29305;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="showdecsep"><!--XLATESTART-->.<!--XLATESTOP--></xsl:attribute>
					<Reading>
						<xsl:call-template name="calVolt">
							<xsl:with-param name="volt"><xsl:value-of select="ProbeReading"/></xsl:with-param>
						</xsl:call-template>
					</Reading>
					<MFThresh>
						<xsl:call-template name="calVolt">
							<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LCThreshold"/></xsl:with-param>
						</xsl:call-template>
					</MFThresh>
					<MXFThresh>
						<xsl:call-template name="calVolt">
							<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param>
						</xsl:call-template>
					</MXFThresh>
					<MWThresh>
						<xsl:call-template name="calVolt">
							<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:with-param>
						</xsl:call-template>
					</MWThresh>
					<MXWThresh>
						<xsl:call-template name="calVolt">
							<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param>
						</xsl:call-template>
					</MXWThresh>
					<ListData>
						<Data display="&#29366;&#24577;" type="status-text">							<xsl:attribute name="value"><xsl:value-of select="@status"/></xsl:attribute>
						</Data>
						<Data display="&#35835;&#25968;" reading="true">
							<xsl:attribute name="value">
								<xsl:call-template name="showcalVolt">
									<xsl:with-param name="volt"><xsl:value-of select="ProbeReading"/></xsl:with-param>
								</xsl:call-template><!--XLATESTART-->&#20239;<!--XLATESTOP-->
							</xsl:attribute>
						</Data>
						<Data display="&#26368;&#23567;&#25925;&#38556;&#38408;&#20540;">
							<xsl:attribute name="value">
								<xsl:call-template name="showcalVolt">
									<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LCThreshold"/></xsl:with-param>
								</xsl:call-template><!--XLATESTART-->&#20239;&#29305;<!--XLATESTOP-->
							</xsl:attribute>
						</Data>
						<Data display="&#26368;&#22823;&#25925;&#38556;&#38408;&#20540;">
							<xsl:attribute name="value">
								<xsl:call-template name="showcalVolt">
									<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param>
								</xsl:call-template><!--XLATESTART-->&#20239;&#29305;<!--XLATESTOP-->
							</xsl:attribute>
						</Data>
						<xsl:choose>
							<xsl:when test="(Capabilities/ProbeUNCDefSetEnabled = 'true') or (Capabilities/ProbeLNCDefSetEnabled = 'true')">			
							<Data display="&#38408;&#20540;&#35774;&#32622;" type="radio"  state="1">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
						<xsl:attribute name="value">Set to Default</xsl:attribute>
							</Data>						
							<Data type="radio">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">Set to Values</xsl:attribute>
							</Data>
							</xsl:when>
							<xsl:otherwise>
							<Data display="&#38408;&#20540;&#35774;&#32622;" type="radio"  state="1">
								<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">Set to Values</xsl:attribute>
							</Data>												
							</xsl:otherwise>
						</xsl:choose>
						<Data display="&#26368;&#23567;&#35686;&#21578;&#38408;&#20540;" type="editbox">
							<xsl:attribute name="textboxname">LNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue">
								<xsl:call-template name="showcalVolt">
									<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:with-param>
								</xsl:call-template>
							</xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART--> &#20239;&#29305;<!--XLATESTOP--></xsl:attribute>
						</Data>
						<Data display="&#26368;&#22823;&#35686;&#21578;&#38408;&#20540;" type="editbox">
							<xsl:attribute name="textboxname">UNCVal</xsl:attribute>
							<xsl:attribute name="textboxvalue">
								<xsl:call-template name="showcalVolt">
									<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param>
								</xsl:call-template>
							</xsl:attribute>
							<xsl:attribute name="unit"><!--XLATESTART--> &#20239;&#29305;<!--XLATESTOP--></xsl:attribute>
						</Data>
					</ListData>
				</Guage>
			</xsl:when>
			<xsl:otherwise>
				<ListData>
					<Data name="plugin" type="hidden">
						<xsl:attribute name="returnvalue">com.dell.hip.webplugins.SetVoltageWebPlugin</xsl:attribute>
					</Data>
					<Data name="oid" type="hidden">
						<xsl:attribute name="returnvalue"><xsl:value-of select="@oid"/></xsl:attribute>
					</Data>
					<xsl:element name="Data">
						<xsl:attribute name="name">Status</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="@status"/></xsl:attribute>
						<xsl:attribute name="display"><!--XLATESTART-->&#29366;&#24577;<!--XLATESTOP--></xsl:attribute>
						<xsl:attribute name="type">status-text</xsl:attribute>
					</xsl:element>
					<xsl:element name="Data">
						<xsl:attribute name="value">
							<xsl:call-template name="showcalVolt">
								<xsl:with-param name="volt"><xsl:value-of select="ProbeReading"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:attribute name="display"><!--XLATESTART-->&#27491;&#22312;&#35835;&#21462;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="type">ustring</xsl:attribute>
						<xsl:attribute name="unit"><!--XLATESTART--> &#20239;&#29305;<!--XLATESTOP--></xsl:attribute>
					</xsl:element>
					<xsl:element name="Data">
						<xsl:attribute name="value">
							<xsl:call-template name="showcalVolt">
								<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LCThreshold"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:attribute name="display"><!--XLATESTART-->&#26368;&#23567;&#25925;&#38556;&#38408;&#20540;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="type">ustring</xsl:attribute>
						<xsl:attribute name="unit"> <!--XLATESTART-->&#20239;&#29305;<!--XLATESTOP--></xsl:attribute>
					</xsl:element>
					<xsl:element name="Data">
						<xsl:attribute name="value">
							<xsl:call-template name="showcalVolt">
								<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:attribute name="display"><!--XLATESTART-->&#26368;&#22823;&#25925;&#38556;&#38408;&#20540;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="type">ustring</xsl:attribute>
						<xsl:attribute name="unit"><!--XLATESTART--> &#20239;&#29305;<!--XLATESTOP--></xsl:attribute>
					</xsl:element>
					<Data display="&#38408;&#20540;&#35774;&#32622;" type="radio"  state="1">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">default</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToDef()</xsl:attribute>
						<xsl:attribute name="value">Set to Default</xsl:attribute>
					</Data>
					<Data type="radio">
						<xsl:attribute name="name">threshsetting</xsl:attribute>
							<xsl:attribute name="returnvalue">uservalues</xsl:attribute>
						<xsl:attribute name="event">onClick</xsl:attribute>
							<xsl:attribute name="handler">javascript:setToVal()</xsl:attribute>
								<xsl:attribute name="value">Set to Values</xsl:attribute>
					</Data>
					<Data display="&#26368;&#23567;&#35686;&#21578;&#38408;&#20540;" type="editbox" size="6">						<xsl:attribute name="name">LNCVal</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:call-template name="showcalVolt">
								<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:attribute name="unit"><!--XLATESTART--> &#20239;<!--XLATESTOP--></xsl:attribute>
					</Data>
					<Data display="&#26368;&#22823;&#35686;&#21578;&#38408;&#20540;" type="editbox" size="6">						<xsl:attribute name="name">UNCVal</xsl:attribute>
						<xsl:attribute name="value">
							<xsl:call-template name="showcalVolt">
								<xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param>
							</xsl:call-template>
						</xsl:attribute>
						<xsl:attribute name="unit"><!--XLATESTART--> &#20239;&#29305;<!--XLATESTOP--></xsl:attribute>
					</Data>
				</ListData>
			</xsl:otherwise>
		</xsl:choose>
		
		<script language="javascript" src="/oma/js/Probe.js" />
		
		<script language="javascript">
		
			var setToDefault	= true;
			var setToValues	= false;
			var UC;
			var LC;
			var preUNC;
			var preLNC;
			var UCTxt;
			var LCTxt;
			var preUNCTxt;
			var preLNCTxt;
			var toggleunivDecsep = <!--XLATESTART-->"."<!--XLATESTOP-->; //In German ,French and Spanish, change it to ",". In en, it should be ".".
			var togglelocalDecsep = <!--XLATESTART-->","<!--XLATESTOP-->;//In German ,French and Spanish, change it to ".".In en, it should be ",".
			var univDecsep = "."; // don't translate.
			var unit =  <!--XLATESTART-->"&#20239;&#29305;"<!--XLATESTOP-->;
			var multiplier = 1000;
			var lengthval = 4;
			var msg1 = <!--XLATESTART-->"&#38169;&#35823;&#65281; &#25968;&#23383;&#30340;&#23567;&#25968;&#28857;&#21518;&#38754;&#26368;&#22810;&#24212;&#20026; 3 &#20301;&#65292;&#20294;&#26159;&#26174;&#31034;&#65306; "<!--XLATESTOP-->;
			var msg2 = <!--XLATESTART-->"&#38169;&#35823;&#65281; &#20540; ["<!--XLATESTOP-->;
			var msg3 = <!--XLATESTART-->"] &#19981;&#22312;&#33539;&#22260;&#20869; "<!--XLATESTOP-->;
			var msg4 = <!--XLATESTART-->" &#21040; "<!--XLATESTOP-->;
			var msg5 = <!--XLATESTART-->" &#20026;&#26368;&#23567;&#35686;&#21578;&#38408;&#20540;&#12290;"<!--XLATESTOP-->;
			var msg6 = <!--XLATESTART-->" &#20026;&#26368;&#22823;&#35686;&#21578;&#38408;&#20540;&#12290;"<!--XLATESTOP-->;
			var msg7 = <!--XLATESTART-->"&#38169;&#35823;&#65281; &#26368;&#23567;&#35686;&#21578;&#38408;&#20540;&#19981;&#24471;&#22823;&#20110;&#25110;&#31561;&#20110;&#26368;&#22823;&#35686;&#21578;&#38408;&#20540;&#12290;"<!--XLATESTOP-->;
			
			function initializationRoutine()
			{
				document.getElementById("UNCVal").value = '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of 	select="ProbeThresholds/UNCThreshold"/></xsl:with-param></xsl:call-template>';
				document.getElementById("LNCVal").value = '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of 	select="ProbeThresholds/LNCThreshold"/></xsl:with-param></xsl:call-template>';
				
				document.getElementById("UNCVal").disabled = true;
				document.getElementById("LNCVal").disabled = true;
				document.getElementById("threshsetting").checked = true;
				assignVal();
				<xsl:if test="(Capabilities/ProbeUNCDefSetEnabled != 'true') and (Capabilities/ProbeLNCDefSetEnabled != 'true')">	
				 	setToVal();
				</xsl:if>
			}
			
			function assignVal(){
					var UCloc 			= parseFloat("<xsl:call-template name="calVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param></xsl:call-template>");
					var LCloc 			= parseFloat("<xsl:call-template name="calVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LCThreshold"/></xsl:with-param></xsl:call-template>");
					var preUNCloc 		= parseFloat("<xsl:call-template name="calVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param></xsl:call-template>");
					var preLNCloc 		= parseFloat("<xsl:call-template name="calVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:with-param></xsl:call-template>");
			
					var UCTxtloc		= '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UCThreshold"/></xsl:with-param></xsl:call-template>';
					var LCTxtloc		= '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LCThreshold"/></xsl:with-param></xsl:call-template>';
		
					var preUNCTxtloc		= '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/UNCThreshold"/></xsl:with-param></xsl:call-template>';
					var preLNCTxtloc 		= '<xsl:call-template name="showcalVolt"><xsl:with-param name="volt"><xsl:value-of select="ProbeThresholds/LNCThreshold"/></xsl:with-param></xsl:call-template>';

					UC = UCloc;
					LC = LCloc;
					preUNC = preUNCloc;
					preLNC = preLNCloc;
					UCTxt = trim(UCTxtloc);
					LCTxt = trim(LCTxtloc);
					preUNCTxt = trim(preUNCTxtloc);
					preLNCTxt = trim(preLNCTxtloc);
			}
		</script>
		
	</DataArea>
</xsl:template>

<xsl:template name="showcalVolt">
	<xsl:param name="volt"/>
		<xsl:variable name="formatval"><xsl:value-of select="format-number($volt div 1000,'##0.000')"/></xsl:variable>
		<xsl:variable name="univdecsep">
			<xsl:choose>
				<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = '.'">.</xsl:when>
				<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = ','">,</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="localdecsep"><!--XLATESTART-->.<!--XLATESTOP--></xsl:variable>
		<xsl:value-of select="translate($formatval,$univdecsep,$localdecsep)"/>	
</xsl:template>

<xsl:template name="calVolt">
	<xsl:param name="volt"/>
		<xsl:variable name="formatval"><xsl:value-of select="format-number($volt div 1000,'##0.000')"/></xsl:variable>
		<xsl:variable name="univdecsep">
			<xsl:choose>
				<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = '.'">.</xsl:when>
				<xsl:when test="substring(format-number(1.1,'##0.0'), 2, 1) = ','">,</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="localdecsep">.</xsl:variable>
		<xsl:value-of select="translate($formatval,$univdecsep,$localdecsep)"/>	
</xsl:template>

<xsl:template name="smstatus">
	<xsl:param name="status"/>
	<xsl:choose>
		<xsl:when test="$status = '-1'"><!--XLATESTART-->&#21629;&#20196;&#26410;&#25104;&#21151;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '1'"><!--XLATESTART-->&#21629;&#20196;&#26410;&#25191;&#34892;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '2'"><!--XLATESTART-->&#21629;&#20196;&#38169;&#35823;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '3'"><!--XLATESTART-->&#21629;&#20196;&#36229;&#26102;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '4'"><!--XLATESTART-->&#21629;&#20196;&#24050;&#21462;&#28040;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '5'"><!--XLATESTART-->&#21629;&#20196;&#24050;&#32456;&#27490;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '6'"><!--XLATESTART-->&#21629;&#20196;&#25346;&#36215;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '7'"><!--XLATESTART-->&#27809;&#26377;&#27492;&#31867;&#35774;&#22791;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '8'"><!--XLATESTART-->&#35774;&#22791;&#27491;&#24537;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '9'"><!--XLATESTART-->&#35774;&#22791;&#25925;&#38556;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '10'"><!--XLATESTART-->&#20551;&#20013;&#26029;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '11'"><!--XLATESTART-->&#36164;&#28304;&#38145;&#23450;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '12'"><!--XLATESTART-->&#32034;&#24341;&#26080;&#25928;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '13'"><!--XLATESTART-->SMB &#38169;&#35823;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '14'"><!--XLATESTART-->&#25152;&#35831;&#27714;&#30340;&#25968;&#25454;&#19981;&#21487;&#29992;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '15'"><!--XLATESTART-->&#25152;&#35831;&#27714;&#30340;&#25968;&#25454;&#22810;&#20110;&#21487;&#29992;&#25968;&#25454;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '16'"><!--XLATESTART-->&#25152;&#35831;&#27714;&#30340;&#25968;&#25454;&#23569;&#20110;&#21487;&#29992;&#25968;&#25454;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '17'"><!--XLATESTART-->&#35774;&#22791;&#23578;&#26410;&#20934;&#22791;&#22909;&#65292;&#26080;&#27861;&#25509;&#21463;&#21629;&#20196;&#12290; &#35831;&#31245;&#21518;&#37325;&#35797;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '18'"><!--XLATESTART-->&#35774;&#22791;&#19978;&#27809;&#26377;&#25968;&#25454;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '19'"><!--XLATESTART-->&#35774;&#22791;&#19978;&#20869;&#23384;&#19981;&#36275;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '20'"><!--XLATESTART-->&#35774;&#22791;&#24050;&#23384;&#22312;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '256'"><!--XLATESTART-->&#30005;&#21387;&#25506;&#27979;&#22120;&#26410;&#25214;&#21040;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '257'"><!--XLATESTART-->&#23545;&#35937;&#21464;&#24418;&#12289;&#25439;&#22351;&#25110;&#26159;&#22351;&#30340;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '258'"><!--XLATESTART-->&#23545;&#35937;&#24050;&#23384;&#22312;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '260'"><!--XLATESTART-->&#26410;&#25214;&#21040; INI &#25991;&#20214;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '261'"><!--XLATESTART-->INI &#21464;&#24418;&#12289;&#25439;&#22351;&#25110;&#26159;&#22351;&#30340;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '262'"><!--XLATESTART-->INI &#37096;&#20998;&#19981;&#23384;&#22312;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '263'"><!--XLATESTART-->INI &#38190;&#19981;&#23384;&#22312;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '264'"><!--XLATESTART-->INI &#20540;&#21464;&#24418;&#12289;&#25439;&#22351;&#25110;&#26159;&#22351;&#30340;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '270'"><!--XLATESTART-->&#35775;&#38382;&#26435;&#38480;&#19981;&#36275;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '271'"><!--XLATESTART-->&#21442;&#25968;&#21517;&#31216;&#25110;&#20540;&#26080;&#25928; <!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '272'"><!--XLATESTART-->&#20869;&#23384;&#19981;&#22815;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '280'"><!--XLATESTART-->&#26410;&#25214;&#21040; XML &#25991;&#20214;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '281'"><!--XLATESTART-->XML &#21464;&#24418;&#12289;&#25439;&#22351;&#25110;&#26159;&#22351;&#30340;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '282'"><!--XLATESTART-->XML &#33410;&#28857;&#19981;&#23384;&#22312;<!--XLATESTOP--></xsl:when>
		<xsl:when test="$status = '283'"><!--XLATESTART-->XML &#20540;&#21464;&#24418;&#12289;&#25439;&#22351;&#25110;&#26159;&#22351;&#30340;<!--XLATESTOP--></xsl:when>
			<xsl:otherwise>SMStatus: <xsl:value-of select="$status"/></xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="*">
</xsl:template>
</xsl:stylesheet>
