<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="xml" omit-xml-declaration="yes"/>
	<xsl:strip-space elements="*"/>
	<xsl:template match="/OMA">
		<Summary>
			<xsl:apply-templates/>
		</Summary>
	</xsl:template>

	<xsl:template match="System">
		<Section name="System">
			<xsl:attribute name="display"><!--XLATESTART-->&#31995;&#32479;<!--XLATESTOP--></xsl:attribute>
			<ListData name="system">
				<xsl:attribute name="display"><!--XLATESTART-->&#31995;&#32479;<!--XLATESTOP--></xsl:attribute>
				<Data name="HostName">
					<xsl:attribute name="display"><!--XLATESTART-->&#20027;&#26426;&#21517;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="HostName"/></xsl:attribute>
				</Data>
				<Data name="SystemLocation">
					<xsl:attribute name="display"><!--XLATESTART-->&#31995;&#32479;&#20301;&#32622;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="SystemInfo/SystemLocation"/></xsl:attribute>
				</Data>
			</ListData>
		</Section>
	</xsl:template>
	<xsl:template match="ChassisList">
			<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="Chassis">
		<Section>
			<xsl:attribute name="name">chassis_<xsl:value-of select="@index" /></xsl:attribute>
			<xsl:attribute name="display">
				<xsl:choose>
					<xsl:when test="@display = 'Main System Chassis'"><!--XLATESTART-->&#20027;&#31995;&#32479;&#26426;&#31665;<!--XLATESTOP--></xsl:when>
					<xsl:otherwise><xsl:value-of select="@display" /></xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:apply-templates select="ChassisInfo" />
			<xsl:apply-templates select="Hardware" />
		</Section>
		<xsl:apply-templates select="Network" />
		<xsl:apply-templates select="Software" />
	</xsl:template>
	<xsl:template match="ChassisInfo">
			<ListData name="ChassisInformation">
				<xsl:attribute name="display"><!--XLATESTART-->&#26426;&#31665;&#20449;&#24687;<!--XLATESTOP--></xsl:attribute>
				<Data name="ChassModel">
					<xsl:attribute name="display"><!--XLATESTART-->&#26426;&#31665;&#22411;&#21495;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ChassisProps1/ChassModel"/></xsl:attribute>
				</Data>
				<Data name="ServiceTag">
					<xsl:attribute name="display"><!--XLATESTART-->&#26426;&#31665;&#26381;&#21153;&#26631;&#31614;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ChassisProps2/ServiceTag"/></xsl:attribute>
				</Data>
				<Data name="ChassLock">
					<xsl:attribute name="display"><!--XLATESTART-->&#26426;&#31665;&#38145;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="ChassisProps1/ChassLockPresent = 'true'"><!--XLATESTART-->&#23384;&#22312;<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><!--XLATESTART-->&#19981;&#21487;&#29992;<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				
				
				<Data name="AssetTag">
					<xsl:attribute name="display">
					<xsl:choose>
					<xsl:when test="/OMA/BaseBoardList/BaseBoard"><!--XLATESTART-->&#26381;&#21153;&#22120;&#27169;&#22359;&#36164;&#20135;&#26631;&#31614;<!--XLATESTOP-->
					</xsl:when>
					<xsl:otherwise><!--XLATESTART-->&#26426;&#31665;&#36164;&#20135;&#26631;&#31614;<!--XLATESTOP--></xsl:otherwise>
			    		</xsl:choose>
					</xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ChassisProps2/AssetTag"/></xsl:attribute>
				</Data>

				
				
				<xsl:if test="/OMA/BaseBoardList/@count > '0'">
					<xsl:call-template name="BaseBoard"/>
				</xsl:if>
			</ListData>
	</xsl:template>
	
	<xsl:template name="BaseBoard">
		<xsl:for-each select="/OMA/BaseBoardList/BaseBoard">
			<xsl:if test="FeatureFlags/HostingBoard='true'">
				<Data name="BladeServiceTag" type="ustring">
					<xsl:attribute name="display"><!--XLATESTART-->&#26381;&#21153;&#22120;&#27169;&#22359;&#26381;&#21153;&#26631;&#31614;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ServiceTag"/></xsl:attribute>
				</Data>
				
				<Data name="BladeLocation" type="ustring">
					<xsl:attribute name="display"><!--XLATESTART-->&#26381;&#21153;&#22120;&#27169;&#22359;&#20301;&#32622;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="BoardLocation"/></xsl:attribute>
				</Data>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="Hardware">
		<xsl:apply-templates/>
		<xsl:apply-templates select="parent::node()/FirmwareList" />
	</xsl:template>
	<xsl:template match="ProcessorList">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="DevProcessor">
		<ListData name="processor">
			<xsl:attribute name="display"><xsl:value-of select="ExtName"/></xsl:attribute>
			<xsl:attribute name="display"><!--XLATESTART-->&#22788;&#29702;&#22120;<!--XLATESTOP--> <xsl:value-of select="@index + 1"/></xsl:attribute>
			<Data name="ProcessorManufacturer">
				<xsl:attribute name="display"><!--XLATESTART-->&#22788;&#29702;&#22120;&#21046;&#36896;&#21830;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Manufacturer"/></xsl:attribute>
			</Data>
			<Data name="ProcessorFamily">
				<xsl:attribute name="display"><!--XLATESTART-->&#22788;&#29702;&#22120;&#31995;&#21015;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="Family='1'"><!--XLATESTART-->&#20854;&#23427;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='3'"><!--XLATESTART-->8086<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='4'"><!--XLATESTART-->286<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='5'"><!--XLATESTART-->386<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='6'"><!--XLATESTART-->486<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='7'"><!--XLATESTART-->8087<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='8'"><!--XLATESTART-->287<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='9'"><!--XLATESTART-->387<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='10'"><!--XLATESTART-->487<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='11'"><!--XLATESTART-->Pentium<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='12'"><!--XLATESTART-->Pentium Pro<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='13'"><!--XLATESTART-->Pentium II<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='14'"><!--XLATESTART-->Pentium&#65288;&#20351;&#29992; MMX &#25216;&#26415;&#65289;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='15'"><!--XLATESTART-->Celeron<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='16'"><!--XLATESTART-->Pentium II Xeon<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='17'"><!--XLATESTART-->Pentium III<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='130'"><!--XLATESTART-->Itanium<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='176'"><!--XLATESTART-->Pentium III Xeon<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='177'"><!--XLATESTART-->Pentium III&#65288;&#20351;&#29992; Intel SpeedStep &#25216;&#26415;&#65289;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='178'"><!--XLATESTART-->Pentium IV<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='179'"><!--XLATESTART-->Xeon<!--XLATESTOP--></xsl:when>
						<xsl:when test="Family='181'"><!--XLATESTART-->Xeon MP<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><!--XLATESTART-->&#26410;&#30693;<!--XLATESTOP--></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data name="ProcessorVersion">
				<xsl:attribute name="display"><!--XLATESTART-->&#22788;&#29702;&#22120;&#29256;&#26412;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Version"/></xsl:attribute>
			</Data>
			<Data name="CurrentSpeed">
				<xsl:attribute name="display"><!--XLATESTART-->&#24403;&#21069;&#36895;&#24230;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="CurSpeed"/><xsl:text> </xsl:text><xsl:value-of select="CurSpeed/@unit"/></xsl:attribute>
			</Data>
			<Data name="MaximumSpeed">
				<xsl:attribute name="display"><!--XLATESTART-->&#26368;&#39640;&#36895;&#24230;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="MaxSpeed"/><xsl:text> </xsl:text><xsl:value-of select="MaxSpeed/@unit"/></xsl:attribute>
			</Data>
			<Data name="ExtClockSpeed">
				<xsl:attribute name="display"><!--XLATESTART-->&#22806;&#37096;&#26102;&#38047;&#36895;&#29575;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="ExtClockSpeed"/><xsl:text> </xsl:text><xsl:value-of select="ExtClockSpeed/@unit"/></xsl:attribute>
			</Data>
			<Data name="Voltage">
				<xsl:attribute name="display"><!--XLATESTART-->&#30005;&#21387;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Voltage"/><xsl:text> </xsl:text><xsl:value-of select="Voltage/@unit"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="MemoryArrayList">
		<ListData name="Memory">
			<xsl:attribute name="display"><!--XLATESTART-->&#20869;&#23384;<!--XLATESTOP--></xsl:attribute>
			<Data name="InstalledSize">
				<xsl:attribute name="display"><!--XLATESTART-->&#23433;&#35013;&#24635;&#23481;&#37327;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="../MaxInstalledSizeMBCumulative"/><xsl:text> </xsl:text><xsl:value-of select="../MaxInstalledSizeMBCumulative/@unit"/>
				</xsl:attribute>
			</Data>
			<Data name="OSInstalledSize">
				<xsl:attribute name="display"><!--XLATESTART-->&#25805;&#20316;&#31995;&#32479;&#21487;&#29992;&#30340;&#24635;&#23433;&#35013;&#23481;&#37327;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="../MemoryInfo/TotalPhysMemorySizeMB"/><xsl:text> </xsl:text><xsl:value-of select="../MemoryInfo/TotalPhysMemorySizeMB/@unit"/>
				</xsl:attribute>
			</Data>
			<Data name="TotalSize">
				<xsl:attribute name="display"><!--XLATESTART-->&#26368;&#22823;&#24635;&#23481;&#37327;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="../MaxSizeMBCumulative"/><xsl:text> </xsl:text><xsl:value-of select="../MaxSizeMBCumulative/@unit"/>
				</xsl:attribute>
			</Data>
			<Data name="MemoryArrays">
				<xsl:attribute name="display"><!--XLATESTART-->&#20869;&#23384;&#38453;&#21015;&#35745;&#25968;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="@count"/></xsl:attribute>
			</Data>
		</ListData>
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="MemoryArray">
		<ListData name="MemoryArray">
			<xsl:attribute name="display"><!--XLATESTART-->&#20869;&#23384;&#38453;&#21015;<!--XLATESTOP--> <xsl:value-of select="@index + 1"/></xsl:attribute>
			<Data name="Location">
				<xsl:attribute name="display"><!--XLATESTART-->&#20301;&#32622;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="Location='1'"><!--XLATESTART-->&#20854;&#23427;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='3'"><!--XLATESTART-->&#31995;&#32479;&#26495;&#25110;&#27597;&#26495;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='4'"><!--XLATESTART-->ISA &#28155;&#21152;&#24335;&#21345;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='5'"><!--XLATESTART-->EISA &#38468;&#21152;&#20214;&#21345;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='6'"><!--XLATESTART-->PCI &#28155;&#21152;&#24335;&#21345;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='7'"><!--XLATESTART-->MCA &#28155;&#21152;&#24335;&#21345;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='8'"><!--XLATESTART-->PCMCIA &#28155;&#21152;&#24335;&#21345;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='9'"><!--XLATESTART-->&#19987;&#29992;&#28155;&#21152;&#24335;&#21345;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='16'"><!--XLATESTART-->NuBus<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='160'"><!--XLATESTART-->PC-98/C20 &#28155;&#21152;&#24335;&#21345;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='161'"><!--XLATESTART-->PC-98/C24 &#28155;&#21152;&#24335;&#21345;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='162'"><!--XLATESTART-->PC-98/E &#28155;&#21152;&#24335;&#21345;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='163'"><!--XLATESTART-->PC-98/&#26412;&#22320;&#24635;&#32447;&#28155;&#21152;&#24335;&#21345;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='164'"><!--XLATESTART-->PC-98/&#21345;&#25554;&#27133;&#28155;&#21152;&#24335;&#21345;<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><!--XLATESTART-->&#26410;&#30693;<!--XLATESTOP--></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data name="Use">
				<xsl:attribute name="display"><!--XLATESTART-->&#29992;&#36884;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="Location='1'"><!--XLATESTART-->&#20854;&#23427;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='3'"><!--XLATESTART-->&#31995;&#32479;&#20869;&#23384;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='4'"><!--XLATESTART-->&#26174;&#23384;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='5'"><!--XLATESTART-->&#38378;&#23384;<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='6'"><!--XLATESTART-->&#38750;&#26131;&#22833;&#24615; RAM<!--XLATESTOP--></xsl:when>
						<xsl:when test="Location='7'"><!--XLATESTART-->&#39640;&#36895;&#32531;&#23384;<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><!--XLATESTART-->&#26410;&#30693;<!--XLATESTOP--></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data name="InstalledSize">
				<xsl:attribute name="display"><!--XLATESTART-->&#23433;&#35013;&#23481;&#37327;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="InstalledSizeMBCumulative"/><xsl:text> </xsl:text><xsl:value-of select="InstalledSizeMBCumulative/@unit"/></xsl:attribute>
			</Data>
			<Data name="MaximumCapacity">
				<xsl:attribute name="display"><!--XLATESTART-->&#26368;&#22823;&#23481;&#37327;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="MaxSizeMB"/><xsl:text> </xsl:text><xsl:value-of select="MaxSizeMB/@unit"/></xsl:attribute>
			</Data>
			<Data name="NumSocketsTotal">
				<xsl:attribute name="display"><!--XLATESTART-->&#21487;&#29992;&#25554;&#27133;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="NumSocketsTotal"/></xsl:attribute>
			</Data>
			<Data name="NumSocketsInUse">
				<xsl:attribute name="display"><!--XLATESTART-->&#24050;&#29992;&#25554;&#27133;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="NumSocketsInUse"/></xsl:attribute>
			</Data>
			<Data name="ErrCorrType">
				<xsl:attribute name="display"><!--XLATESTART-->&#32416;&#38169;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="ErrCorrType='1'"><!--XLATESTART-->&#20854;&#23427;<!--XLATESTOP--></xsl:when>
						<xsl:when test="ErrCorrType='3'"><!--XLATESTART-->&#26080;<!--XLATESTOP--></xsl:when>
						<xsl:when test="ErrCorrType='4'"><!--XLATESTART-->&#22855;&#20598;&#26657;&#39564;<!--XLATESTOP--></xsl:when>
						<xsl:when test="ErrCorrType='5'"><!--XLATESTART-->&#21333;&#20301; ECC<!--XLATESTOP--></xsl:when>
						<xsl:when test="ErrCorrType='6'"><!--XLATESTART-->&#22810;&#20301; ECC<!--XLATESTOP--></xsl:when>
						<xsl:when test="ErrCorrType='7'"><!--XLATESTART-->CRC<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><!--XLATESTART-->&#26410;&#30693;<!--XLATESTOP--></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="SlotsList">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="Slot">
		<xsl:if test="ExtName != 'Embedded'">
			<ListData>
				<xsl:attribute name="name">slot<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><!--XLATESTART-->&#25554;&#27133; <!--XLATESTOP--> <xsl:value-of select="ExtName"/></xsl:attribute>
				<Data name="adapter">
					<xsl:attribute name="display"><!--XLATESTART-->&#36866;&#37197;&#22120;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="SlotDevice"><xsl:value-of select="SlotDevice/DeviceDesc" /></xsl:when>
							<xsl:otherwise><!--XLATESTART-->&#26410;&#21344;&#29992;<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="Type"  editable="false" type="ustring">
					<xsl:attribute name="display"><!--XLATESTART-->&#31867;&#22411;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="Type='1'"><!--XLATESTART-->&#20854;&#23427;<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='3'"><!--XLATESTART-->ISA<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='4'"><!--XLATESTART-->MCA<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='5'"><!--XLATESTART-->EISA<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='6'"><!--XLATESTART-->PCI<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='7'"><!--XLATESTART-->PCMCIA<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='8'"><!--XLATESTART-->VL VESA<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='9'"><!--XLATESTART-->&#19987;&#29992;<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='10'"><!--XLATESTART-->&#22788;&#29702;&#22120;&#21345;<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='11'"><!--XLATESTART-->&#19987;&#29992;&#20869;&#23384;&#21345;<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='12'"><!--XLATESTART-->IO &#25552;&#21319;&#21345;<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='13'"><!--XLATESTART-->NuBus<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='14'"><!--XLATESTART-->PCI 66Mhz<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='15'"><!--XLATESTART-->AGP<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='16'"><!--XLATESTART-->AGP 2X<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='17'"><!--XLATESTART-->AGP 4X<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='18'"><!--XLATESTART-->PCI X<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='160'"><!--XLATESTART-->PC98 C20<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='161'"><!--XLATESTART-->PC98 C24<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='162'"><!--XLATESTART-->PC98 E<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='163'"><!--XLATESTART-->PC98 &#26412;&#22320;&#24635;&#32447;<!--XLATESTOP--></xsl:when>
							<xsl:when test="Type='164'"><!--XLATESTART-->PC98 &#21345;<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><!--XLATESTART-->&#26410;&#30693;<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="DataBusWidth">
					<xsl:attribute name="display"><!--XLATESTART-->&#25968;&#25454;&#24635;&#32447;&#23485;&#24230;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='1'"><!--XLATESTART-->&#20854;&#23427;<!--XLATESTOP--></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='3'"><!--XLATESTART-->8 &#20301;<!--XLATESTOP--></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='4'"><!--XLATESTART-->16 &#20301;<!--XLATESTOP--></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='5'"><!--XLATESTART-->32 &#20301;<!--XLATESTOP--></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='6'"><!--XLATESTART-->64 &#20301;<!--XLATESTOP--></xsl:when>
							<xsl:when test="HotPlugSystemSlot/DataBusWidth='7'"><!--XLATESTART-->128 &#20301;<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><!--XLATESTART-->&#26410;&#30693;<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="Speed"  editable="false" type="ustring">
					<xsl:attribute name="display"><!--XLATESTART-->&#36895;&#24230;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="HotPlugSystemSlot/SlotSpeed='0'"><!--XLATESTART-->&#26410;&#30693;<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><xsl:value-of select="HotPlugSystemSlot/SlotSpeed"/><xsl:text> </xsl:text><xsl:value-of select="HotPlugSystemSlot/SlotSpeed/@unit"/></xsl:otherwise>
						</xsl:choose></xsl:attribute>
				</Data>
				<Data name="SlotLength">
					<xsl:attribute name="display"><!--XLATESTART-->&#25554;&#27133;&#38271;&#24230;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="Length='1'"><!--XLATESTART-->&#20854;&#23427;<!--XLATESTOP--></xsl:when>
							<xsl:when test="Length='3'"><!--XLATESTART-->&#30701;<!--XLATESTOP--></xsl:when>
							<xsl:when test="Length='4'"><!--XLATESTART-->&#38271;<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><!--XLATESTART-->&#26410;&#30693;<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
				<Data name="VoltSupply"  editable="false" type="ustring">
					<xsl:attribute name="display"><!--XLATESTART-->&#30005;&#21387;&#20379;&#24212;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:if test="IsVolt33='true'">3.3 <!--XLATESTART-->&#20239;&#29305;<!--XLATESTOP--><xsl:if test="IsVolt5='true'">, </xsl:if></xsl:if>
						<xsl:if test="IsVolt5='true'">5 <!--XLATESTART-->&#20239;&#29305;<!--XLATESTOP--></xsl:if>
					</xsl:attribute>
				</Data>
			</ListData>
		</xsl:if>
	</xsl:template>
	<xsl:template match="SystemBIOS">
		<ListData name="SystemBIOS">
			<xsl:attribute name="display"><!--XLATESTART-->BIOS &#20449;&#24687;<!--XLATESTOP--></xsl:attribute>
			<Data name="Manufacturer">
				<xsl:attribute name="display"><!--XLATESTART-->&#21046;&#36896;&#21830;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Manufacturer"/></xsl:attribute>
			</Data>
			<Data name="Version">
				<xsl:attribute name="display"><!--XLATESTART-->&#29256;&#26412;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="Version"/></xsl:attribute>
			</Data>
			<Data name="ReleaseDate">
				<xsl:attribute name="display"><!--XLATESTART-->&#21457;&#24067;&#26085;&#26399;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="ReleaseDate"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="Network">
		<Section name="Network">
			<xsl:attribute name="display"><!--XLATESTART-->&#32593;&#32476;&#25968;&#25454;<!--/XLATESTOP--></xsl:attribute>
			<xsl:choose>
				<xsl:when test="NICList">
					<xsl:apply-templates select="NICList" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates/>
				</xsl:otherwise>
			</xsl:choose>
		</Section>
	</xsl:template>
	<xsl:template match="NICList">
			<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="NICCard">
		<ListData>
			<xsl:attribute name="name">NICList<xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="display"><!--XLATESTART-->&#32593;&#21345; <xsl:value-of select="@index"/> &#25968;&#25454;<!--/XLATESTOP--></xsl:attribute>
			<Data>
				<xsl:attribute name="name">IPAddr<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><!--XLATESTART-->IP &#22320;&#22336;<!--/XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="IPAddress = ''"><!--XLATESTART-->&#26410;&#33719;&#21462;<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><xsl:value-of select="IPAddress"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">SubnetMask<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><!--XLATESTART-->&#23376;&#32593;&#25513;&#30721;<!--/XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="SubnetMask = ''"><!--XLATESTART-->&#26410;&#33719;&#21462;<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><xsl:value-of select="SubnetMask"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">DefaultGateway<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><!--XLATESTART-->&#40664;&#35748;&#32593;&#20851;<!--/XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="DefaultGateway = ''"><!--XLATESTART-->&#26410;&#33719;&#21462;<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><xsl:value-of select="DefaultGateway"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
			<Data>
				<xsl:attribute name="name">MacAddr<xsl:value-of select="@index"/></xsl:attribute>
				<xsl:attribute name="display"><!--XLATESTART-->MAC &#22320;&#22336;<!--/XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value">
					<xsl:choose>
						<xsl:when test="CurrentMACAddr = ''"><!--XLATESTART-->&#26410;&#33719;&#21462;<!--XLATESTOP--></xsl:when>
						<xsl:otherwise><xsl:value-of select="CurrentMACAddr"/></xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="IPAddrList">
		<ListData name="IPAddrList">
			<xsl:attribute name="display"><!--XLATESTART-->IP &#22320;&#22336;&#25968;&#25454;<!--XLATESTOP--></xsl:attribute>
			<xsl:apply-templates/>
		</ListData>
	</xsl:template>
	<xsl:template match="IPAddr">
		<Data name="IPAddr">
			<xsl:attribute name="name">IPAddr<xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="display"><!--XLATESTART-->IP &#22320;&#22336; <!--XLATESTOP--><xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
		</Data>
	</xsl:template>
	<xsl:template match="Software">
		<Section name="Software">
			<xsl:attribute name="display"><!--XLATESTART-->&#36719;&#20214;&#37197;&#32622;&#25991;&#20214;<!--XLATESTOP--></xsl:attribute>
			<xsl:apply-templates/>
		</Section>
	</xsl:template>
	<xsl:template match="OSInfo">
		<ListData name="OSInfo">
			<xsl:attribute name="display"><!--XLATESTART-->&#25805;&#20316;&#31995;&#32479;<!--XLATESTOP--></xsl:attribute>
			<Data name="OSName">
				<xsl:attribute name="display"><!--XLATESTART-->&#21517;&#31216;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="OSName"/></xsl:attribute>
			</Data>
			<Data name="OSVersion">
				<xsl:attribute name="display"><!--XLATESTART-->&#29256;&#26412;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="OSVersion"/></xsl:attribute>
			</Data>
			<Data name="SystemTime">
				<xsl:attribute name="display"><!--XLATESTART-->&#31995;&#32479;&#26102;&#38388;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="//System/SystemInfo/SystemTime"/></xsl:attribute>
			</Data>
			<Data name="SystemBootupTime">
				<xsl:attribute name="display"><!--XLATESTART-->&#31995;&#32479;&#21551;&#21160;&#26102;&#38388;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="//System/SystemInfo/SystemBootupTime"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>
	<xsl:template match="FirmwareList">
		<xsl:apply-templates />
	</xsl:template>
	<xsl:template match="Firmware">
		<ListData>
			<xsl:attribute name="name">Firmware_<xsl:value-of select="@index"/></xsl:attribute>
			<xsl:attribute name="display"><!--XLATESTART-->&#22266;&#20214;&#20449;&#24687;<!--XLATESTOP--></xsl:attribute>
			<Data name="Name">
				<xsl:attribute name="display"><!--XLATESTART-->&#21517;&#31216;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="FWText"/></xsl:attribute>
			</Data>
			<Data name="Version">
				<xsl:attribute name="display"><!--XLATESTART-->&#29256;&#26412;<!--XLATESTOP--></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="FWVersion"/></xsl:attribute>
			</Data>
		</ListData>
	</xsl:template>

	<xsl:template match="ClusterInfo">
		<Section name="ClusterInfo">
			<xsl:attribute name="display"><!--XLATESTART-->&#32676;&#38598;&#20449;&#24687;<!--XLATESTOP--></xsl:attribute>
			<ListData name="Information">
				<xsl:attribute name="display"><!--XLATESTART-->&#32676;&#38598;&#20449;&#24687;<!--XLATESTOP--></xsl:attribute>
				<Data name="ClusterName">
					<xsl:attribute name="display"><!--XLATESTART-->&#32676;&#38598;&#21517;&#31216;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ClusterName"/></xsl:attribute>
				</Data>
				<Data name="TypeDescription">
					<xsl:attribute name="display"><!--XLATESTART-->&#32676;&#38598;&#35828;&#26126;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="TypeDescription"/></xsl:attribute>
				</Data>
				<Data name="ClusterType">
					<xsl:attribute name="display"><!--XLATESTART-->&#32676;&#38598;&#31867;&#22411;<!--XLATESTOP--></xsl:attribute>
					<xsl:attribute name="value">
						<xsl:choose>
							<xsl:when test="ClusterType='2'"><!--XLATESTART-->Microsoft &#32676;&#38598;&#26381;&#21153;&#22120;<!--XLATESTOP--></xsl:when>
							<xsl:otherwise><!--XLATESTART-->&#26410;&#30693;<!--XLATESTOP--></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</Data>
			</ListData>
		</Section>
	</xsl:template>

	<xsl:template match="*"/>

</xsl:stylesheet>
